static const uint16_t presym_length_table[] = {
  1,	/* ! */
  1,	/* % */
  1,	/* & */
  1,	/* * */
  1,	/* + */
  1,	/* - */
  1,	/* / */
  1,	/* < */
  1,	/* > */
  1,	/* E */
  1,	/* ^ */
  1,	/* _ */
  1,	/* ` */
  1,	/* a */
  1,	/* b */
  1,	/* c */
  1,	/* d */
  1,	/* e */
  1,	/* f */
  1,	/* g */
  1,	/* h */
  1,	/* i */
  1,	/* j */
  1,	/* k */
  1,	/* l */
  1,	/* m */
  1,	/* n */
  1,	/* o */
  1,	/* p */
  1,	/* q */
  1,	/* r */
  1,	/* s */
  1,	/* t */
  1,	/* u */
  1,	/* v */
  1,	/* w */
  1,	/* x */
  1,	/* y */
  1,	/* z */
  1,	/* | */
  1,	/* ~ */
  2,	/* != */
  2,	/* !~ */
  2,	/* $$ */
  2,	/* $& */
  2,	/* $' */
  2,	/* $0 */
  2,	/* $? */
  2,	/* $` */
  2,	/* $~ */
  2,	/* && */
  2,	/* ** */
  2,	/* +@ */
  2,	/* -@ */
  2,	/* << */
  2,	/* <= */
  2,	/* == */
  2,	/* =~ */
  2,	/* >= */
  2,	/* >> */
  2,	/* @h */
  2,	/* @q */
  2,	/* @t */
  2,	/* @w */
  2,	/* @x */
  2,	/* @y */
  2,	/* AA */
  2,	/* AM */
  2,	/* CA */
  2,	/* CC */
  2,	/* CI */
  2,	/* CW */
  2,	/* EC */
  2,	/* EI */
  2,	/* GC */
  2,	/* GL */
  2,	/* IO */
  2,	/* IR */
  2,	/* PI */
  2,	/* SA */
  2,	/* SC */
  2,	/* SP */
  2,	/* [] */
  2,	/* a0 */
  2,	/* a1 */
  2,	/* a= */
  2,	/* aa */
  2,	/* ar */
  2,	/* at */
  2,	/* aw */
  2,	/* ax */
  2,	/* ay */
  2,	/* b= */
  2,	/* bb */
  2,	/* bg */
  2,	/* bh */
  2,	/* bi */
  2,	/* br */
  2,	/* bs */
  2,	/* bt */
  2,	/* bw */
  2,	/* bx */
  2,	/* by */
  2,	/* c1 */
  2,	/* c2 */
  2,	/* c= */
  2,	/* cb */
  2,	/* cc */
  2,	/* ch */
  2,	/* ci */
  2,	/* cl */
  2,	/* co */
  2,	/* cs */
  2,	/* cv */
  2,	/* cx */
  2,	/* cy */
  2,	/* d2 */
  2,	/* d= */
  2,	/* db */
  2,	/* dp */
  2,	/* dt */
  2,	/* dv */
  2,	/* dx */
  2,	/* dy */
  2,	/* e= */
  2,	/* e_ */
  2,	/* ed */
  2,	/* ei */
  2,	/* eq */
  2,	/* ev */
  2,	/* f= */
  2,	/* fd */
  2,	/* fn */
  2,	/* fo */
  2,	/* fr */
  2,	/* fs */
  2,	/* g= */
  2,	/* gc */
  2,	/* gm */
  2,	/* h= */
  2,	/* hc */
  2,	/* hf */
  2,	/* hh */
  2,	/* hl */
  2,	/* hm */
  2,	/* id */
  2,	/* ii */
  2,	/* im */
  2,	/* in */
  2,	/* io */
  2,	/* ir */
  2,	/* kk */
  2,	/* kr */
  2,	/* la */
  2,	/* lb */
  2,	/* le */
  2,	/* lh */
  2,	/* li */
  2,	/* ll */
  2,	/* lm */
  2,	/* ln */
  2,	/* lp */
  2,	/* lu */
  2,	/* m1 */
  2,	/* m2 */
  2,	/* m3 */
  2,	/* md */
  2,	/* mm */
  2,	/* mn */
  2,	/* ms */
  2,	/* mw */
  2,	/* mx */
  2,	/* my */
  2,	/* n2 */
  2,	/* nd */
  2,	/* nk */
  2,	/* nn */
  2,	/* nt */
  2,	/* nv */
  2,	/* of */
  2,	/* on */
  2,	/* oo */
  2,	/* op */
  2,	/* p1 */
  2,	/* p2 */
  2,	/* p3 */
  2,	/* pb */
  2,	/* pc */
  2,	/* ph */
  2,	/* pi */
  2,	/* pp */
  2,	/* pr */
  2,	/* ps */
  2,	/* pt */
  2,	/* pw */
  2,	/* px */
  2,	/* py */
  2,	/* r0 */
  2,	/* r1 */
  2,	/* r= */
  2,	/* re */
  2,	/* rf */
  2,	/* ri */
  2,	/* rr */
  2,	/* rs */
  2,	/* rt */
  2,	/* rw */
  2,	/* ry */
  2,	/* sh */
  2,	/* sn */
  2,	/* ss */
  2,	/* sv */
  2,	/* sw */
  2,	/* sx */
  2,	/* sy */
  2,	/* t1 */
  2,	/* t2 */
  2,	/* t3 */
  2,	/* t4 */
  2,	/* t5 */
  2,	/* tb */
  2,	/* te */
  2,	/* th */
  2,	/* tp */
  2,	/* tr */
  2,	/* tw */
  2,	/* tx */
  2,	/* ty */
  2,	/* ul */
  2,	/* up */
  2,	/* ur */
  2,	/* v1 */
  2,	/* v2 */
  2,	/* va */
  2,	/* vg */
  2,	/* vo */
  2,	/* vr */
  2,	/* vs */
  2,	/* vv */
  2,	/* vw */
  2,	/* w= */
  2,	/* wb */
  2,	/* wc */
  2,	/* wd */
  2,	/* wf */
  2,	/* wp */
  2,	/* ww */
  2,	/* x1 */
  2,	/* x2 */
  2,	/* x= */
  2,	/* xc */
  2,	/* xf */
  2,	/* xm */
  2,	/* xp */
  2,	/* xx */
  2,	/* y1 */
  2,	/* y2 */
  2,	/* y= */
  2,	/* yc */
  2,	/* yf */
  2,	/* ym */
  2,	/* yp */
  2,	/* yt */
  2,	/* yy */
  2,	/* || */
  3,	/* $vg */
  3,	/* <=> */
  3,	/* === */
  3,	/* @IR */
  3,	/* @cc */
  3,	/* @db */
  3,	/* @dx */
  3,	/* @dy */
  3,	/* @eq */
  3,	/* @ev */
  3,	/* @fn */
  3,	/* @hm */
  3,	/* @id */
  3,	/* @ir */
  3,	/* @lp */
  3,	/* @mx */
  3,	/* @my */
  3,	/* @rw */
  3,	/* @sx */
  3,	/* @sy */
  3,	/* @tb */
  3,	/* @vg */
  3,	/* @vv */
  3,	/* ALT */
  3,	/* CCW */
  3,	/* Col */
  3,	/* DSP */
  3,	/* Dir */
  3,	/* EIO */
  3,	/* FBO */
  3,	/* NAN */
  3,	/* NVG */
  3,	/* OSC */
  3,	/* Osc */
  3,	/* Pos */
  3,	/* Qml */
  3,	/* Set */
  3,	/* TID */
  3,	/* []= */
  3,	/* _bx */
  3,	/* _by */
  3,	/* _lx */
  3,	/* _ly */
  3,	/* _rx */
  3,	/* _ry */
  3,	/* _ux */
  3,	/* _uy */
  3,	/* abs */
  3,	/* act */
  3,	/* add */
  3,	/* all */
  3,	/* alt */
  3,	/* amp */
  3,	/* ani */
  3,	/* app */
  3,	/* arc */
  3,	/* arg */
  3,	/* arp */
  3,	/* arr */
  3,	/* ary */
  3,	/* avg */
  3,	/* bar */
  3,	/* bb1 */
  3,	/* bb2 */
  3,	/* bbl */
  3,	/* bbs */
  3,	/* beg */
  3,	/* bg= */
  3,	/* bid */
  3,	/* blk */
  3,	/* bnd */
  3,	/* bot */
  3,	/* box */
  3,	/* but */
  3,	/* bx1 */
  3,	/* bx2 */
  3,	/* bx3 */
  3,	/* by1 */
  3,	/* by2 */
  3,	/* by3 */
  3,	/* cap */
  3,	/* cat */
  3,	/* cc= */
  3,	/* cch */
  3,	/* chd */
  3,	/* chr */
  3,	/* clr */
  3,	/* cls */
  3,	/* cmd */
  3,	/* cmp */
  3,	/* cnt */
  3,	/* col */
  3,	/* cos */
  3,	/* cpy */
  3,	/* ctx */
  3,	/* dat */
  3,	/* day */
  3,	/* db= */
  3,	/* del */
  3,	/* dem */
  3,	/* dev */
  3,	/* dig */
  3,	/* dim */
  3,	/* dir */
  3,	/* div */
  3,	/* dmg */
  3,	/* dne */
  3,	/* dsp */
  3,	/* dst */
  3,	/* dt_ */
  3,	/* dup */
  3,	/* dyn */
  3,	/* eff */
  3,	/* elm */
  3,	/* end */
  3,	/* ent */
  3,	/* env */
  3,	/* eof */
  3,	/* erf */
  3,	/* err */
  3,	/* evs */
  3,	/* exp */
  3,	/* ext */
  3,	/* fav */
  3,	/* fbo */
  3,	/* fib */
  3,	/* fil */
  3,	/* fin */
  3,	/* fn= */
  3,	/* foo */
  3,	/* gap */
  3,	/* gen */
  3,	/* gid */
  3,	/* hes */
  3,	/* hex */
  3,	/* hl= */
  3,	/* hsl */
  3,	/* hue */
  3,	/* ids */
  3,	/* idx */
  3,	/* img */
  3,	/* ind */
  3,	/* ino */
  3,	/* ins */
  3,	/* inx */
  3,	/* ist */
  3,	/* key */
  3,	/* kid */
  3,	/* kit */
  3,	/* lab */
  3,	/* len */
  3,	/* let */
  3,	/* lfo */
  3,	/* lhs */
  3,	/* lim */
  3,	/* lir */
  3,	/* log */
  3,	/* low */
  3,	/* mag */
  3,	/* map */
  3,	/* max */
  3,	/* mch */
  3,	/* mid */
  3,	/* min */
  3,	/* mmm */
  3,	/* mod */
  3,	/* mon */
  3,	/* new */
  3,	/* nhr */
  3,	/* now */
  3,	/* num */
  3,	/* nxt */
  3,	/* obj */
  3,	/* oct */
  3,	/* off */
  3,	/* old */
  3,	/* opt */
  3,	/* ord */
  3,	/* osc */
  3,	/* out */
  3,	/* p1= */
  3,	/* p2= */
  3,	/* pad */
  3,	/* par */
  3,	/* pat */
  3,	/* pdb */
  3,	/* pid */
  3,	/* pir */
  3,	/* pop */
  3,	/* pos */
  3,	/* pow */
  3,	/* prt */
  3,	/* pts */
  3,	/* pwd */
  3,	/* qid */
  3,	/* quo */
  3,	/* red */
  3,	/* ref */
  3,	/* rel */
  3,	/* rem */
  3,	/* req */
  3,	/* res */
  3,	/* ret */
  3,	/* rgb */
  3,	/* rhs */
  3,	/* rnd */
  3,	/* row */
  3,	/* run */
  3,	/* rw2 */
  3,	/* sec */
  3,	/* sel */
  3,	/* sep */
  3,	/* seq */
  3,	/* set */
  3,	/* sin */
  3,	/* src */
  3,	/* srt */
  3,	/* st0 */
  3,	/* st1 */
  3,	/* st2 */
  3,	/* st3 */
  3,	/* str */
  3,	/* sub */
  3,	/* sum */
  3,	/* sup */
  3,	/* sus */
  3,	/* sym */
  3,	/* tab */
  3,	/* tan */
  3,	/* tap */
  3,	/* te1 */
  3,	/* te2 */
  3,	/* te3 */
  3,	/* te4 */
  3,	/* tic */
  3,	/* tmp */
  3,	/* toc */
  3,	/* tok */
  3,	/* top */
  3,	/* tot */
  3,	/* tr! */
  3,	/* typ */
  3,	/* uid */
  3,	/* url */
  3,	/* use */
  3,	/* utc */
  3,	/* val */
  3,	/* vce */
  3,	/* vel */
  3,	/* vis */
  3,	/* wah */
  3,	/* wid */
  3,	/* win */
  3,	/* x_b */
  3,	/* x_m */
  3,	/* xc= */
  3,	/* xsp */
  3,	/* y_b */
  3,	/* y_m */
  3,	/* yc= */
  3,	/* zip */
  4,	/* @add */
  4,	/* @amp */
  4,	/* @app */
  4,	/* @arp */
  4,	/* @avg */
  4,	/* @bot */
  4,	/* @box */
  4,	/* @buf */
  4,	/* @but */
  4,	/* @cat */
  4,	/* @clr */
  4,	/* @col */
  4,	/* @cpy */
  4,	/* @del */
  4,	/* @dep */
  4,	/* @dir */
  4,	/* @dst */
  4,	/* @dyn */
  4,	/* @eff */
  4,	/* @env */
  4,	/* @ext */
  4,	/* @fib */
  4,	/* @fil */
  4,	/* @gen */
  4,	/* @hes */
  4,	/* @hue */
  4,	/* @key */
  4,	/* @kit */
  4,	/* @lfo */
  4,	/* @lhs */
  4,	/* @mod */
  4,	/* @nhr */
  4,	/* @num */
  4,	/* @obj */
  4,	/* @oct */
  4,	/* @opt */
  4,	/* @pid */
  4,	/* @pos */
  4,	/* @pow */
  4,	/* @qid */
  4,	/* @ref */
  4,	/* @rhs */
  4,	/* @rnd */
  4,	/* @row */
  4,	/* @rw2 */
  4,	/* @sep */
  4,	/* @seq */
  4,	/* @str */
  4,	/* @sub */
  4,	/* @sus */
  4,	/* @te1 */
  4,	/* @te2 */
  4,	/* @te3 */
  4,	/* @te4 */
  4,	/* @top */
  4,	/* @typ */
  4,	/* @url */
  4,	/* @vel */
  4,	/* @vis */
  4,	/* @wah */
  4,	/* ARGV */
  4,	/* BUTT */
  4,	/* CTRL */
  4,	/* Draw */
  4,	/* EADV */
  4,	/* EDOM */
  4,	/* EXCL */
  4,	/* File */
  4,	/* Glob */
  4,	/* Grid */
  4,	/* HOLE */
  4,	/* Hash */
  4,	/* Knob */
  4,	/* Math */
  4,	/* Menu */
  4,	/* NONE */
  4,	/* NULL */
  4,	/* Node */
  4,	/* PUGL */
  4,	/* Path */
  4,	/* Proc */
  4,	/* RDWR */
  4,	/* Rect */
  4,	/* SYNC */
  4,	/* Stat */
  4,	/* Test */
  4,	/* Text */
  4,	/* Time */
  4,	/* Unit */
  4,	/* _dev */
  4,	/* abbv */
  4,	/* acos */
  4,	/* add= */
  4,	/* add? */
  4,	/* aeps */
  4,	/* all? */
  4,	/* ampl */
  4,	/* any? */
  4,	/* appl */
  4,	/* arg0 */
  4,	/* arg1 */
  4,	/* arg2 */
  4,	/* args */
  4,	/* argv */
  4,	/* asin */
  4,	/* atan */
  4,	/* attr */
  4,	/* back */
  4,	/* bank */
  4,	/* base */
  4,	/* bbox */
  4,	/* best */
  4,	/* blue */
  4,	/* bold */
  4,	/* bsiz */
  4,	/* byte */
  4,	/* call */
  4,	/* cang */
  4,	/* cbrt */
  4,	/* ceil */
  4,	/* chan */
  4,	/* char */
  4,	/* chop */
  4,	/* circ */
  4,	/* code */
  4,	/* cols */
  4,	/* comb */
  4,	/* conn */
  4,	/* copy */
  4,	/* cosh */
  4,	/* ctrl */
  4,	/* curr */
  4,	/* cval */
  4,	/* data */
  4,	/* demo */
  4,	/* dest */
  4,	/* dirs */
  4,	/* dist */
  4,	/* down */
  4,	/* draw */
  4,	/* drum */
  4,	/* dst? */
  4,	/* dump */
  4,	/* dval */
  4,	/* e_id */
  4,	/* each */
  4,	/* echo */
  4,	/* edit */
  4,	/* egrp */
  4,	/* elem */
  4,	/* emit */
  4,	/* end_ */
  4,	/* enum */
  4,	/* eof? */
  4,	/* epos */
  4,	/* epri */
  4,	/* eql? */
  4,	/* erfc */
  4,	/* estr */
  4,	/* eval */
  4,	/* excl */
  4,	/* exit */
  4,	/* exp1 */
  4,	/* exp2 */
  4,	/* ext1 */
  4,	/* ext2 */
  4,	/* ext= */
  4,	/* fade */
  4,	/* favs */
  4,	/* feed */
  4,	/* ff_h */
  4,	/* ff_w */
  4,	/* ff_x */
  4,	/* ff_y */
  4,	/* file */
  4,	/* fill */
  4,	/* filt */
  4,	/* find */
  4,	/* fine */
  4,	/* flag */
  4,	/* font */
  4,	/* foot */
  4,	/* fork */
  4,	/* free */
  4,	/* freq */
  4,	/* full */
  4,	/* func */
  4,	/* fv_h */
  4,	/* fv_w */
  4,	/* fv_x */
  4,	/* fv_y */
  4,	/* fval */
  4,	/* gain */
  4,	/* getc */
  4,	/* gets */
  4,	/* glob */
  4,	/* gmt? */
  4,	/* gold */
  4,	/* grad */
  4,	/* grep */
  4,	/* grid */
  4,	/* gsub */
  4,	/* harm */
  4,	/* hash */
  4,	/* head */
  4,	/* high */
  4,	/* hit? */
  4,	/* home */
  4,	/* hour */
  4,	/* hpad */
  4,	/* hsla */
  4,	/* idx2 */
  4,	/* idx= */
  4,	/* inds */
  4,	/* info */
  4,	/* init */
  4,	/* inst */
  4,	/* item */
  4,	/* join */
  4,	/* key? */
  4,	/* keys */
  4,	/* kill */
  4,	/* kits */
  4,	/* knob */
  4,	/* lary */
  4,	/* last */
  4,	/* lbut */
  4,	/* left */
  4,	/* lidx */
  4,	/* line */
  4,	/* list */
  4,	/* log2 */
  4,	/* logo */
  4,	/* loop */
  4,	/* lval */
  4,	/* map! */
  4,	/* mapp */
  4,	/* max_ */
  4,	/* mday */
  4,	/* menu */
  4,	/* mesg */
  4,	/* meta */
  4,	/* meth */
  4,	/* min_ */
  4,	/* mod= */
  4,	/* mode */
  4,	/* mono */
  4,	/* moog */
  4,	/* move */
  4,	/* mval */
  4,	/* name */
  4,	/* nan? */
  4,	/* nbox */
  4,	/* ndep */
  4,	/* nest */
  4,	/* next */
  4,	/* nil? */
  4,	/* node */
  4,	/* noff */
  4,	/* none */
  4,	/* note */
  4,	/* num= */
  4,	/* nval */
  4,	/* objs */
  4,	/* off= */
  4,	/* offs */
  4,	/* oldi */
  4,	/* oldl */
  4,	/* oldr */
  4,	/* olds */
  4,	/* open */
  4,	/* opts */
  4,	/* orig */
  4,	/* oval */
  4,	/* pack */
  4,	/* pad1 */
  4,	/* pad2 */
  4,	/* pad= */
  4,	/* padh */
  4,	/* padw */
  4,	/* pars */
  4,	/* part */
  4,	/* pat= */
  4,	/* path */
  4,	/* pbox */
  4,	/* pbvm */
  4,	/* peek */
  4,	/* perm */
  4,	/* pipe */
  4,	/* plen */
  4,	/* plot */
  4,	/* poll */
  4,	/* port */
  4,	/* pos2 */
  4,	/* pos= */
  4,	/* ppid */
  4,	/* prev */
  4,	/* proc */
  4,	/* prog */
  4,	/* prop */
  4,	/* pset */
  4,	/* push */
  4,	/* puts */
  4,	/* pval */
  4,	/* q_ir */
  4,	/* quit */
  4,	/* rand */
  4,	/* rdev */
  4,	/* read */
  4,	/* rect */
  4,	/* recv */
  4,	/* refs */
  4,	/* relx */
  4,	/* rely */
  4,	/* rest */
  4,	/* rgba */
  4,	/* rgbf */
  4,	/* ridx */
  4,	/* root */
  4,	/* ropt */
  4,	/* row1 */
  4,	/* row2 */
  4,	/* row3 */
  4,	/* rows */
  4,	/* rseq */
  4,	/* rval */
  4,	/* sans */
  4,	/* save */
  4,	/* scan */
  4,	/* seek */
  4,	/* seen */
  4,	/* send */
  4,	/* setf */
  4,	/* seti */
  4,	/* sets */
  4,	/* sheq */
  4,	/* side */
  4,	/* sine */
  4,	/* sinh */
  4,	/* size */
  4,	/* skip */
  4,	/* slot */
  4,	/* snsa */
  4,	/* snsb */
  4,	/* sort */
  4,	/* spin */
  4,	/* sqrt */
  4,	/* stat */
  4,	/* stem */
  4,	/* step */
  4,	/* stop */
  4,	/* str2 */
  4,	/* sub! */
  4,	/* succ */
  4,	/* supe */
  4,	/* swap */
  4,	/* sym= */
  4,	/* sync */
  4,	/* tabs */
  4,	/* tanh */
  4,	/* te1= */
  4,	/* tell */
  4,	/* test */
  4,	/* text */
  4,	/* tgrp */
  4,	/* then */
  4,	/* this */
  4,	/* tick */
  4,	/* time */
  4,	/* to_a */
  4,	/* to_f */
  4,	/* to_h */
  4,	/* to_i */
  4,	/* to_s */
  4,	/* tr_s */
  4,	/* tty? */
  4,	/* tune */
  4,	/* tval */
  4,	/* type */
  4,	/* uniq */
  4,	/* upto */
  4,	/* usec */
  4,	/* user */
  4,	/* utc? */
  4,	/* vals */
  4,	/* vfor */
  4,	/* vgrp */
  4,	/* view */
  4,	/* vis= */
  4,	/* vpad */
  4,	/* vpow */
  4,	/* wNew */
  4,	/* wOld */
  4,	/* warp */
  4,	/* wave */
  4,	/* wday */
  4,	/* weak */
  4,	/* widg */
  4,	/* xdat */
  4,	/* xmin */
  4,	/* xoff */
  4,	/* xpad */
  4,	/* xpts */
  4,	/* ydat */
  4,	/* yday */
  4,	/* year */
  4,	/* yloc */
  4,	/* ymin */
  4,	/* yoff */
  4,	/* ypos */
  4,	/* ypts */
  4,	/* zone */
  5,	/* @ampl */
  5,	/* @appl */
  5,	/* @args */
  5,	/* @bank */
  5,	/* @base */
  5,	/* @chan */
  5,	/* @code */
  5,	/* @copy */
  5,	/* @ctrl */
  5,	/* @data */
  5,	/* @demo */
  5,	/* @dirs */
  5,	/* @drum */
  5,	/* @echo */
  5,	/* @edit */
  5,	/* @egrp */
  5,	/* @favs */
  5,	/* @file */
  5,	/* @filt */
  5,	/* @font */
  5,	/* @foot */
  5,	/* @free */
  5,	/* @freq */
  5,	/* @full */
  5,	/* @func */
  5,	/* @gain */
  5,	/* @glob */
  5,	/* @harm */
  5,	/* @hash */
  5,	/* @head */
  5,	/* @info */
  5,	/* @init */
  5,	/* @item */
  5,	/* @knob */
  5,	/* @last */
  5,	/* @lbut */
  5,	/* @line */
  5,	/* @logo */
  5,	/* @mapp */
  5,	/* @menu */
  5,	/* @meth */
  5,	/* @mode */
  5,	/* @name */
  5,	/* @next */
  5,	/* @objs */
  5,	/* @part */
  5,	/* @path */
  5,	/* @plot */
  5,	/* @port */
  5,	/* @prev */
  5,	/* @proc */
  5,	/* @pset */
  5,	/* @refs */
  5,	/* @row1 */
  5,	/* @row2 */
  5,	/* @row3 */
  5,	/* @side */
  5,	/* @slot */
  5,	/* @snsa */
  5,	/* @snsb */
  5,	/* @swap */
  5,	/* @test */
  5,	/* @text */
  5,	/* @tgrp */
  5,	/* @this */
  5,	/* @tune */
  5,	/* @type */
  5,	/* @unix */
  5,	/* @vfor */
  5,	/* @vgrp */
  5,	/* @vpow */
  5,	/* @wave */
  5,	/* Align */
  5,	/* Array */
  5,	/* BEVEL */
  5,	/* CREAT */
  5,	/* Class */
  5,	/* Color */
  5,	/* DEBUG */
  5,	/* DSYNC */
  5,	/* E2BIG */
  5,	/* EAUTH */
  5,	/* EBADE */
  5,	/* EBADF */
  5,	/* EBADR */
  5,	/* EBUSY */
  5,	/* ECOMM */
  5,	/* EFBIG */
  5,	/* EIDRM */
  5,	/* EINTR */
  5,	/* ELOOP */
  5,	/* ENOSR */
  5,	/* ENXIO */
  5,	/* EPERM */
  5,	/* EPIPE */
  5,	/* EROFS */
  5,	/* ESRCH */
  5,	/* ETIME */
  5,	/* EXDEV */
  5,	/* Errno */
  5,	/* Fiber */
  5,	/* Float */
  5,	/* Forms */
  5,	/* Group */
  5,	/* MITER */
  5,	/* MRuby */
  5,	/* Match */
  5,	/* Paint */
  5,	/* ROUND */
  5,	/* RSYNC */
  5,	/* Range */
  5,	/* SHIFT */
  5,	/* SOLID */
  5,	/* STDIN */
  5,	/* SUPER */
  5,	/* Sched */
  5,	/* TFunc */
  5,	/* TInst */
  5,	/* TProp */
  5,	/* TRUNC */
  5,	/* Theme */
  5,	/* VisEq */
  5,	/* _mode */
  5,	/* _pipe */
  5,	/* _rdev */
  5,	/* about */
  5,	/* abs_x */
  5,	/* abs_y */
  5,	/* acosh */
  5,	/* align */
  5,	/* alpha */
  5,	/* aname */
  5,	/* angle */
  5,	/* appl= */
  5,	/* apply */
  5,	/* args= */
  5,	/* arity */
  5,	/* array */
  5,	/* ary_F */
  5,	/* ary_T */
  5,	/* asinh */
  5,	/* assoc */
  5,	/* atan2 */
  5,	/* atanh */
  5,	/* atime */
  5,	/* bank= */
  5,	/* banks */
  5,	/* base= */
  5,	/* begin */
  5,	/* black */
  5,	/* blist */
  5,	/* block */
  5,	/* bound */
  5,	/* boxes */
  5,	/* breal */
  5,	/* bytes */
  5,	/* capts */
  5,	/* chBox */
  5,	/* ch_id */
  5,	/* chars */
  5,	/* chdir */
  5,	/* check */
  5,	/* child */
  5,	/* chmod */
  5,	/* chomp */
  5,	/* chop! */
  5,	/* chunk */
  5,	/* class */
  5,	/* clean */
  5,	/* clear */
  5,	/* clone */
  5,	/* close */
  5,	/* cname */
  5,	/* coeff */
  5,	/* color */
  5,	/* cols= */
  5,	/* coral */
  5,	/* count */
  5,	/* ctime */
  5,	/* curry */
  5,	/* cvt_x */
  5,	/* cvt_y */
  5,	/* data= */
  5,	/* data_ */
  5,	/* debug */
  5,	/* delay */
  5,	/* delta */
  5,	/* depth */
  5,	/* doRun */
  5,	/* draw1 */
  5,	/* draw2 */
  5,	/* drum= */
  5,	/* dummy */
  5,	/* emode */
  5,	/* errno */
  5,	/* event */
  5,	/* exit! */
  5,	/* exit? */
  5,	/* extfm */
  5,	/* extra */
  5,	/* fancy */
  5,	/* favs= */
  5,	/* fbase */
  5,	/* fetch */
  5,	/* ff_x2 */
  5,	/* field */
  5,	/* file= */
  5,	/* file? */
  5,	/* files */
  5,	/* first */
  5,	/* fixed */
  5,	/* flags */
  5,	/* float */
  5,	/* flock */
  5,	/* floor */
  5,	/* flush */
  5,	/* fname */
  5,	/* forms */
  5,	/* found */
  5,	/* frame */
  5,	/* frexp */
  5,	/* front */
  5,	/* ftype */
  5,	/* fv_w2 */
  5,	/* fv_x2 */
  5,	/* gbl_h */
  5,	/* gbl_w */
  5,	/* getgm */
  5,	/* getwd */
  5,	/* grad1 */
  5,	/* grad2 */
  5,	/* green */
  5,	/* grid= */
  5,	/* gridt */
  5,	/* gsub! */
  5,	/* head1 */
  5,	/* hedit */
  5,	/* hfill */
  5,	/* hpack */
  5,	/* hypot */
  5,	/* ident */
  5,	/* image */
  5,	/* impl= */
  5,	/* index */
  5,	/* info= */
  5,	/* inner */
  5,	/* input */
  5,	/* is_a? */
  5,	/* label */
  5,	/* lastx */
  5,	/* lasty */
  5,	/* layer */
  5,	/* ldexp */
  5,	/* learn */
  5,	/* level */
  5,	/* limit */
  5,	/* lines */
  5,	/* ljust */
  5,	/* loc_x */
  5,	/* local */
  5,	/* log10 */
  5,	/* log_x */
  5,	/* log_y */
  5,	/* lsize */
  5,	/* lstat */
  5,	/* macro */
  5,	/* match */
  5,	/* max_x */
  5,	/* max_y */
  5,	/* merge */
  5,	/* meter */
  5,	/* micro */
  5,	/* min_x */
  5,	/* min_y */
  5,	/* mixer */
  5,	/* mkdir */
  5,	/* mockx */
  5,	/* mocky */
  5,	/* mode= */
  5,	/* monof */
  5,	/* month */
  5,	/* mouse */
  5,	/* mtime */
  5,	/* names */
  5,	/* next! */
  5,	/* nlink */
  5,	/* noise */
  5,	/* nopts */
  5,	/* npath */
  5,	/* nrows */
  5,	/* nsize */
  5,	/* ntype */
  5,	/* old_x */
  5,	/* oldcc */
  5,	/* omega */
  5,	/* onKey */
  5,	/* order */
  5,	/* oscil */
  5,	/* other */
  5,	/* outer */
  5,	/* padh2 */
  5,	/* padw2 */
  5,	/* paint */
  5,	/* panic */
  5,	/* param */
  5,	/* parts */
  5,	/* paste */
  5,	/* phase */
  5,	/* pipe? */
  5,	/* place */
  5,	/* plist */
  5,	/* polar */
  5,	/* popen */
  5,	/* power */
  5,	/* ppath */
  5,	/* pproc */
  5,	/* pread */
  5,	/* press */
  5,	/* prev= */
  5,	/* prime */
  5,	/* print */
  5,	/* props */
  5,	/* pxpad */
  5,	/* quote */
  5,	/* raise */
  5,	/* range */
  5,	/* ratio */
  5,	/* reads */
  5,	/* reset */
  5,	/* reson */
  5,	/* rgbaf */
  5,	/* rharm */
  5,	/* right */
  5,	/* rjust */
  5,	/* rmdir */
  5,	/* round */
  5,	/* rows= */
  5,	/* rwbox */
  5,	/* scale */
  5,	/* sched */
  5,	/* setrw */
  5,	/* settf */
  5,	/* setup */
  5,	/* shape */
  5,	/* shift */
  5,	/* size= */
  5,	/* size? */
  5,	/* skip= */
  5,	/* sleep */
  5,	/* slice */
  5,	/* slide */
  5,	/* slots */
  5,	/* solve */
  5,	/* sort! */
  5,	/* space */
  5,	/* spin= */
  5,	/* split */
  5,	/* spork */
  5,	/* srand */
  5,	/* stack */
  5,	/* stale */
  5,	/* start */
  5,	/* state */
  5,	/* stats */
  5,	/* store */
  5,	/* strip */
  5,	/* style */
  5,	/* subbw */
  5,	/* subfl */
  5,	/* subfq */
  5,	/* succ! */
  5,	/* super */
  5,	/* swapp */
  5,	/* sync= */
  5,	/* tabid */
  5,	/* term? */
  5,	/* thick */
  5,	/* throw */
  5,	/* time= */
  5,	/* times */
  5,	/* title */
  5,	/* toPos */
  5,	/* to_dB */
  5,	/* todel */
  5,	/* topOf */
  5,	/* top_h */
  5,	/* top_w */
  5,	/* top_x */
  5,	/* top_y */
  5,	/* total */
  5,	/* tr_s! */
  5,	/* tramp */
  5,	/* trans */
  5,	/* type= */
  5,	/* types */
  5,	/* umask */
  5,	/* union */
  5,	/* uniq! */
  5,	/* units */
  5,	/* updir */
  5,	/* value */
  5,	/* vfill */
  5,	/* vline */
  5,	/* voice */
  5,	/* vpack */
  5,	/* watch */
  5,	/* wheel */
  5,	/* width */
  5,	/* write */
  5,	/* xdiff */
  5,	/* xform */
  5,	/* xnorm */
  5,	/* xskip */
  5,	/* yaxis */
  5,	/* ydiff */
  5,	/* yield */
  5,	/* zero? */
  6,	/* $DEBUG */
  6,	/* $sched */
  6,	/* $stdin */
  6,	/* @aname */
  6,	/* @atime */
  6,	/* @boxes */
  6,	/* @cc_id */
  6,	/* @class */
  6,	/* @close */
  6,	/* @ctime */
  6,	/* @depth */
  6,	/* @extfm */
  6,	/* @fancy */
  6,	/* @fbase */
  6,	/* @field */
  6,	/* @files */
  6,	/* @flags */
  6,	/* @forms */
  6,	/* @frame */
  6,	/* @head1 */
  6,	/* @hedit */
  6,	/* @ident */
  6,	/* @image */
  6,	/* @input */
  6,	/* @lastw */
  6,	/* @layer */
  6,	/* @learn */
  6,	/* @lines */
  6,	/* @meter */
  6,	/* @micro */
  6,	/* @mixer */
  6,	/* @modal */
  6,	/* @names */
  6,	/* @panic */
  6,	/* @param */
  6,	/* @paste */
  6,	/* @phase */
  6,	/* @plist */
  6,	/* @ppath */
  6,	/* @props */
  6,	/* @reson */
  6,	/* @row_h */
  6,	/* @rwbox */
  6,	/* @scale */
  6,	/* @setup */
  6,	/* @slide */
  6,	/* @slots */
  6,	/* @stale */
  6,	/* @state */
  6,	/* @subbw */
  6,	/* @subfl */
  6,	/* @subfq */
  6,	/* @swapp */
  6,	/* @title */
  6,	/* @total */
  6,	/* @value */
  6,	/* @wheel */
  6,	/* @width */
  6,	/* @yaxis */
  6,	/* APPEND */
  6,	/* BINARY */
  6,	/* Button */
  6,	/* DIRECT */
  6,	/* EACCES */
  6,	/* EAGAIN */
  6,	/* EBADFD */
  6,	/* EBFONT */
  6,	/* ECHILD */
  6,	/* ECHRNG */
  6,	/* EDQUOT */
  6,	/* EEXIST */
  6,	/* EFAULT */
  6,	/* EFTYPE */
  6,	/* EILSEQ */
  6,	/* EINVAL */
  6,	/* EIPSEC */
  6,	/* EISDIR */
  6,	/* EISNAM */
  6,	/* EL2HLT */
  6,	/* EL3HLT */
  6,	/* EL3RST */
  6,	/* ELNRNG */
  6,	/* EMFILE */
  6,	/* EMLINK */
  6,	/* ENFILE */
  6,	/* ENOANO */
  6,	/* ENOCSI */
  6,	/* ENODEV */
  6,	/* ENOENT */
  6,	/* ENOKEY */
  6,	/* ENOLCK */
  6,	/* ENOMEM */
  6,	/* ENOMSG */
  6,	/* ENONET */
  6,	/* ENOPKG */
  6,	/* ENOSPC */
  6,	/* ENOSTR */
  6,	/* ENOSYS */
  6,	/* ENOTTY */
  6,	/* EPROTO */
  6,	/* ERANGE */
  6,	/* ESPIPE */
  6,	/* ESRMNT */
  6,	/* ESTALE */
  6,	/* EUSERS */
  6,	/* EXFULL */
  6,	/* Fixnum */
  6,	/* Indent */
  6,	/* IrNode */
  6,	/* Kernel */
  6,	/* Layout */
  6,	/* LfoVis */
  6,	/* Module */
  6,	/* NOCTTY */
  6,	/* Nanovg */
  6,	/* NumBox */
  6,	/* Object */
  6,	/* Parser */
  6,	/* ProgIR */
  6,	/* ProgVM */
  6,	/* RDONLY */
  6,	/* Random */
  6,	/* Record */
  6,	/* Regexp */
  6,	/* Remote */
  6,	/* SQUARE */
  6,	/* STDERR */
  6,	/* STDOUT */
  6,	/* Slider */
  6,	/* States */
  6,	/* Status */
  6,	/* String */
  6,	/* Symbol */
  6,	/* TLocal */
  6,	/* VGroup */
  6,	/* WRONLY */
  6,	/* Widget */
  6,	/* Window */
  6,	/* ZynKit */
  6,	/* ZynLFO */
  6,	/* ZynWip */
  6,	/* __id__ */
  6,	/* _chdir */
  6,	/* _getwd */
  6,	/* _mtime */
  6,	/* _popen */
  6,	/* action */
  6,	/* active */
  6,	/* addFav */
  6,	/* add_cb */
  6,	/* align= */
  6,	/* alive? */
  6,	/* amount */
  6,	/* analog */
  6,	/* append */
  6,	/* arc_to */
  6,	/* aspect */
  6,	/* avg_hz */
  6,	/* blocks */
  6,	/* border */
  6,	/* bottom */
  6,	/* bounds */
  6,	/* braces */
  6,	/* bright */
  6,	/* button */
  6,	/* cancel */
  6,	/* cc_num */
  6,	/* cctype */
  6,	/* center */
  6,	/* change */
  6,	/* chomp! */
  6,	/* chorus */
  6,	/* chroot */
  6,	/* circle */
  6,	/* clrFav */
  6,	/* coeff= */
  6,	/* colors */
  6,	/* concat */
  6,	/* cumsum */
  6,	/* curOff */
  6,	/* cursor */
  6,	/* damage */
  6,	/* delete */
  6,	/* depth= */
  6,	/* dest_x */
  6,	/* dest_y */
  6,	/* detect */
  6,	/* divide */
  6,	/* divmod */
  6,	/* doBank */
  6,	/* doLoad */
  6,	/* doSave */
  6,	/* doTest */
  6,	/* doType */
  6,	/* domain */
  6,	/* downto */
  6,	/* ec_key */
  6,	/* emode= */
  6,	/* empty? */
  6,	/* enable */
  6,	/* equal? */
  6,	/* escape */
  6,	/* events */
  6,	/* except */
  6,	/* exist? */
  6,	/* extend */
  6,	/* extent */
  6,	/* extern */
  6,	/* extmod */
  6,	/* extval */
  6,	/* fbase= */
  6,	/* fields */
  6,	/* fileno */
  6,	/* filter */
  6,	/* finish */
  6,	/* fixpad */
  6,	/* flavor */
  6,	/* footer */
  6,	/* for_fd */
  6,	/* format */
  6,	/* frames */
  6,	/* freeze */
  6,	/* gbl_cx */
  6,	/* gbl_cy */
  6,	/* genBox */
  6,	/* gensym */
  6,	/* getutc */
  6,	/* global */
  6,	/* gmtime */
  6,	/* handle */
  6,	/* header */
  6,	/* height */
  6,	/* hscale */
  6,	/* ifnone */
  6,	/* ignore */
  6,	/* image= */
  6,	/* indent */
  6,	/* index= */
  6,	/* inject */
  6,	/* input= */
  6,	/* insefx */
  6,	/* insert */
  6,	/* insset */
  6,	/* intern */
  6,	/* invert */
  6,	/* isatty */
  6,	/* itself */
  6,	/* kitnum */
  6,	/* label= */
  6,	/* labels */
  6,	/* lambda */
  6,	/* layer= */
  6,	/* layers */
  6,	/* layout */
  6,	/* lbrace */
  6,	/* length */
  6,	/* lines= */
  6,	/* loadIR */
  6,	/* loader */
  6,	/* longer */
  6,	/* lookup */
  6,	/* lsize= */
  6,	/* lstrip */
  6,	/* mapper */
  6,	/* match? */
  6,	/* maxkey */
  6,	/* maxlen */
  6,	/* member */
  6,	/* merge! */
  6,	/* method */
  6,	/* min_db */
  6,	/* minkey */
  6,	/* mktime */
  6,	/* modosc */
  6,	/* modsel */
  6,	/* names2 */
  6,	/* noise= */
  6,	/* normal */
  6,	/* noteOn */
  6,	/* nrows= */
  6,	/* numBox */
  6,	/* number */
  6,	/* nunits */
  6,	/* nvalue */
  6,	/* nvowel */
  6,	/* object */
  6,	/* octave */
  6,	/* offset */
  6,	/* oldOff */
  6,	/* old_aw */
  6,	/* oldctx */
  6,	/* on_dir */
  6,	/* oscill */
  6,	/* outbuf */
  6,	/* outer= */
  6,	/* owned? */
  6,	/* p_code */
  6,	/* p_draw */
  6,	/* p_poll */
  6,	/* p_swap */
  6,	/* padstr */
  6,	/* parent */
  6,	/* path_1 */
  6,	/* path_2 */
  6,	/* path_3 */
  6,	/* path_4 */
  6,	/* path_5 */
  6,	/* path_6 */
  6,	/* path_7 */
  6,	/* path_8 */
  6,	/* path_9 */
  6,	/* period */
  6,	/* phase= */
  6,	/* phaser */
  6,	/* points */
  6,	/* pos_id */
  6,	/* ppath= */
  6,	/* printf */
  6,	/* prtefx */
  6,	/* public */
  6,	/* pwrite */
  6,	/* pxpad= */
  6,	/* qml_ir */
  6,	/* radial */
  6,	/* radius */
  6,	/* rampup */
  6,	/* random */
  6,	/* rap2dB */
  6,	/* rassoc */
  6,	/* rbrace */
  6,	/* reader */
  6,	/* recalc */
  6,	/* record */
  6,	/* rect_h */
  6,	/* rect_w */
  6,	/* rect_x */
  6,	/* rect_y */
  6,	/* reduce */
  6,	/* regexp */
  6,	/* region */
  6,	/* rehash */
  6,	/* reject */
  6,	/* reload */
  6,	/* remote */
  6,	/* rename */
  6,	/* render */
  6,	/* resize */
  6,	/* resopt */
  6,	/* result */
  6,	/* resume */
  6,	/* reverb */
  6,	/* rewind */
  6,	/* rindex */
  6,	/* rotate */
  6,	/* row_id */
  6,	/* rstrip */
  6,	/* runner */
  6,	/* sample */
  6,	/* scale! */
  6,	/* scalex */
  6,	/* scroll */
  6,	/* search */
  6,	/* select */
  6,	/* setTab */
  6,	/* set_cc */
  6,	/* shift= */
  6,	/* skew_x */
  6,	/* skew_y */
  6,	/* slice! */
  6,	/* slider */
  6,	/* source */
  6,	/* space? */
  6,	/* spacer */
  6,	/* splice */
  6,	/* square */
  6,	/* stages */
  6,	/* stale= */
  6,	/* startt */
  6,	/* state= */
  6,	/* status */
  6,	/* stride */
  6,	/* string */
  6,	/* strip! */
  6,	/* stroke */
  6,	/* style= */
  6,	/* subamp */
  6,	/* subobj */
  6,	/* substr */
  6,	/* sysefx */
  6,	/* system */
  6,	/* tab_id */
  6,	/* tabbox */
  6,	/* title= */
  6,	/* titleH */
  6,	/* titleW */
  6,	/* to_int */
  6,	/* to_str */
  6,	/* to_sym */
  6,	/* toggle */
  6,	/* top_w2 */
  6,	/* top_x2 */
  6,	/* top_y2 */
  6,	/* transf */
  6,	/* ungetc */
  6,	/* units= */
  6,	/* unlink */
  6,	/* unpack */
  6,	/* upcase */
  6,	/* update */
  6,	/* value= */
  6,	/* value? */
  6,	/* values */
  6,	/* velrnd */
  6,	/* vis_eq */
  6,	/* visual */
  6,	/* vlimit */
  6,	/* voices */
  6,	/* vowels */
  6,	/* vphase */
  6,	/* vstack */
  6,	/* weight */
  6,	/* wheel= */
  6,	/* whence */
  6,	/* white1 */
  6,	/* white2 */
  6,	/* widget */
  6,	/* width= */
  6,	/* widths */
  6,	/* window */
  6,	/* wscale */
  6,	/* wtitle */
  6,	/* xform= */
  7,	/* $remote */
  7,	/* $stderr */
  7,	/* $stdout */
  7,	/* @button */
  7,	/* @cctype */
  7,	/* @center */
  7,	/* @chorus */
  7,	/* @chrcls */
  7,	/* @cur_id */
  7,	/* @damage */
  7,	/* @events */
  7,	/* @extmod */
  7,	/* @fields */
  7,	/* @filter */
  7,	/* @footer */
  7,	/* @header */
  7,	/* @ignore */
  7,	/* @indent */
  7,	/* @insset */
  7,	/* @labels */
  7,	/* @maxkey */
  7,	/* @member */
  7,	/* @minkey */
  7,	/* @modsel */
  7,	/* @numBox */
  7,	/* @offset */
  7,	/* @oscill */
  7,	/* @phaser */
  7,	/* @points */
  7,	/* @pos_id */
  7,	/* @radial */
  7,	/* @regexp */
  7,	/* @resopt */
  7,	/* @reverb */
  7,	/* @scroll */
  7,	/* @search */
  7,	/* @slider */
  7,	/* @source */
  7,	/* @stages */
  7,	/* @status */
  7,	/* @stream */
  7,	/* @string */
  7,	/* @subamp */
  7,	/* @subobj */
  7,	/* @titleW */
  7,	/* @toggle */
  7,	/* @vis_eq */
  7,	/* @vlimit */
  7,	/* @voices */
  7,	/* @widget */
  7,	/* @widths */
  7,	/* @window */
  7,	/* BankOdd */
  7,	/* Binding */
  7,	/* Complex */
  7,	/* Context */
  7,	/* DEFAULT */
  7,	/* EBADMSG */
  7,	/* EBADRPC */
  7,	/* EBADRQC */
  7,	/* EBADSLT */
  7,	/* EDEADLK */
  7,	/* EDOOFUS */
  7,	/* EDOTDOT */
  7,	/* EISCONN */
  7,	/* ELIBACC */
  7,	/* ELIBBAD */
  7,	/* ELIBMAX */
  7,	/* ELIBSCN */
  7,	/* ENAVAIL */
  7,	/* ENOATTR */
  7,	/* ENOBUFS */
  7,	/* ENODATA */
  7,	/* ENOEXEC */
  7,	/* ENOLINK */
  7,	/* ENOTBLK */
  7,	/* ENOTDIR */
  7,	/* ENOTNAM */
  7,	/* ENOTSUP */
  7,	/* EREMCHG */
  7,	/* EREMOTE */
  7,	/* ERFKILL */
  7,	/* ETXTBSY */
  7,	/* EUCLEAN */
  7,	/* EUNATCH */
  7,	/* Formant */
  7,	/* GradBox */
  7,	/* HSlider */
  7,	/* HotLoad */
  7,	/* IOError */
  7,	/* Integer */
  7,	/* LOCK_EX */
  7,	/* LOCK_NB */
  7,	/* LOCK_SH */
  7,	/* LOCK_UN */
  7,	/* LineCap */
  7,	/* NOATIME */
  7,	/* NOERROR */
  7,	/* NO_FLAG */
  7,	/* Numeric */
  7,	/* PathElm */
  7,	/* Pokemon */
  7,	/* Process */
  7,	/* Special */
  7,	/* TAssign */
  7,	/* TExtend */
  7,	/* TImport */
  7,	/* TMPFILE */
  7,	/* TestExt */
  7,	/* TextBox */
  7,	/* TextSel */
  7,	/* VSlider */
  7,	/* VuMeter */
  7,	/* WNOHANG */
  7,	/* Winding */
  7,	/* Yielder */
  7,	/* ZRunner */
  7,	/* ZynBank */
  7,	/* ZynEcho */
  7,	/* ZynLLFO */
  7,	/* ZynLogo */
  7,	/* ZynPart */
  7,	/* __lines */
  7,	/* abs_sum */
  7,	/* action= */
  7,	/* active= */
  7,	/* add_cat */
  7,	/* add_dir */
  7,	/* addbase */
  7,	/* amp_env */
  7,	/* amp_gen */
  7,	/* amp_lfo */
  7,	/* amplBox */
  7,	/* animate */
  7,	/* any_kit */
  7,	/* ary_max */
  7,	/* ary_sum */
  7,	/* asctime */
  7,	/* aspect2 */
  7,	/* au_plot */
  7,	/* authbox */
  7,	/* basemod */
  7,	/* blksize */
  7,	/* browser */
  7,	/* bsearch */
  7,	/* buttBox */
  7,	/* buttons */
  7,	/* casecmp */
  7,	/* cb_item */
  7,	/* cb_list */
  7,	/* channel */
  7,	/* closed? */
  7,	/* cls_def */
  7,	/* collect */
  7,	/* command */
  7,	/* commbox */
  7,	/* compact */
  7,	/* compile */
  7,	/* consume */
  7,	/* content */
  7,	/* context */
  7,	/* cpy_but */
  7,	/* curOff= */
  7,	/* cur_end */
  7,	/* current */
  7,	/* damaged */
  7,	/* default */
  7,	/* del_set */
  7,	/* delete! */
  7,	/* delete? */
  7,	/* depends */
  7,	/* destroy */
  7,	/* details */
  7,	/* dirname */
  7,	/* disable */
  7,	/* doMerge */
  7,	/* doSetup */
  7,	/* do_norm */
  7,	/* draw_id */
  7,	/* ebutton */
  7,	/* effects */
  7,	/* ellipse */
  7,	/* enable= */
  7,	/* entries */
  7,	/* envlope */
  7,	/* ev_prop */
  7,	/* ev_type */
  7,	/* exists? */
  7,	/* exited? */
  7,	/* explore */
  7,	/* extbase */
  7,	/* extent= */
  7,	/* extern= */
  7,	/* extname */
  7,	/* feather */
  7,	/* fields= */
  7,	/* fil_sel */
  7,	/* filtBox */
  7,	/* filter! */
  7,	/* filters */
  7,	/* finite? */
  7,	/* fixpad= */
  7,	/* flatten */
  7,	/* flavor= */
  7,	/* fnmatch */
  7,	/* folders */
  7,	/* for_num */
  7,	/* foreach */
  7,	/* formant */
  7,	/* format= */
  7,	/* freqBox */
  7,	/* friday? */
  7,	/* frozen? */
  7,	/* funcpar */
  7,	/* get_dep */
  7,	/* get_kit */
  7,	/* get_tab */
  7,	/* getaddr */
  7,	/* getbyte */
  7,	/* getport */
  7,	/* headBox */
  7,	/* header= */
  7,	/* height= */
  7,	/* heights */
  7,	/* in_test */
  7,	/* include */
  7,	/* indexes */
  7,	/* init_gl */
  7,	/* ins_sel */
  7,	/* inspect */
  7,	/* invalid */
  7,	/* inverse */
  7,	/* keep_if */
  7,	/* key_mod */
  7,	/* keyrest */
  7,	/* kitedit */
  7,	/* kitnum= */
  7,	/* labels= */
  7,	/* lambda? */
  7,	/* lfo_mod */
  7,	/* lfo_vis */
  7,	/* limited */
  7,	/* line_to */
  7,	/* lstrip! */
  7,	/* map_or! */
  7,	/* mapping */
  7,	/* matches */
  7,	/* maximum */
  7,	/* member? */
  7,	/* message */
  7,	/* methods */
  7,	/* miniBox */
  7,	/* minimum */
  7,	/* modules */
  7,	/* monday? */
  7,	/* move_to */
  7,	/* nactive */
  7,	/* namebox */
  7,	/* needles */
  7,	/* new_dsp */
  7,	/* new_key */
  7,	/* normal= */
  7,	/* noteOff */
  7,	/* numbBox */
  7,	/* number= */
  7,	/* nunits= */
  7,	/* nvowels */
  7,	/* nwidget */
  7,	/* obj_ids */
  7,	/* octave= */
  7,	/* offset= */
  7,	/* oldOff= */
  7,	/* old_dsp */
  7,	/* old_sub */
  7,	/* onMerge */
  7,	/* onSetup */
  7,	/* onWrite */
  7,	/* opt_bar */
  7,	/* options */
  7,	/* oscill= */
  7,	/* overlay */
  7,	/* p_total */
  7,	/* pad_but */
  7,	/* padding */
  7,	/* parent= */
  7,	/* partial */
  7,	/* path_10 */
  7,	/* pattern */
  7,	/* period= */
  7,	/* pointer */
  7,	/* points= */
  7,	/* pp_info */
  7,	/* prepend */
  7,	/* private */
  7,	/* produce */
  7,	/* program */
  7,	/* pst_but */
  7,	/* pstring */
  7,	/* punish2 */
  7,	/* q_value */
  7,	/* quad_to */
  7,	/* radius= */
  7,	/* range_x */
  7,	/* range_y */
  7,	/* refresh */
  7,	/* reject! */
  7,	/* release */
  7,	/* remote= */
  7,	/* replace */
  7,	/* require */
  7,	/* rescale */
  7,	/* restore */
  7,	/* result= */
  7,	/* reverse */
  7,	/* rewrite */
  7,	/* rightOf */
  7,	/* rotate! */
  7,	/* row1Box */
  7,	/* row2Box */
  7,	/* row3Box */
  7,	/* row_id= */
  7,	/* rstrip! */
  7,	/* runTest */
  7,	/* running */
  7,	/* sGlobal */
  7,	/* scissor */
  7,	/* search_ */
  7,	/* select! */
  7,	/* selfBox */
  7,	/* sep_len */
  7,	/* setBank */
  7,	/* setType */
  7,	/* set_amp */
  7,	/* set_max */
  7,	/* set_min */
  7,	/* set_tab */
  7,	/* setbyte */
  7,	/* setgid? */
  7,	/* setuid? */
  7,	/* shorter */
  7,	/* shuffle */
  7,	/* skew_x! */
  7,	/* skew_y! */
  7,	/* slide_q */
  7,	/* slot_id */
  7,	/* socket? */
  7,	/* spacer= */
  7,	/* sprintf */
  7,	/* squeeze */
  7,	/* stages= */
  7,	/* sticky? */
  7,	/* stopsig */
  7,	/* subset? */
  7,	/* subtabs */
  7,	/* subview */
  7,	/* sunday? */
  7,	/* swapBox */
  7,	/* symlink */
  7,	/* sysopen */
  7,	/* sysread */
  7,	/* sysseek */
  7,	/* tabbox= */
  7,	/* tabpack */
  7,	/* termsig */
  7,	/* textBox */
  7,	/* textsel */
  7,	/* this_id */
  7,	/* titleW= */
  7,	/* to_enum */
  7,	/* to_path */
  7,	/* to_proc */
  7,	/* tooltip */
  7,	/* topSize */
  7,	/* uheight */
  7,	/* ui_path */
  7,	/* unbound */
  7,	/* unknown */
  7,	/* unlearn */
  7,	/* unpack1 */
  7,	/* unshift */
  7,	/* upcase! */
  7,	/* upcase= */
  7,	/* use_mtx */
  7,	/* velrnd= */
  7,	/* vis_sub */
  7,	/* visharm */
  7,	/* visual= */
  7,	/* vow_num */
  7,	/* vowels= */
  7,	/* vumeter */
  7,	/* waiting */
  7,	/* waitpid */
  7,	/* warning */
  7,	/* weights */
  7,	/* window= */
  7,	/* xpoints */
  7,	/* ypoints */
  8,	/* $anon_id */
  8,	/* @activew */
  8,	/* @addbase */
  8,	/* @amp_env */
  8,	/* @amp_gen */
  8,	/* @amp_lfo */
  8,	/* @au_plot */
  8,	/* @authbox */
  8,	/* @basemod */
  8,	/* @browser */
  8,	/* @buttons */
  8,	/* @cb_list */
  8,	/* @clicked */
  8,	/* @commbox */
  8,	/* @content */
  8,	/* @context */
  8,	/* @cpy_but */
  8,	/* @depends */
  8,	/* @details */
  8,	/* @ebutton */
  8,	/* @explore */
  8,	/* @fil_sel */
  8,	/* @folders */
  8,	/* @for_num */
  8,	/* @funcpar */
  8,	/* @hotload */
  8,	/* @ins_sel */
  8,	/* @kitedit */
  8,	/* @lfo_mod */
  8,	/* @lfo_vis */
  8,	/* @matches */
  8,	/* @namebox */
  8,	/* @onWrite */
  8,	/* @options */
  8,	/* @pad_but */
  8,	/* @pp_info */
  8,	/* @pst_but */
  8,	/* @slide_q */
  8,	/* @subtabs */
  8,	/* @textBox */
  8,	/* @textsel */
  8,	/* @ui_path */
  8,	/* @used_id */
  8,	/* @vis_sub */
  8,	/* @visharm */
  8,	/* @vow_num */
  8,	/* @vumeter */
  8,	/* ArrowBox */
  8,	/* BUF_SIZE */
  8,	/* BankEven */
  8,	/* BusyLoop */
  8,	/* CachedIR */
  8,	/* ClearBox */
  8,	/* ColorBox */
  8,	/* ColorSel */
  8,	/* DataView */
  8,	/* DrawRect */
  8,	/* DropDown */
  8,	/* DummyBox */
  8,	/* EALREADY */
  8,	/* EL2NSYNC */
  8,	/* ELIBEXEC */
  8,	/* EMSGSIZE */
  8,	/* ENETDOWN */
  8,	/* ENOTCONN */
  8,	/* ENOTSOCK */
  8,	/* ENOTUNIQ */
  8,	/* EOFError */
  8,	/* EPROCLIM */
  8,	/* ERESTART */
  8,	/* ESTRPIPE */
  8,	/* EXTENDED */
  8,	/* Envelope */
  8,	/* FileTest */
  8,	/* GridLine */
  8,	/* INFINITY */
  8,	/* KeyBlack */
  8,	/* KeyError */
  8,	/* Keyboard */
  8,	/* Literals */
  8,	/* MAX_AUTO */
  8,	/* MAX_SLOT */
  8,	/* MainMenu */
  8,	/* ModWheel */
  8,	/* NOFOLLOW */
  8,	/* NONBLOCK */
  8,	/* NVGError */
  8,	/* NilClass */
  8,	/* NumEntry */
  8,	/* Property */
  8,	/* Rational */
  8,	/* SEEK_CUR */
  8,	/* SEEK_END */
  8,	/* SEEK_SET */
  8,	/* Selector */
  8,	/* Solidity */
  8,	/* TabGroup */
  8,	/* TestBase */
  8,	/* TestCase */
  8,	/* TestRows */
  8,	/* TestSwap */
  8,	/* TextEdit */
  8,	/* TextLine */
  8,	/* TitleBar */
  8,	/* Valuator */
  8,	/* WaveForm */
  8,	/* WaveView */
  8,	/* ZynAbout */
  8,	/* ZynMixer */
  8,	/* ZynOscil */
  8,	/* ZynScale */
  8,	/* __ary_eq */
  8,	/* __delete */
  8,	/* __send__ */
  8,	/* __svalue */
  8,	/* __to_int */
  8,	/* _bufread */
  8,	/* _gethome */
  8,	/* _inspect */
  8,	/* accessor */
  8,	/* add_attr */
  8,	/* add_char */
  8,	/* add_favs */
  8,	/* add_func */
  8,	/* alienwah */
  8,	/* allocate */
  8,	/* amplEBox */
  8,	/* amplLBox */
  8,	/* ampl_env */
  8,	/* ampl_lfo */
  8,	/* applying */
  8,	/* arg_list */
  8,	/* automate */
  8,	/* bank_tag */
  8,	/* bar_size */
  8,	/* base_osc */
  8,	/* basename */
  8,	/* between? */
  8,	/* bg_color */
  8,	/* black_bb */
  8,	/* bot_left */
  8,	/* button_c */
  8,	/* button_p */
  8,	/* bytesize */
  8,	/* callback */
  8,	/* captures */
  8,	/* casecmp? */
  8,	/* centered */
  8,	/* chardev? */
  8,	/* children */
  8,	/* circ_mag */
  8,	/* classify */
  8,	/* collect! */
  8,	/* compact! */
  8,	/* contains */
  8,	/* content= */
  8,	/* contents */
  8,	/* copyable */
  8,	/* cur_time */
  8,	/* dark_off */
  8,	/* database */
  8,	/* default= */
  8,	/* del_char */
  8,	/* del_list */
  8,	/* depends= */
  8,	/* deselect */
  8,	/* diameter */
  8,	/* dir_name */
  8,	/* dnd_drop */
  8,	/* dnd_pick */
  8,	/* doRescan */
  8,	/* doSearch */
  8,	/* doUpdate */
  8,	/* doupcase */
  8,	/* downcase */
  8,	/* draw_alt */
  8,	/* draw_new */
  8,	/* each_key */
  8,	/* editable */
  8,	/* enum_for */
  8,	/* env_plot */
  8,	/* envelope */
  8,	/* eval_str */
  8,	/* extended */
  8,	/* feather= */
  8,	/* file_sel */
  8,	/* filename */
  8,	/* filetype */
  8,	/* filtEBox */
  8,	/* filtLBox */
  8,	/* filt_env */
  8,	/* filt_lfo */
  8,	/* filter_q */
  8,	/* find_all */
  8,	/* fixedpad */
  8,	/* flatten! */
  8,	/* fnmatch? */
  8,	/* for_num= */
  8,	/* formants */
  8,	/* freqEBox */
  8,	/* freqLBox */
  8,	/* freq_env */
  8,	/* freq_lfo */
  8,	/* freq_var */
  8,	/* full_dir */
  8,	/* get_mode */
  8,	/* get_node */
  8,	/* get_note */
  8,	/* get_part */
  8,	/* getlocal */
  8,	/* gl_clear */
  8,	/* global_x */
  8,	/* global_y */
  8,	/* harmonic */
  8,	/* has_key? */
  8,	/* haystack */
  8,	/* home_dir */
  8,	/* hotload= */
  8,	/* include? */
  8,	/* included */
  8,	/* info_box */
  8,	/* instance */
  8,	/* inverse! */
  8,	/* keyPress */
  8,	/* keyboard */
  8,	/* kind_of? */
  8,	/* kit_item */
  8,	/* kittable */
  8,	/* labelBox */
  8,	/* layer_id */
  8,	/* lfo_plot */
  8,	/* line_cap */
  8,	/* linear_x */
  8,	/* linear_y */
  8,	/* linspace */
  8,	/* literal? */
  8,	/* load_qml */
  8,	/* logo_bot */
  8,	/* logo_top */
  8,	/* logspace */
  8,	/* max_text */
  8,	/* maximum= */
  8,	/* med_fill */
  8,	/* metadata */
  8,	/* midi_ref */
  8,	/* min_dist */
  8,	/* minimize */
  8,	/* minimum= */
  8,	/* mod_wave */
  8,	/* modified */
  8,	/* modulate */
  8,	/* multiply */
  8,	/* new_args */
  8,	/* new_diff */
  8,	/* next_ctr */
  8,	/* next_sel */
  8,	/* next_sep */
  8,	/* nformant */
  8,	/* no_black */
  8,	/* norm_0_1 */
  8,	/* norm_sum */
  8,	/* numentry */
  8,	/* oldValue */
  8,	/* old_gsub */
  8,	/* old_time */
  8,	/* onScroll */
  8,	/* on_color */
  8,	/* on_write */
  8,	/* opt_plot */
  8,	/* opt_vals */
  8,	/* options= */
  8,	/* osc_wave */
  8,	/* overtone */
  8,	/* pad_norm */
  8,	/* path_ref */
  8,	/* path_str */
  8,	/* pattern= */
  8,	/* patterns */
  8,	/* priority */
  8,	/* prop_add */
  8,	/* property */
  8,	/* provided */
  8,	/* q_value= */
  8,	/* qml_data */
  8,	/* rampdown */
  8,	/* rdepends */
  8,	/* readbyte */
  8,	/* readchar */
  8,	/* readline */
  8,	/* readlink */
  8,	/* realpath */
  8,	/* renderer */
  8,	/* response */
  8,	/* reverse! */
  8,	/* run_view */
  8,	/* selected */
  8,	/* selector */
  8,	/* self_len */
  8,	/* setValue */
  8,	/* set_data */
  8,	/* set_dirs */
  8,	/* set_favs */
  8,	/* set_free */
  8,	/* set_freq */
  8,	/* set_gain */
  8,	/* set_mode */
  8,	/* set_view */
  8,	/* settings */
  8,	/* shuffle! */
  8,	/* slide_q= */
  8,	/* slot_id= */
  8,	/* solve_ir */
  8,	/* source_x */
  8,	/* source_y */
  8,	/* special? */
  8,	/* squeeze! */
  8,	/* statevar */
  8,	/* stopped? */
  8,	/* str_each */
  8,	/* subsynth */
  8,	/* subtract */
  8,	/* success? */
  8,	/* swapcase */
  8,	/* switched */
  8,	/* symlink? */
  8,	/* syswrite */
  8,	/* teardown */
  8,	/* testRoot */
  8,	/* text_box */
  8,	/* textedit */
  8,	/* titleBox */
  8,	/* tooltip= */
  8,	/* topSize= */
  8,	/* total_ir */
  8,	/* transfer */
  8,	/* triangle */
  8,	/* truncate */
  8,	/* tuesday? */
  8,	/* type_var */
  8,	/* ui_path= */
  8,	/* valuator */
  8,	/* valueRef */
  8,	/* vce_list */
  8,	/* velocity */
  8,	/* vertical */
  8,	/* vis_sub= */
  8,	/* visreson */
  8,	/* vow_num= */
  8,	/* waitpid2 */
  8,	/* weights= */
  8,	/* whenTime */
  8,	/* white_bb */
  8,	/* wintitle */
  8,	/* xpoints= */
  8,	/* ypoints= */
  8,	/* zipToPos */
  9,	/* $test_err */
  9,	/* @active_y */
  9,	/* @alloc_id */
  9,	/* @ampl_env */
  9,	/* @ampl_lfo */
  9,	/* @animated */
  9,	/* @arg_list */
  9,	/* @backdrop */
  9,	/* @bank_tag */
  9,	/* @base_osc */
  9,	/* @button_c */
  9,	/* @button_p */
  9,	/* @callback */
  9,	/* @cursor_x */
  9,	/* @draw_alt */
  9,	/* @draw_seq */
  9,	/* @filt_env */
  9,	/* @filt_lfo */
  9,	/* @frame_id */
  9,	/* @freq_env */
  9,	/* @freq_lfo */
  9,	/* @info_box */
  9,	/* @instance */
  9,	/* @keyboard */
  9,	/* @kit_item */
  9,	/* @kittable */
  9,	/* @learning */
  9,	/* @minimize */
  9,	/* @mod_wave */
  9,	/* @numentry */
  9,	/* @osc_wave */
  9,	/* @overtone */
  9,	/* @rdepends */
  9,	/* @run_view */
  9,	/* @selector */
  9,	/* @settings */
  9,	/* @stop_exc */
  9,	/* @subsynth */
  9,	/* @textedit */
  9,	/* @valuator */
  9,	/* @vce_list */
  9,	/* @view_pos */
  9,	/* @visreson */
  9,	/* @wintitle */
  9,	/* ALIGN_TOP */
  9,	/* ANTIALIAS */
  9,	/* BoundAttr */
  9,	/* CachedDep */
  9,	/* Constants */
  9,	/* ECANCELED */
  9,	/* EDEADLOCK */
  9,	/* EHOSTDOWN */
  9,	/* EMULTIHOP */
  9,	/* ENEEDAUTH */
  9,	/* ENETRESET */
  9,	/* ENOMEDIUM */
  9,	/* ENOTEMPTY */
  9,	/* EOVERFLOW */
  9,	/* EREMOTEIO */
  9,	/* ESHUTDOWN */
  9,	/* ETIMEDOUT */
  9,	/* Exception */
  9,	/* Generator */
  9,	/* KeyEnable */
  9,	/* KitButton */
  9,	/* KnobGrad1 */
  9,	/* KnobGrad2 */
  9,	/* LogWidget */
  9,	/* MULTILINE */
  9,	/* MatchData */
  9,	/* Modifiers */
  9,	/* NameError */
  9,	/* ParModule */
  9,	/* PowButton */
  9,	/* Rectangle */
  9,	/* SEPARATOR */
  9,	/* ScrollBar */
  9,	/* SearchBox */
  9,	/* SelButton */
  9,	/* SelColumn */
  9,	/* Swappable */
  9,	/* TabButton */
  9,	/* TextColor */
  9,	/* TextField */
  9,	/* TotalObjs */
  9,	/* Transform */
  9,	/* TrueClass */
  9,	/* TypeError */
  9,	/* VisFilter */
  9,	/* VisualDim */
  9,	/* WUNTRACED */
  9,	/* ZynAmpEnv */
  9,	/* ZynAmpMod */
  9,	/* ZynCenter */
  9,	/* ZynChorus */
  9,	/* ZynFooter */
  9,	/* ZynHeader */
  9,	/* ZynKitRow */
  9,	/* ZynPadAmp */
  9,	/* ZynPhaser */
  9,	/* ZynReverb */
  9,	/* ZynSubAmp */
  9,	/* ZynTuning */
  9,	/* ZynWipTwo */
  9,	/* __ary_cmp */
  9,	/* __outer__ */
  9,	/* _gc_root_ */
  9,	/* _read_buf */
  9,	/* _readchar */
  9,	/* _sys_fail */
  9,	/* _sysclose */
  9,	/* add_child */
  9,	/* add_point */
  9,	/* add_seq_c */
  9,	/* add_synth */
  9,	/* addglobal */
  9,	/* amplitude */
  9,	/* ancestors */
  9,	/* anon_test */
  9,	/* assert_eq */
  9,	/* backtrace */
  9,	/* bandwidth */
  9,	/* bank_name */
  9,	/* bank_type */
  9,	/* bar_color */
  9,	/* bar_size= */
  9,	/* base_harm */
  9,	/* base_osc= */
  9,	/* base_path */
  9,	/* best_diff */
  9,	/* best_dist */
  9,	/* bezier_to */
  9,	/* birthtime */
  9,	/* black_pos */
  9,	/* blockdev? */
  9,	/* bot_right */
  9,	/* build_fbo */
  9,	/* button_c= */
  9,	/* button_p= */
  9,	/* byteslice */
  9,	/* callback= */
  9,	/* casefold? */
  9,	/* centered= */
  9,	/* changeMax */
  9,	/* changeMin */
  9,	/* children= */
  9,	/* circ_link */
  9,	/* circ_text */
  9,	/* clear_sel */
  9,	/* code_attr */
  9,	/* color_rgb */
  9,	/* const_get */
  9,	/* const_set */
  9,	/* container */
  9,	/* copyable= */
  9,	/* coredump? */
  9,	/* cur_start */
  9,	/* data_view */
  9,	/* del_point */
  9,	/* delay_var */
  9,	/* delete_at */
  9,	/* delete_if */
  9,	/* demo_mode */
  9,	/* depth_var */
  9,	/* dev_major */
  9,	/* dev_minor */
  9,	/* dim_color */
  9,	/* disjoint? */
  9,	/* doRefresh */
  9,	/* doUpdate= */
  9,	/* doupcase= */
  9,	/* downcase! */
  9,	/* dragScale */
  9,	/* drag_prev */
  9,	/* drag_type */
  9,	/* draw_grid */
  9,	/* draw_path */
  9,	/* draw_play */
  9,	/* draw_stop */
  9,	/* draw_text */
  9,	/* each_byte */
  9,	/* each_char */
  9,	/* each_line */
  9,	/* each_pair */
  9,	/* editable= */
  9,	/* ego_death */
  9,	/* end_frame */
  9,	/* end_with? */
  9,	/* enveditor */
  9,	/* exception */
  9,	/* exclusive */
  9,	/* fail_test */
  9,	/* feedvalue */
  9,	/* file_name */
  9,	/* find_font */
  9,	/* fine_mode */
  9,	/* fixed_pad */
  9,	/* fixedpad= */
  9,	/* flat_line */
  9,	/* font_blur */
  9,	/* font_face */
  9,	/* font_size */
  9,	/* footerbox */
  9,	/* frequency */
  9,	/* full_harm */
  9,	/* getStride */
  9,	/* get_image */
  9,	/* get_units */
  9,	/* get_voice */
  9,	/* get_width */
  9,	/* grpowned? */
  9,	/* harmonics */
  9,	/* infinite? */
  9,	/* inherited */
  9,	/* init_font */
  9,	/* init_pugl */
  9,	/* initalize */
  9,	/* intersect */
  9,	/* iterator? */
  9,	/* kittable= */
  9,	/* knobPhase */
  9,	/* knobWidth */
  9,	/* knob_dash */
  9,	/* known_cls */
  9,	/* labelsBox */
  9,	/* learn_ref */
  9,	/* learning= */
  9,	/* left_text */
  9,	/* lerp_rgba */
  9,	/* line_cap= */
  9,	/* line_join */
  9,	/* localtime */
  9,	/* long_mode */
  9,	/* magnitude */
  9,	/* max_text= */
  9,	/* midi_chan */
  9,	/* minheight */
  9,	/* mk_points */
  9,	/* mouseMove */
  9,	/* multiply! */
  9,	/* name_push */
  9,	/* new_label */
  9,	/* new_value */
  9,	/* new_width */
  9,	/* next_list */
  9,	/* next_sect */
  9,	/* nformants */
  9,	/* normalize */
  9,	/* numButton */
  9,	/* numerator */
  9,	/* object_id */
  9,	/* off_color */
  9,	/* old_index */
  9,	/* old_slice */
  9,	/* old_split */
  9,	/* old_valid */
  9,	/* onSpecial */
  9,	/* opt_vals= */
  9,	/* out_value */
  9,	/* overtone= */
  9,	/* pack_misc */
  9,	/* padButton */
  9,	/* pad_synth */
  9,	/* padfactor */
  9,	/* padglobal */
  9,	/* parmodule */
  9,	/* partition */
  9,	/* pass_test */
  9,	/* path_join */
  9,	/* path_simp */
  9,	/* phase_mod */
  9,	/* phase_osc */
  9,	/* phase_var */
  9,	/* pos_vowel */
  9,	/* pre_match */
  9,	/* prepended */
  9,	/* prev_note */
  9,	/* priority= */
  9,	/* protected */
  9,	/* push_char */
  9,	/* rdepends= */
  9,	/* read_list */
  9,	/* readable? */
  9,	/* readlines */
  9,	/* renderer= */
  9,	/* resonance */
  9,	/* root_node */
  9,	/* runUpdate */
  9,	/* run_view= */
  9,	/* satisfied */
  9,	/* saturday? */
  9,	/* sel_color */
  9,	/* select_id */
  9,	/* selected= */
  9,	/* send_name */
  9,	/* separator */
  9,	/* set_files */
  9,	/* set_level */
  9,	/* set_modal */
  9,	/* set_scale */
  9,	/* set_value */
  9,	/* set_voice */
  9,	/* set_watch */
  9,	/* shortcuts */
  9,	/* signaled? */
  9,	/* slide_amp */
  9,	/* slidetype */
  9,	/* slot_name */
  9,	/* slot_path */
  9,	/* subButton */
  9,	/* sub_synth */
  9,	/* subglobal */
  9,	/* subsynth= */
  9,	/* superargs */
  9,	/* superset? */
  9,	/* swapcase! */
  9,	/* swappable */
  9,	/* testSetup */
  9,	/* textColor */
  9,	/* textScale */
  9,	/* thursday? */
  9,	/* title_bar */
  9,	/* to_delete */
  9,	/* totalHarm */
  9,	/* total_len */
  9,	/* transform */
  9,	/* translate */
  9,	/* transpose */
  9,	/* tryScroll */
  9,	/* ungetbyte */
  9,	/* unhandled */
  9,	/* updatePos */
  9,	/* validated */
  9,	/* valueRef= */
  9,	/* value_lab */
  9,	/* value_ref */
  9,	/* value_sel */
  9,	/* values_at */
  9,	/* vce_list= */
  9,	/* velocity= */
  9,	/* vertical= */
  9,	/* vowel_num */
  9,	/* wantedMax */
  9,	/* wantedMin */
  9,	/* wave_view */
  9,	/* wheelwell */
  9,	/* whenClick */
  9,	/* whenEnter */
  9,	/* whenTime= */
  9,	/* whenValue */
  9,	/* whiteKeys */
  9,	/* writable? */
  9,	/* zero_line */
  9,	/* zynCenter */
  10,	/* $ruby_mode */
  10,	/* @active_ev */
  10,	/* @addglobal */
  10,	/* @bank_name */
  10,	/* @bank_type */
  10,	/* @base_harm */
  10,	/* @container */
  10,	/* @data_view */
  10,	/* @enveditor */
  10,	/* @feedvalue */
  10,	/* @fine_mode */
  10,	/* @footerbox */
  10,	/* @full_harm */
  10,	/* @global_ir */
  10,	/* @knobPhase */
  10,	/* @knobWidth */
  10,	/* @lookahead */
  10,	/* @meta_prop */
  10,	/* @midi_chan */
  10,	/* @numerator */
  10,	/* @padButton */
  10,	/* @padglobal */
  10,	/* @phase_mod */
  10,	/* @phase_osc */
  10,	/* @pos_vowel */
  10,	/* @quit_time */
  10,	/* @read_list */
  10,	/* @send_name */
  10,	/* @separator */
  10,	/* @shortcuts */
  10,	/* @slide_amp */
  10,	/* @slot_name */
  10,	/* @subButton */
  10,	/* @subglobal */
  10,	/* @swappable */
  10,	/* @title_bar */
  10,	/* @total_len */
  10,	/* @wave_view */
  10,	/* @wheelwell */
  10,	/* ALIGN_LEFT */
  10,	/* AbortFrame */
  10,	/* Comparable */
  10,	/* CopyButton */
  10,	/* DemoLayers */
  10,	/* EADDRINUSE */
  10,	/* ECONNRESET */
  10,	/* EOPNOTSUPP */
  10,	/* EOWNERDEAD */
  10,	/* EPROTOTYPE */
  10,	/* EditRegion */
  10,	/* EntryMatch */
  10,	/* Enumerable */
  10,	/* Enumerator */
  10,	/* FakeWindow */
  10,	/* FalseClass */
  10,	/* FiberError */
  10,	/* FileButton */
  10,	/* FlowLayout */
  10,	/* FontHandle */
  10,	/* Group_nocp */
  10,	/* IGNORECASE */
  10,	/* ImageFlags */
  10,	/* IndentTest */
  10,	/* IndexError */
  10,	/* InnerGrad1 */
  10,	/* InnerGrad2 */
  10,	/* KitButtons */
  10,	/* MacroState */
  10,	/* MainWindow */
  10,	/* OverlayBox */
  10,	/* PlotLabelY */
  10,	/* QmlIRCache */
  10,	/* RadialMenu */
  10,	/* RangeError */
  10,	/* TParseType */
  10,	/* TestLfoVis */
  10,	/* TextScroll */
  10,	/* UiEventSeq */
  10,	/* VisFormant */
  10,	/* VisualLine */
  10,	/* VolumeKnob */
  10,	/* ZynEffects */
  10,	/* ZynEnvEdit */
  10,	/* ZynFormant */
  10,	/* ZynFreqEnv */
  10,	/* ZynFreqMod */
  10,	/* ZynPadFreq */
  10,	/* ZynSidebar */
  10,	/* ZynSubFreq */
  10,	/* __case_eqq */
  10,	/* __num_to_a */
  10,	/* active_ref */
  10,	/* add_method */
  10,	/* add_parent */
  10,	/* allow_dots */
  10,	/* assert_nil */
  10,	/* automation */
  10,	/* background */
  10,	/* bank_type= */
  10,	/* base_title */
  10,	/* begin_path */
  10,	/* cache_file */
  10,	/* capitalize */
  10,	/* change_cat */
  10,	/* change_vis */
  10,	/* check_args */
  10,	/* class_eval */
  10,	/* class_name */
  10,	/* close_path */
  10,	/* codepoints */
  10,	/* contentBox */
  10,	/* correct_ir */
  10,	/* deg_to_rad */
  10,	/* delay_time */
  10,	/* difference */
  10,	/* dimensions */
  10,	/* directory? */
  10,	/* distortion */
  10,	/* doFastLoad */
  10,	/* doRefresh= */
  10,	/* doSavePart */
  10,	/* dragScale= */
  10,	/* drag_prev= */
  10,	/* drag_type= */
  10,	/* draw_arrow */
  10,	/* draw_black */
  10,	/* draw_layer */
  10,	/* draw_pause */
  10,	/* draw_white */
  10,	/* dump_plist */
  10,	/* each_index */
  10,	/* each_value */
  10,	/* env_marker */
  10,	/* eval_value */
  10,	/* everything */
  10,	/* exitstatus */
  10,	/* extensions */
  10,	/* externalDb */
  10,	/* fd_or_path */
  10,	/* file_value */
  10,	/* filebutton */
  10,	/* fill_color */
  10,	/* fill_paint */
  10,	/* filter_amp */
  10,	/* filtertype */
  10,	/* findWidget */
  10,	/* find_index */
  10,	/* find_slice */
  10,	/* fixed_long */
  10,	/* font_blur= */
  10,	/* font_error */
  10,	/* font_face= */
  10,	/* font_size= */
  10,	/* full_title */
  10,	/* gain_value */
  10,	/* given_args */
  10,	/* gl_scissor */
  10,	/* global_pad */
  10,	/* has_value? */
  10,	/* horizontal */
  10,	/* identifier */
  10,	/* image_size */
  10,	/* init_class */
  10,	/* initialize */
  10,	/* innerspace */
  10,	/* internalDb */
  10,	/* intersect? */
  10,	/* invalid_ir */
  10,	/* invalidate */
  10,	/* key_widget */
  10,	/* kitbuttons */
  10,	/* knobOffset */
  10,	/* last_match */
  10,	/* layoutOpts */
  10,	/* learn_midi */
  10,	/* learn_mode */
  10,	/* leftButton */
  10,	/* light_fill */
  10,	/* line_join= */
  10,	/* load_scale */
  10,	/* main_width */
  10,	/* make_child */
  10,	/* make_curry */
  10,	/* match_data */
  10,	/* maxeffects */
  10,	/* menuIndent */
  10,	/* midi_learn */
  10,	/* mousePress */
  10,	/* move_sense */
  10,	/* needsRegen */
  10,	/* new_height */
  10,	/* next_coeff */
  10,	/* next_frame */
  10,	/* nharmonics */
  10,	/* noise_mode */
  10,	/* normal_int */
  10,	/* note_names */
  10,	/* numButtonn */
  10,	/* numButtont */
  10,	/* num_fields */
  10,	/* octave_num */
  10,	/* old_slice! */
  10,	/* other_hash */
  10,	/* overlaybox */
  10,	/* padprofile */
  10,	/* parameters */
  10,	/* path_split */
  10,	/* path_token */
  10,	/* post_match */
  10,	/* prev_note= */
  10,	/* properties */
  10,	/* qwerty_low */
  10,	/* rad_to_deg */
  10,	/* rdev_major */
  10,	/* rdev_minor */
  10,	/* recur_list */
  10,	/* redraw_fbo */
  10,	/* redraw_img */
  10,	/* refreshing */
  10,	/* reset_mode */
  10,	/* resolution */
  10,	/* rpartition */
  10,	/* run_script */
  10,	/* screenshot */
  10,	/* sel_column */
  10,	/* sel_folder */
  10,	/* select_id= */
  10,	/* self_arity */
  10,	/* selminibox */
  10,	/* separator= */
  10,	/* setDataVis */
  10,	/* set_active */
  10,	/* set_enable */
  10,	/* set_filter */
  10,	/* set_offset */
  10,	/* set_scroll */
  10,	/* short_name */
  10,	/* slide_amp= */
  10,	/* slide_freq */
  10,	/* slidetype= */
  10,	/* splitColor */
  10,	/* step_ratio */
  10,	/* stream_out */
  10,	/* sub_global */
  10,	/* subsubview */
  10,	/* superclass */
  10,	/* tail_empty */
  10,	/* test_paths */
  10,	/* textColor= */
  10,	/* textHeight */
  10,	/* textScale= */
  10,	/* text_align */
  10,	/* text_color */
  10,	/* text_field */
  10,	/* textrender */
  10,	/* tick_sched */
  10,	/* toggleable */
  10,	/* totalHarm= */
  10,	/* total_objs */
  10,	/* translate! */
  10,	/* un_rescale */
  10,	/* unix_start */
  10,	/* updateType */
  10,	/* update_pos */
  10,	/* user_value */
  10,	/* value_lab= */
  10,	/* value_sel= */
  10,	/* vis_filter */
  10,	/* voice_item */
  10,	/* vowel_num= */
  10,	/* wednesday? */
  10,	/* whenCancel */
  10,	/* whenClick= */
  10,	/* whenValue= */
  10,	/* white_keys */
  10,	/* whitespace */
  10,	/* with_index */
  10,	/* workaround */
  10,	/* yield_self */
  11,	/* $test_quiet */
  11,	/* $total_objs */
  11,	/* @anonymous3 */
  11,	/* @automation */
  11,	/* @base_title */
  11,	/* @cache_load */
  11,	/* @click_time */
  11,	/* @cursor_col */
  11,	/* @cursor_row */
  11,	/* @draw_layer */
  11,	/* @event_list */
  11,	/* @extensions */
  11,	/* @externalDb */
  11,	/* @filebutton */
  11,	/* @full_title */
  11,	/* @identifier */
  11,	/* @internalDb */
  11,	/* @kitbuttons */
  11,	/* @knobOffset */
  11,	/* @last_match */
  11,	/* @learn_mode */
  11,	/* @log_widget */
  11,	/* @menuIndent */
  11,	/* @overlaybox */
  11,	/* @padprofile */
  11,	/* @properties */
  11,	/* @read_count */
  11,	/* @redraw_fbo */
  11,	/* @redraw_img */
  11,	/* @setup_done */
  11,	/* @slide_freq */
  11,	/* @stream_len */
  11,	/* @stream_pos */
  11,	/* @text_field */
  11,	/* @textrender */
  11,	/* @true_label */
  11,	/* @value_prop */
  11,	/* @vis_filter */
  11,	/* @voice_item */
  11,	/* @word_buf_w */
  11,	/* ALIGN_RIGHT */
  11,	/* ApplyButton */
  11,	/* Automations */
  11,	/* BasicObject */
  11,	/* ButtonGrad1 */
  11,	/* ButtonGrad2 */
  11,	/* CachedCtime */
  11,	/* ColorButton */
  11,	/* ColorScheme */
  11,	/* CreateFlags */
  11,	/* DataViewAlt */
  11,	/* DomainError */
  11,	/* DrawSeqNode */
  11,	/* EINPROGRESS */
  11,	/* EKEYEXPIRED */
  11,	/* EKEYREVOKED */
  11,	/* EMEDIUMTYPE */
  11,	/* ENETUNREACH */
  11,	/* ENOPROTOOPT */
  11,	/* EWOULDBLOCK */
  11,	/* Environment */
  11,	/* Errno2class */
  11,	/* FNM_SYSCASE */
  11,	/* FancyButton */
  11,	/* FileBrowser */
  11,	/* FrozenError */
  11,	/* GroupHeader */
  11,	/* IMAGE_FLIPY */
  11,	/* ImageHandle */
  11,	/* LabelButton */
  11,	/* LearnButton */
  11,	/* ModuleGrad1 */
  11,	/* ModuleGrad2 */
  11,	/* MouseButton */
  11,	/* MouseScroll */
  11,	/* OverlayTest */
  11,	/* PanicButton */
  11,	/* PasteButton */
  11,	/* ProgBuildVM */
  11,	/* QmlIrToRuby */
  11,	/* RUBY_ENGINE */
  11,	/* RegexpError */
  11,	/* RemoteParam */
  11,	/* ScriptError */
  11,	/* SyntaxError */
  11,	/* TimeProfile */
  11,	/* VisHarmonic */
  11,	/* WindowGrad1 */
  11,	/* WindowGrad2 */
  11,	/* ZynAddSynth */
  11,	/* ZynAddVoice */
  11,	/* ZynAlienwah */
  11,	/* ZynDAFilter */
  11,	/* ZynDFFilter */
  11,	/* ZynDyFilter */
  11,	/* ZynEqFilter */
  11,	/* ZynKitTable */
  11,	/* ZynMixerCol */
  11,	/* ZynOscilMod */
  11,	/* ZynPadSynth */
  11,	/* ZynSettings */
  11,	/* ZynSubSynth */
  11,	/* __ary_index */
  11,	/* _recur_list */
  11,	/* abort_frame */
  11,	/* active_auto */
  11,	/* attr_reader */
  11,	/* attr_writer */
  11,	/* begin_frame */
  11,	/* best_height */
  11,	/* bg_on_color */
  11,	/* black_color */
  11,	/* bound_child */
  11,	/* capitalize! */
  11,	/* change_file */
  11,	/* change_view */
  11,	/* circ_filter */
  11,	/* clear_flags */
  11,	/* clear_seq_c */
  11,	/* close_write */
  11,	/* combination */
  11,	/* consume_tok */
  11,	/* copy_button */
  11,	/* create_font */
  11,	/* create_menu */
  11,	/* damage_item */
  11,	/* damage_self */
  11,	/* dark_orange */
  11,	/* default_dir */
  11,	/* del_partial */
  11,	/* delay_time= */
  11,	/* display_log */
  11,	/* doInsSelect */
  11,	/* draw_button */
  11,	/* draw_normal */
  11,	/* draw_record */
  11,	/* draw_strike */
  11,	/* each_string */
  11,	/* eq_response */
  11,	/* executable? */
  11,	/* expand_path */
  11,	/* file_select */
  11,	/* fill_color= */
  11,	/* fill_paint= */
  11,	/* filter_freq */
  11,	/* filtertype= */
  11,	/* find_widget */
  11,	/* fixed_width */
  11,	/* font_handle */
  11,	/* gain_value= */
  11,	/* genConstBox */
  11,	/* get_context */
  11,	/* get_refresh */
  11,	/* gl_viewport */
  11,	/* init_window */
  11,	/* inner_color */
  11,	/* knobLRcross */
  11,	/* label_items */
  11,	/* last_match= */
  11,	/* layoutOpts= */
  11,	/* learn_midi= */
  11,	/* learn_mode= */
  11,	/* light_filll */
  11,	/* line_widths */
  11,	/* log_widget= */
  11,	/* main_widget */
  11,	/* make_points */
  11,	/* map_include */
  11,	/* maxeffects= */
  11,	/* miter_limit */
  11,	/* module_eval */
  11,	/* mouseScroll */
  11,	/* needRefresh */
  11,	/* needsRegen= */
  11,	/* next_coeff= */
  11,	/* next_values */
  11,	/* noise_mode= */
  11,	/* numformants */
  11,	/* onMouseMove */
  11,	/* outer_color */
  11,	/* overlay_fbo */
  11,	/* overlay_lfo */
  11,	/* owned_real? */
  11,	/* padprofile= */
  11,	/* partsetting */
  11,	/* peek_values */
  11,	/* permutation */
  11,	/* pure_string */
  11,	/* pure_symbol */
  11,	/* qwerty_high */
  11,	/* read_string */
  11,	/* recommended */
  11,	/* refreshing= */
  11,	/* render_seqs */
  11,	/* reset_value */
  11,	/* respond_to? */
  11,	/* rightButton */
  11,	/* sample_rate */
  11,	/* search_path */
  11,	/* selected_id */
  11,	/* send_points */
  11,	/* set_content */
  11,	/* set_non_kit */
  11,	/* set_partial */
  11,	/* set_vis_amp */
  11,	/* set_vis_env */
  11,	/* set_vis_lfo */
  11,	/* slide_freq= */
  11,	/* start_with? */
  11,	/* step_ratio= */
  11,	/* subfqbutton */
  11,	/* text_align= */
  11,	/* text_bounds */
  11,	/* text_color1 */
  11,	/* text_color2 */
  11,	/* tick_events */
  11,	/* tick_remote */
  11,	/* toggleable= */
  11,	/* tri_upper_x */
  11,	/* tri_upper_y */
  11,	/* try_hotload */
  11,	/* update_data */
  11,	/* update_path */
  11,	/* update_text */
  11,	/* update_time */
  11,	/* value_label */
  11,	/* weak_box_id */
  11,	/* weight_list */
  11,	/* whenSwapped */
  11,	/* whitespace= */
  11,	/* windowTitle */
  11,	/* with_object */
  12,	/* $current_dir */
  12,	/* $dummy_class */
  12,	/* $global_self */
  12,	/* @@key_lookup */
  12,	/* @active_line */
  12,	/* @anonymous17 */
  12,	/* @anonymous18 */
  12,	/* @anonymous20 */
  12,	/* @anonymous31 */
  12,	/* @anonymous43 */
  12,	/* @anonymous47 */
  12,	/* @anonymous51 */
  12,	/* @anonymous52 */
  12,	/* @anonymous53 */
  12,	/* @anonymous54 */
  12,	/* @anonymous55 */
  12,	/* @anonymous57 */
  12,	/* @anonymous58 */
  12,	/* @anonymous59 */
  12,	/* @anonymous60 */
  12,	/* @anonymous61 */
  12,	/* @anonymous67 */
  12,	/* @copy_button */
  12,	/* @current_dir */
  12,	/* @knobLRcross */
  12,	/* @line_widths */
  12,	/* @main_widget */
  12,	/* @overlay_fbo */
  12,	/* @overlay_img */
  12,	/* @partsetting */
  12,	/* @search_path */
  12,	/* @send_update */
  12,	/* @subfqbutton */
  12,	/* @word_buffer */
  12,	/* ALIGN_BOTTOM */
  12,	/* ALIGN_CENTER */
  12,	/* ALIGN_MIDDLE */
  12,	/* ButtonActive */
  12,	/* BypassButton */
  12,	/* DrawSequence */
  12,	/* EAFNOSUPPORT */
  12,	/* ECONNABORTED */
  12,	/* ECONNREFUSED */
  12,	/* EDESTADDRREQ */
  12,	/* EHOSTUNREACH */
  12,	/* EKEYREJECTED */
  12,	/* ENAMETOOLONG */
  12,	/* EPFNOSUPPORT */
  12,	/* EPROCUNAVAIL */
  12,	/* EPROGUNAVAIL */
  12,	/* ERPCMISMATCH */
  12,	/* ETOOMANYREFS */
  12,	/* FNM_CASEFOLD */
  12,	/* FNM_DOTMATCH */
  12,	/* FNM_NOESCAPE */
  12,	/* FNM_PATHNAME */
  12,	/* FileSelector */
  12,	/* HarmonicEdit */
  12,	/* HarmonicView */
  12,	/* NumberButton */
  12,	/* ParModuleRow */
  12,	/* RUBY_VERSION */
  12,	/* RuntimeError */
  12,	/* SHARE_DELETE */
  12,	/* ScrollActive */
  12,	/* SliderActive */
  12,	/* SliderStroke */
  12,	/* SustainPoint */
  12,	/* TextModColor */
  12,	/* ToggleButton */
  12,	/* UiEventTypes */
  12,	/* VisResonance */
  12,	/* VisualBright */
  12,	/* VisualSelect */
  12,	/* VisualStroke */
  12,	/* ZynAddGlobal */
  12,	/* ZynDynFilter */
  12,	/* ZynEqualizer */
  12,	/* ZynFilterEnv */
  12,	/* ZynMidiLearn */
  12,	/* ZynModAmpEnv */
  12,	/* ZynPadGlobal */
  12,	/* ZynPatchInfo */
  12,	/* ZynResonance */
  12,	/* ZynSendToRow */
  12,	/* ZynSubFilter */
  12,	/* ZynSubGlobal */
  12,	/* __attached__ */
  12,	/* __printstr__ */
  12,	/* _concat_path */
  12,	/* activeWidget */
  12,	/* active_auto= */
  12,	/* active_event */
  12,	/* add_property */
  12,	/* alias_method */
  12,	/* analogButton */
  12,	/* assert_equal */
  12,	/* assert_raise */
  12,	/* black_accent */
  12,	/* black_key_id */
  12,	/* block_given? */
  12,	/* bound_parent */
  12,	/* bound_points */
  12,	/* box_gradient */
  12,	/* bright_green */
  12,	/* cancel_frame */
  12,	/* changeAnalog */
  12,	/* check_redraw */
  12,	/* column_count */
  12,	/* column_index */
  12,	/* consume_inst */
  12,	/* consume_line */
  12,	/* create_image */
  12,	/* default_proc */
  12,	/* delayRefresh */
  12,	/* delete_image */
  12,	/* do_with_enum */
  12,	/* drawVZSlider */
  12,	/* draw_borders */
  12,	/* draw_classic */
  12,	/* draw_overlay */
  12,	/* drive_prefix */
  12,	/* enable_color */
  12,	/* env_sel_line */
  12,	/* escape_table */
  12,	/* event_widget */
  12,	/* exclude_end? */
  12,	/* fetch_values */
  12,	/* font_face_id */
  12,	/* force_update */
  12,	/* get_view_pos */
  12,	/* get_x_points */
  12,	/* getkeystring */
  12,	/* global_alpha */
  12,	/* handleScroll */
  12,	/* ignoreAspect */
  12,	/* ignore_phase */
  12,	/* image_handle */
  12,	/* ind_selected */
  12,	/* indent_color */
  12,	/* inner_color= */
  12,	/* install_attr */
  12,	/* instance_of? */
  12,	/* intersection */
  12,	/* last_up_time */
  12,	/* layout_hpack */
  12,	/* make_formant */
  12,	/* method_added */
  12,	/* middleButton */
  12,	/* middle_panel */
  12,	/* midi_unlearn */
  12,	/* miter_limit= */
  12,	/* mouseRelease */
  12,	/* mouse_enable */
  12,	/* mouse_handle */
  12,	/* needRefresh= */
  12,	/* needs_update */
  12,	/* numformants= */
  12,	/* onMouseEnter */
  12,	/* onMouseHover */
  12,	/* onMouseLeave */
  12,	/* onMousePress */
  12,	/* oscillbutton */
  12,	/* oscilloscope */
  12,	/* outer_color= */
  12,	/* partchannels */
  12,	/* paste_button */
  12,	/* path_winding */
  12,	/* pre_multiply */
  12,	/* print_matrix */
  12,	/* pure_numeric */
  12,	/* remove_const */
  12,	/* remove_sense */
  12,	/* reverse_each */
  12,	/* rounded_rect */
  12,	/* runBuildTest */
  12,	/* search_path= */
  12,	/* selected_fbo */
  12,	/* selected_val */
  12,	/* set_callback */
  12,	/* set_home_dir */
  12,	/* set_value_ar */
  12,	/* set_value_tf */
  12,	/* set_view_pos */
  12,	/* set_vis_freq */
  12,	/* setup_widget */
  12,	/* should_close */
  12,	/* shownWeights */
  12,	/* smash_layout */
  12,	/* strike_color */
  12,	/* stroke_color */
  12,	/* stroke_paint */
  12,	/* stroke_width */
  12,	/* test_no_home */
  12,	/* test_summary */
  12,	/* test_unix_cd */
  12,	/* text_metrics */
  12,	/* tick_hotload */
  12,	/* turn_off_tab */
  12,	/* undef_method */
  12,	/* updatePosAbs */
  12,	/* update_coeff */
  12,	/* update_image */
  12,	/* update_value */
  12,	/* value_label= */
  12,	/* whenModified */
  12,	/* whenSwapped= */
  12,	/* white_accent */
  12,	/* white_key_id */
  12,	/* windowResize */
  12,	/* windowTitle= */
  13,	/* $test_counter */
  13,	/* @analogButton */
  13,	/* @anonymous110 */
  13,	/* @anonymous111 */
  13,	/* @anonymous113 */
  13,	/* @anonymous114 */
  13,	/* @anonymous115 */
  13,	/* @anonymous116 */
  13,	/* @anonymous117 */
  13,	/* @anonymous118 */
  13,	/* @anonymous119 */
  13,	/* @anonymous122 */
  13,	/* @anonymous124 */
  13,	/* @anonymous125 */
  13,	/* @anonymous126 */
  13,	/* @anonymous127 */
  13,	/* @anonymous129 */
  13,	/* @anonymous141 */
  13,	/* @anonymous145 */
  13,	/* @anonymous146 */
  13,	/* @anonymous148 */
  13,	/* @anonymous149 */
  13,	/* @anonymous150 */
  13,	/* @anonymous157 */
  13,	/* @anonymous162 */
  13,	/* @anonymous163 */
  13,	/* @anonymous170 */
  13,	/* @anonymous171 */
  13,	/* @anonymous177 */
  13,	/* @anonymous178 */
  13,	/* @anonymous179 */
  13,	/* @anonymous180 */
  13,	/* @anonymous181 */
  13,	/* @anonymous185 */
  13,	/* @anonymous186 */
  13,	/* @anonymous192 */
  13,	/* @anonymous207 */
  13,	/* @anonymous208 */
  13,	/* @anonymous214 */
  13,	/* @anonymous215 */
  13,	/* @anonymous216 */
  13,	/* @anonymous219 */
  13,	/* @anonymous220 */
  13,	/* @anonymous221 */
  13,	/* @anonymous223 */
  13,	/* @anonymous224 */
  13,	/* @anonymous225 */
  13,	/* @anonymous226 */
  13,	/* @anonymous227 */
  13,	/* @anonymous228 */
  13,	/* @anonymous229 */
  13,	/* @anonymous230 */
  13,	/* @anonymous242 */
  13,	/* @anonymous243 */
  13,	/* @anonymous244 */
  13,	/* @anonymous247 */
  13,	/* @anonymous248 */
  13,	/* @anonymous249 */
  13,	/* @anonymous250 */
  13,	/* @anonymous251 */
  13,	/* @anonymous252 */
  13,	/* @anonymous253 */
  13,	/* @anonymous255 */
  13,	/* @anonymous256 */
  13,	/* @anonymous257 */
  13,	/* @anonymous258 */
  13,	/* @anonymous259 */
  13,	/* @anonymous260 */
  13,	/* @anonymous261 */
  13,	/* @anonymous263 */
  13,	/* @anonymous264 */
  13,	/* @anonymous265 */
  13,	/* @anonymous266 */
  13,	/* @anonymous267 */
  13,	/* @anonymous268 */
  13,	/* @anonymous269 */
  13,	/* @anonymous270 */
  13,	/* @anonymous271 */
  13,	/* @anonymous272 */
  13,	/* @anonymous273 */
  13,	/* @anonymous274 */
  13,	/* @anonymous275 */
  13,	/* @anonymous276 */
  13,	/* @anonymous277 */
  13,	/* @anonymous280 */
  13,	/* @anonymous281 */
  13,	/* @anonymous282 */
  13,	/* @anonymous284 */
  13,	/* @anonymous285 */
  13,	/* @anonymous286 */
  13,	/* @anonymous287 */
  13,	/* @anonymous288 */
  13,	/* @anonymous289 */
  13,	/* @anonymous292 */
  13,	/* @anonymous293 */
  13,	/* @anonymous294 */
  13,	/* @anonymous295 */
  13,	/* @anonymous297 */
  13,	/* @anonymous298 */
  13,	/* @anonymous299 */
  13,	/* @anonymous300 */
  13,	/* @anonymous301 */
  13,	/* @anonymous304 */
  13,	/* @anonymous305 */
  13,	/* @anonymous306 */
  13,	/* @anonymous307 */
  13,	/* @anonymous308 */
  13,	/* @anonymous310 */
  13,	/* @anonymous311 */
  13,	/* @anonymous312 */
  13,	/* @anonymous314 */
  13,	/* @anonymous315 */
  13,	/* @anonymous316 */
  13,	/* @anonymous319 */
  13,	/* @anonymous320 */
  13,	/* @anonymous321 */
  13,	/* @anonymous324 */
  13,	/* @anonymous328 */
  13,	/* @anonymous329 */
  13,	/* @anonymous332 */
  13,	/* @anonymous333 */
  13,	/* @anonymous337 */
  13,	/* @anonymous341 */
  13,	/* @anonymous345 */
  13,	/* @anonymous349 */
  13,	/* @anonymous355 */
  13,	/* @anonymous358 */
  13,	/* @anonymous359 */
  13,	/* @anonymous360 */
  13,	/* @anonymous361 */
  13,	/* @anonymous363 */
  13,	/* @anonymous364 */
  13,	/* @anonymous371 */
  13,	/* @anonymous373 */
  13,	/* @anonymous374 */
  13,	/* @anonymous375 */
  13,	/* @anonymous376 */
  13,	/* @anonymous379 */
  13,	/* @anonymous380 */
  13,	/* @anonymous383 */
  13,	/* @anonymous384 */
  13,	/* @anonymous385 */
  13,	/* @anonymous386 */
  13,	/* @anonymous387 */
  13,	/* @anonymous388 */
  13,	/* @anonymous389 */
  13,	/* @anonymous390 */
  13,	/* @anonymous391 */
  13,	/* @anonymous392 */
  13,	/* @anonymous393 */
  13,	/* @anonymous395 */
  13,	/* @anonymous396 */
  13,	/* @anonymous397 */
  13,	/* @anonymous398 */
  13,	/* @anonymous399 */
  13,	/* @anonymous400 */
  13,	/* @anonymous401 */
  13,	/* @anonymous403 */
  13,	/* @anonymous404 */
  13,	/* @anonymous405 */
  13,	/* @anonymous406 */
  13,	/* @anonymous408 */
  13,	/* @anonymous409 */
  13,	/* @anonymous410 */
  13,	/* @anonymous411 */
  13,	/* @anonymous412 */
  13,	/* @anonymous415 */
  13,	/* @anonymous416 */
  13,	/* @anonymous417 */
  13,	/* @anonymous418 */
  13,	/* @anonymous419 */
  13,	/* @anonymous420 */
  13,	/* @anonymous422 */
  13,	/* @anonymous423 */
  13,	/* @anonymous424 */
  13,	/* @anonymous425 */
  13,	/* @anonymous426 */
  13,	/* @anonymous428 */
  13,	/* @anonymous429 */
  13,	/* @anonymous430 */
  13,	/* @anonymous439 */
  13,	/* @anonymous440 */
  13,	/* @anonymous441 */
  13,	/* @anonymous442 */
  13,	/* @anonymous443 */
  13,	/* @anonymous444 */
  13,	/* @anonymous445 */
  13,	/* @anonymous446 */
  13,	/* @anonymous447 */
  13,	/* @anonymous448 */
  13,	/* @anonymous449 */
  13,	/* @anonymous450 */
  13,	/* @anonymous451 */
  13,	/* @anonymous452 */
  13,	/* @anonymous453 */
  13,	/* @anonymous454 */
  13,	/* @anonymous457 */
  13,	/* @anonymous458 */
  13,	/* @anonymous459 */
  13,	/* @anonymous460 */
  13,	/* @anonymous461 */
  13,	/* @anonymous462 */
  13,	/* @anonymous463 */
  13,	/* @anonymous464 */
  13,	/* @anonymous465 */
  13,	/* @anonymous466 */
  13,	/* @anonymous467 */
  13,	/* @anonymous468 */
  13,	/* @anonymous469 */
  13,	/* @anonymous470 */
  13,	/* @anonymous471 */
  13,	/* @anonymous472 */
  13,	/* @anonymous473 */
  13,	/* @anonymous476 */
  13,	/* @anonymous478 */
  13,	/* @anonymous480 */
  13,	/* @anonymous482 */
  13,	/* @anonymous483 */
  13,	/* @anonymous484 */
  13,	/* @anonymous485 */
  13,	/* @anonymous486 */
  13,	/* @anonymous487 */
  13,	/* @anonymous489 */
  13,	/* @anonymous490 */
  13,	/* @anonymous491 */
  13,	/* @anonymous493 */
  13,	/* @anonymous494 */
  13,	/* @anonymous495 */
  13,	/* @anonymous496 */
  13,	/* @anonymous498 */
  13,	/* @anonymous499 */
  13,	/* @anonymous501 */
  13,	/* @anonymous502 */
  13,	/* @anonymous503 */
  13,	/* @anonymous506 */
  13,	/* @anonymous507 */
  13,	/* @anonymous510 */
  13,	/* @anonymous511 */
  13,	/* @anonymous512 */
  13,	/* @anonymous513 */
  13,	/* @anonymous514 */
  13,	/* @anonymous515 */
  13,	/* @anonymous516 */
  13,	/* @anonymous517 */
  13,	/* @anonymous518 */
  13,	/* @anonymous519 */
  13,	/* @anonymous520 */
  13,	/* @anonymous521 */
  13,	/* @anonymous522 */
  13,	/* @anonymous523 */
  13,	/* @anonymous524 */
  13,	/* @anonymous526 */
  13,	/* @anonymous527 */
  13,	/* @anonymous528 */
  13,	/* @anonymous529 */
  13,	/* @anonymous530 */
  13,	/* @anonymous531 */
  13,	/* @anonymous532 */
  13,	/* @anonymous533 */
  13,	/* @anonymous534 */
  13,	/* @anonymous535 */
  13,	/* @anonymous536 */
  13,	/* @anonymous539 */
  13,	/* @anonymous540 */
  13,	/* @anonymous541 */
  13,	/* @anonymous542 */
  13,	/* @anonymous544 */
  13,	/* @anonymous545 */
  13,	/* @anonymous546 */
  13,	/* @anonymous547 */
  13,	/* @anonymous549 */
  13,	/* @anonymous550 */
  13,	/* @anonymous551 */
  13,	/* @anonymous552 */
  13,	/* @anonymous553 */
  13,	/* @anonymous554 */
  13,	/* @anonymous556 */
  13,	/* @anonymous557 */
  13,	/* @anonymous558 */
  13,	/* @anonymous559 */
  13,	/* @anonymous560 */
  13,	/* @anonymous565 */
  13,	/* @anonymous568 */
  13,	/* @anonymous571 */
  13,	/* @anonymous573 */
  13,	/* @anonymous574 */
  13,	/* @anonymous575 */
  13,	/* @anonymous577 */
  13,	/* @anonymous579 */
  13,	/* @anonymous581 */
  13,	/* @anonymous583 */
  13,	/* @anonymous584 */
  13,	/* @anonymous586 */
  13,	/* @anonymous587 */
  13,	/* @anonymous588 */
  13,	/* @anonymous589 */
  13,	/* @anonymous590 */
  13,	/* @anonymous591 */
  13,	/* @anonymous593 */
  13,	/* @anonymous594 */
  13,	/* @anonymous595 */
  13,	/* @anonymous596 */
  13,	/* @anonymous610 */
  13,	/* @anonymous611 */
  13,	/* @anonymous612 */
  13,	/* @anonymous613 */
  13,	/* @anonymous614 */
  13,	/* @anonymous615 */
  13,	/* @anonymous621 */
  13,	/* @anonymous622 */
  13,	/* @anonymous623 */
  13,	/* @anonymous625 */
  13,	/* @anonymous627 */
  13,	/* @anonymous629 */
  13,	/* @anonymous630 */
  13,	/* @anonymous632 */
  13,	/* @anonymous633 */
  13,	/* @anonymous634 */
  13,	/* @anonymous635 */
  13,	/* @anonymous636 */
  13,	/* @anonymous638 */
  13,	/* @anonymous639 */
  13,	/* @anonymous640 */
  13,	/* @anonymous642 */
  13,	/* @anonymous643 */
  13,	/* @anonymous644 */
  13,	/* @anonymous647 */
  13,	/* @anonymous648 */
  13,	/* @anonymous649 */
  13,	/* @anonymous650 */
  13,	/* @anonymous651 */
  13,	/* @anonymous652 */
  13,	/* @anonymous653 */
  13,	/* @anonymous655 */
  13,	/* @anonymous656 */
  13,	/* @anonymous657 */
  13,	/* @anonymous658 */
  13,	/* @anonymous659 */
  13,	/* @anonymous660 */
  13,	/* @anonymous661 */
  13,	/* @anonymous662 */
  13,	/* @anonymous664 */
  13,	/* @anonymous665 */
  13,	/* @anonymous666 */
  13,	/* @anonymous667 */
  13,	/* @anonymous668 */
  13,	/* @anonymous669 */
  13,	/* @anonymous670 */
  13,	/* @anonymous674 */
  13,	/* @anonymous683 */
  13,	/* @anonymous684 */
  13,	/* @anonymous685 */
  13,	/* @anonymous686 */
  13,	/* @anonymous687 */
  13,	/* @anonymous688 */
  13,	/* @anonymous691 */
  13,	/* @anonymous692 */
  13,	/* @anonymous693 */
  13,	/* @anonymous694 */
  13,	/* @anonymous695 */
  13,	/* @anonymous696 */
  13,	/* @anonymous697 */
  13,	/* @anonymous698 */
  13,	/* @anonymous699 */
  13,	/* @anonymous701 */
  13,	/* @anonymous702 */
  13,	/* @anonymous704 */
  13,	/* @anonymous705 */
  13,	/* @anonymous706 */
  13,	/* @anonymous708 */
  13,	/* @anonymous709 */
  13,	/* @anonymous711 */
  13,	/* @anonymous712 */
  13,	/* @anonymous713 */
  13,	/* @anonymous715 */
  13,	/* @anonymous720 */
  13,	/* @anonymous722 */
  13,	/* @anonymous723 */
  13,	/* @anonymous724 */
  13,	/* @anonymous725 */
  13,	/* @anonymous726 */
  13,	/* @anonymous727 */
  13,	/* @anonymous728 */
  13,	/* @anonymous729 */
  13,	/* @anonymous730 */
  13,	/* @anonymous731 */
  13,	/* @anonymous734 */
  13,	/* @anonymous735 */
  13,	/* @anonymous736 */
  13,	/* @anonymous737 */
  13,	/* @anonymous739 */
  13,	/* @anonymous740 */
  13,	/* @anonymous741 */
  13,	/* @anonymous742 */
  13,	/* @anonymous743 */
  13,	/* @anonymous745 */
  13,	/* @anonymous746 */
  13,	/* @anonymous747 */
  13,	/* @anonymous748 */
  13,	/* @anonymous750 */
  13,	/* @anonymous751 */
  13,	/* @anonymous752 */
  13,	/* @anonymous754 */
  13,	/* @anonymous755 */
  13,	/* @anonymous756 */
  13,	/* @anonymous757 */
  13,	/* @anonymous758 */
  13,	/* @anonymous759 */
  13,	/* @anonymous760 */
  13,	/* @anonymous761 */
  13,	/* @anonymous762 */
  13,	/* @anonymous763 */
  13,	/* @anonymous764 */
  13,	/* @anonymous765 */
  13,	/* @anonymous767 */
  13,	/* @anonymous768 */
  13,	/* @anonymous769 */
  13,	/* @anonymous770 */
  13,	/* @anonymous771 */
  13,	/* @anonymous772 */
  13,	/* @anonymous773 */
  13,	/* @anonymous774 */
  13,	/* @anonymous776 */
  13,	/* @anonymous777 */
  13,	/* @anonymous778 */
  13,	/* @anonymous780 */
  13,	/* @anonymous781 */
  13,	/* @anonymous784 */
  13,	/* @anonymous785 */
  13,	/* @anonymous786 */
  13,	/* @anonymous787 */
  13,	/* @anonymous788 */
  13,	/* @anonymous789 */
  13,	/* @anonymous790 */
  13,	/* @anonymous791 */
  13,	/* @anonymous792 */
  13,	/* @anonymous794 */
  13,	/* @anonymous795 */
  13,	/* @anonymous796 */
  13,	/* @anonymous797 */
  13,	/* @anonymous798 */
  13,	/* @anonymous800 */
  13,	/* @anonymous801 */
  13,	/* @anonymous802 */
  13,	/* @anonymous803 */
  13,	/* @anonymous804 */
  13,	/* @anonymous805 */
  13,	/* @anonymous807 */
  13,	/* @anonymous808 */
  13,	/* @anonymous809 */
  13,	/* @anonymous810 */
  13,	/* @anonymous811 */
  13,	/* @anonymous812 */
  13,	/* @anonymous822 */
  13,	/* @anonymous823 */
  13,	/* @anonymous824 */
  13,	/* @anonymous825 */
  13,	/* @anonymous826 */
  13,	/* @anonymous828 */
  13,	/* @anonymous829 */
  13,	/* @anonymous830 */
  13,	/* @anonymous831 */
  13,	/* @anonymous832 */
  13,	/* @anonymous833 */
  13,	/* @anonymous834 */
  13,	/* @anonymous835 */
  13,	/* @anonymous836 */
  13,	/* @anonymous837 */
  13,	/* @anonymous838 */
  13,	/* @anonymous839 */
  13,	/* @anonymous840 */
  13,	/* @anonymous841 */
  13,	/* @anonymous842 */
  13,	/* @anonymous843 */
  13,	/* @anonymous844 */
  13,	/* @anonymous845 */
  13,	/* @anonymous846 */
  13,	/* @anonymous847 */
  13,	/* @anonymous848 */
  13,	/* @anonymous849 */
  13,	/* @anonymous850 */
  13,	/* @anonymous851 */
  13,	/* @anonymous852 */
  13,	/* @anonymous853 */
  13,	/* @anonymous854 */
  13,	/* @anonymous855 */
  13,	/* @anonymous856 */
  13,	/* @anonymous857 */
  13,	/* @anonymous858 */
  13,	/* @anonymous859 */
  13,	/* @anonymous860 */
  13,	/* @anonymous861 */
  13,	/* @anonymous862 */
  13,	/* @anonymous863 */
  13,	/* @anonymous864 */
  13,	/* @anonymous868 */
  13,	/* @anonymous871 */
  13,	/* @anonymous872 */
  13,	/* @anonymous873 */
  13,	/* @anonymous874 */
  13,	/* @anonymous875 */
  13,	/* @anonymous876 */
  13,	/* @anonymous879 */
  13,	/* @anonymous881 */
  13,	/* @anonymous882 */
  13,	/* @anonymous883 */
  13,	/* @anonymous884 */
  13,	/* @anonymous885 */
  13,	/* @anonymous886 */
  13,	/* @anonymous887 */
  13,	/* @anonymous888 */
  13,	/* @anonymous889 */
  13,	/* @anonymous890 */
  13,	/* @anonymous891 */
  13,	/* @anonymous894 */
  13,	/* @anonymous895 */
  13,	/* @anonymous896 */
  13,	/* @anonymous897 */
  13,	/* @anonymous899 */
  13,	/* @anonymous902 */
  13,	/* @anonymous903 */
  13,	/* @anonymous904 */
  13,	/* @anonymous906 */
  13,	/* @anonymous907 */
  13,	/* @anonymous911 */
  13,	/* @anonymous912 */
  13,	/* @anonymous914 */
  13,	/* @anonymous915 */
  13,	/* @anonymous916 */
  13,	/* @anonymous917 */
  13,	/* @anonymous919 */
  13,	/* @anonymous920 */
  13,	/* @anonymous921 */
  13,	/* @anonymous922 */
  13,	/* @anonymous923 */
  13,	/* @anonymous924 */
  13,	/* @anonymous927 */
  13,	/* @anonymous928 */
  13,	/* @anonymous929 */
  13,	/* @anonymous930 */
  13,	/* @anonymous931 */
  13,	/* @anonymous932 */
  13,	/* @anonymous933 */
  13,	/* @anonymous934 */
  13,	/* @anonymous935 */
  13,	/* @anonymous942 */
  13,	/* @anonymous943 */
  13,	/* @anonymous944 */
  13,	/* @anonymous948 */
  13,	/* @anonymous949 */
  13,	/* @anonymous951 */
  13,	/* @anonymous952 */
  13,	/* @anonymous953 */
  13,	/* @anonymous954 */
  13,	/* @anonymous955 */
  13,	/* @anonymous956 */
  13,	/* @anonymous957 */
  13,	/* @anonymous958 */
  13,	/* @anonymous959 */
  13,	/* @anonymous960 */
  13,	/* @anonymous961 */
  13,	/* @anonymous962 */
  13,	/* @anonymous963 */
  13,	/* @anonymous965 */
  13,	/* @anonymous966 */
  13,	/* @anonymous967 */
  13,	/* @anonymous968 */
  13,	/* @anonymous969 */
  13,	/* @anonymous970 */
  13,	/* @anonymous971 */
  13,	/* @anonymous972 */
  13,	/* @anonymous973 */
  13,	/* @anonymous974 */
  13,	/* @anonymous975 */
  13,	/* @anonymous976 */
  13,	/* @anonymous977 */
  13,	/* @anonymous978 */
  13,	/* @anonymous979 */
  13,	/* @anonymous980 */
  13,	/* @anonymous982 */
  13,	/* @anonymous983 */
  13,	/* @anonymous984 */
  13,	/* @anonymous985 */
  13,	/* @anonymous986 */
  13,	/* @anonymous987 */
  13,	/* @anonymous988 */
  13,	/* @anonymous989 */
  13,	/* @anonymous990 */
  13,	/* @anonymous991 */
  13,	/* @anonymous992 */
  13,	/* @anonymous993 */
  13,	/* @anonymous994 */
  13,	/* @anonymous995 */
  13,	/* @anonymous996 */
  13,	/* @anonymous997 */
  13,	/* @anonymous998 */
  13,	/* @current_file */
  13,	/* @keep_running */
  13,	/* @middle_panel */
  13,	/* @needs_update */
  13,	/* @oscillbutton */
  13,	/* @paste_button */
  13,	/* @startup_time */
  13,	/* ALT_SEPARATOR */
  13,	/* ArgumentError */
  13,	/* CachedClasses */
  13,	/* ConfirmButton */
  13,	/* ConstantEntry */
  13,	/* EADDRNOTAVAIL */
  13,	/* EPROGMISMATCH */
  13,	/* EnvelopePoint */
  13,	/* GlobalIRCache */
  13,	/* HarmonicColor */
  13,	/* IMAGE_REPEATX */
  13,	/* IMAGE_REPEATY */
  13,	/* KeyBackground */
  13,	/* KeyWhiteGrad1 */
  13,	/* KeyWhiteGrad2 */
  13,	/* MRUBY_VERSION */
  13,	/* NoMemoryError */
  13,	/* NoMethodError */
  13,	/* QmlSearchPath */
  13,	/* RootDirectory */
  13,	/* SidebarButton */
  13,	/* StandardError */
  13,	/* StopIteration */
  13,	/* TriggerButton */
  13,	/* ZynAmpGeneral */
  13,	/* ZynAutomation */
  13,	/* ZynDistortion */
  13,	/* ZynPadProfile */
  13,	/* ZynPortamento */
  13,	/* ZynResOptions */
  13,	/* ZynSendToGrid */
  13,	/* ZynSubFreqEnv */
  13,	/* __classname__ */
  13,	/* __sub_replace */
  13,	/* __update_hash */
  13,	/* animate_frame */
  13,	/* animation_fbo */
  13,	/* assert_not_eq */
  13,	/* attr_accessor */
  13,	/* attr_property */
  13,	/* black_pattern */
  13,	/* brace_pattern */
  13,	/* bsearch_index */
  13,	/* calc_cursor_x */
  13,	/* change_active */
  13,	/* change_filter */
  13,	/* clear_refresh */
  13,	/* const_missing */
  13,	/* content_items */
  13,	/* context_apply */
  13,	/* create_radial */
  13,	/* damage_region */
  13,	/* default_proc= */
  13,	/* define_method */
  13,	/* delayRefresh= */
  13,	/* delete_prefix */
  13,	/* delete_suffix */
  13,	/* display_value */
  13,	/* drag_and_drop */
  13,	/* draw_borders= */
  13,	/* draw_centered */
  13,	/* draw_inactive */
  13,	/* drawn_widgets */
  13,	/* dynamicfilter */
  13,	/* expanded_path */
  13,	/* extend_object */
  13,	/* flatten_merge */
  13,	/* font_face_id= */
  13,	/* force_refresh */
  13,	/* get_note_name */
  13,	/* get_qml_const */
  13,	/* global_alpha= */
  13,	/* handle_events */
  13,	/* harmonic_view */
  13,	/* highlight_pos */
  13,	/* ignore_phase= */
  13,	/* image_pattern */
  13,	/* in_lower_half */
  13,	/* ind_selected= */
  13,	/* indirect_attr */
  13,	/* init_automate */
  13,	/* initialize_rb */
  13,	/* instance_eval */
  13,	/* instance_exec */
  13,	/* learn_address */
  13,	/* load_property */
  13,	/* make_bandpass */
  13,	/* make_callback */
  13,	/* make_rdepends */
  13,	/* message_class */
  13,	/* mouse_enable= */
  13,	/* needs_refresh */
  13,	/* no_constraint */
  13,	/* opt_magnitude */
  13,	/* oscillbutton= */
  13,	/* outline_color */
  13,	/* path_elements */
  13,	/* path_winding= */
  13,	/* pre_multiply! */
  13,	/* prev_channels */
  13,	/* rec_clean_cbs */
  13,	/* rec_del_props */
  13,	/* refresh_recur */
  13,	/* reorder_cache */
  13,	/* reset_scissor */
  13,	/* selected_item */
  13,	/* set_backtrace */
  13,	/* set_sub_value */
  13,	/* set_value_str */
  13,	/* setup_classes */
  13,	/* shownWeights= */
  13,	/* splitted_path */
  13,	/* strip_literal */
  13,	/* stroke_color= */
  13,	/* stroke_paint= */
  13,	/* stroke_width= */
  13,	/* sub_harmonics */
  13,	/* sustain_color */
  13,	/* sustain_point */
  13,	/* update_active */
  13,	/* update_points */
  13,	/* update_values */
  13,	/* whenModified= */
  13,	/* windows_path? */
  13,	/* windows_start */
  14,	/* $auto_apply_dt */
  14,	/* @active_widget */
  14,	/* @animation_fbo */
  14,	/* @animation_img */
  14,	/* @anonymous1000 */
  14,	/* @anonymous1001 */
  14,	/* @anonymous1002 */
  14,	/* @anonymous1010 */
  14,	/* @anonymous1011 */
  14,	/* @anonymous1012 */
  14,	/* @anonymous1013 */
  14,	/* @anonymous1014 */
  14,	/* @anonymous1015 */
  14,	/* @anonymous1017 */
  14,	/* @anonymous1019 */
  14,	/* @anonymous1021 */
  14,	/* @anonymous1024 */
  14,	/* @anonymous1025 */
  14,	/* @anonymous1026 */
  14,	/* @anonymous1027 */
  14,	/* @anonymous1028 */
  14,	/* @anonymous1029 */
  14,	/* @anonymous1030 */
  14,	/* @anonymous1031 */
  14,	/* @anonymous1032 */
  14,	/* @anonymous1033 */
  14,	/* @anonymous1034 */
  14,	/* @anonymous1035 */
  14,	/* @anonymous1037 */
  14,	/* @anonymous1040 */
  14,	/* @anonymous1043 */
  14,	/* @anonymous1044 */
  14,	/* @anonymous1048 */
  14,	/* @anonymous1049 */
  14,	/* @anonymous1050 */
  14,	/* @anonymous1051 */
  14,	/* @anonymous1052 */
  14,	/* @anonymous1053 */
  14,	/* @anonymous1054 */
  14,	/* @anonymous1055 */
  14,	/* @anonymous1056 */
  14,	/* @anonymous1057 */
  14,	/* @anonymous1058 */
  14,	/* @anonymous1059 */
  14,	/* @anonymous1061 */
  14,	/* @anonymous1062 */
  14,	/* @anonymous1063 */
  14,	/* @anonymous1064 */
  14,	/* @anonymous1065 */
  14,	/* @anonymous1066 */
  14,	/* @anonymous1067 */
  14,	/* @anonymous1068 */
  14,	/* @anonymous1069 */
  14,	/* @anonymous1070 */
  14,	/* @anonymous1071 */
  14,	/* @anonymous1072 */
  14,	/* @anonymous1073 */
  14,	/* @anonymous1076 */
  14,	/* @anonymous1077 */
  14,	/* @anonymous1079 */
  14,	/* @anonymous1080 */
  14,	/* @anonymous1081 */
  14,	/* @anonymous1082 */
  14,	/* @anonymous1083 */
  14,	/* @anonymous1084 */
  14,	/* @anonymous1085 */
  14,	/* @anonymous1086 */
  14,	/* @anonymous1087 */
  14,	/* @anonymous1088 */
  14,	/* @anonymous1089 */
  14,	/* @anonymous1090 */
  14,	/* @anonymous1093 */
  14,	/* @anonymous1094 */
  14,	/* @anonymous1095 */
  14,	/* @anonymous1096 */
  14,	/* @anonymous1097 */
  14,	/* @anonymous1098 */
  14,	/* @anonymous1099 */
  14,	/* @anonymous1100 */
  14,	/* @anonymous1101 */
  14,	/* @anonymous1102 */
  14,	/* @anonymous1103 */
  14,	/* @anonymous1104 */
  14,	/* @anonymous1105 */
  14,	/* @anonymous1106 */
  14,	/* @anonymous1107 */
  14,	/* @anonymous1108 */
  14,	/* @anonymous1109 */
  14,	/* @anonymous1110 */
  14,	/* @anonymous1113 */
  14,	/* @anonymous1114 */
  14,	/* @anonymous1117 */
  14,	/* @anonymous1118 */
  14,	/* @anonymous1119 */
  14,	/* @anonymous1120 */
  14,	/* @anonymous1121 */
  14,	/* @anonymous1122 */
  14,	/* @anonymous1123 */
  14,	/* @anonymous1124 */
  14,	/* @anonymous1125 */
  14,	/* @anonymous1126 */
  14,	/* @anonymous1127 */
  14,	/* @anonymous1128 */
  14,	/* @anonymous1129 */
  14,	/* @anonymous1130 */
  14,	/* @anonymous1131 */
  14,	/* @anonymous1132 */
  14,	/* @anonymous1133 */
  14,	/* @anonymous1134 */
  14,	/* @anonymous1135 */
  14,	/* @anonymous1136 */
  14,	/* @anonymous1137 */
  14,	/* @anonymous1140 */
  14,	/* @anonymous1145 */
  14,	/* @anonymous1150 */
  14,	/* @anonymous1156 */
  14,	/* @anonymous1157 */
  14,	/* @anonymous1158 */
  14,	/* @anonymous1159 */
  14,	/* @anonymous1160 */
  14,	/* @anonymous1161 */
  14,	/* @anonymous1162 */
  14,	/* @anonymous1163 */
  14,	/* @anonymous1164 */
  14,	/* @anonymous1166 */
  14,	/* @anonymous1167 */
  14,	/* @anonymous1168 */
  14,	/* @anonymous1169 */
  14,	/* @anonymous1170 */
  14,	/* @anonymous1171 */
  14,	/* @anonymous1173 */
  14,	/* @anonymous1175 */
  14,	/* @anonymous1176 */
  14,	/* @anonymous1177 */
  14,	/* @anonymous1178 */
  14,	/* @anonymous1179 */
  14,	/* @anonymous1180 */
  14,	/* @anonymous1181 */
  14,	/* @anonymous1182 */
  14,	/* @anonymous1183 */
  14,	/* @anonymous1188 */
  14,	/* @anonymous1190 */
  14,	/* @anonymous1192 */
  14,	/* @anonymous1193 */
  14,	/* @anonymous1194 */
  14,	/* @anonymous1195 */
  14,	/* @anonymous1196 */
  14,	/* @anonymous1197 */
  14,	/* @anonymous1198 */
  14,	/* @anonymous1199 */
  14,	/* @anonymous1200 */
  14,	/* @anonymous1201 */
  14,	/* @anonymous1202 */
  14,	/* @anonymous1203 */
  14,	/* @anonymous1205 */
  14,	/* @anonymous1206 */
  14,	/* @anonymous1207 */
  14,	/* @anonymous1208 */
  14,	/* @anonymous1209 */
  14,	/* @anonymous1210 */
  14,	/* @anonymous1211 */
  14,	/* @anonymous1212 */
  14,	/* @anonymous1213 */
  14,	/* @anonymous1214 */
  14,	/* @anonymous1220 */
  14,	/* @anonymous1221 */
  14,	/* @anonymous1222 */
  14,	/* @anonymous1226 */
  14,	/* @anonymous1227 */
  14,	/* @anonymous1228 */
  14,	/* @anonymous1229 */
  14,	/* @anonymous1230 */
  14,	/* @anonymous1231 */
  14,	/* @anonymous1232 */
  14,	/* @anonymous1233 */
  14,	/* @anonymous1234 */
  14,	/* @anonymous1235 */
  14,	/* @anonymous1238 */
  14,	/* @anonymous1239 */
  14,	/* @anonymous1240 */
  14,	/* @anonymous1241 */
  14,	/* @anonymous1242 */
  14,	/* @anonymous1243 */
  14,	/* @anonymous1246 */
  14,	/* @anonymous1250 */
  14,	/* @anonymous1252 */
  14,	/* @anonymous1254 */
  14,	/* @anonymous1255 */
  14,	/* @anonymous1256 */
  14,	/* @anonymous1257 */
  14,	/* @anonymous1258 */
  14,	/* @anonymous1259 */
  14,	/* @anonymous1261 */
  14,	/* @anonymous1262 */
  14,	/* @anonymous1263 */
  14,	/* @children_locs */
  14,	/* @damage_layers */
  14,	/* @harmonic_view */
  14,	/* @needs_refresh */
  14,	/* @old_read_list */
  14,	/* @path_elements */
  14,	/* @sub_harmonics */
  14,	/* ALIGN_BASELINE */
  14,	/* ButtonInactive */
  14,	/* DirectoryMatch */
  14,	/* HighlightGrad1 */
  14,	/* HighlightGrad2 */
  14,	/* KeyBlackAccent */
  14,	/* KeyWhiteAccent */
  14,	/* LayoutConstBox */
  14,	/* LocalJumpError */
  14,	/* PATH_SEPARATOR */
  14,	/* RemoteMetadata */
  14,	/* ScrollInactive */
  14,	/* VisualDimTrans */
  14,	/* ZynControllers */
  14,	/* ZynEffectGroup */
  14,	/* ZynEffectsPart */
  14,	/* ZynFreqGeneral */
  14,	/* ZynPadOvertone */
  14,	/* ZynSubHarmonic */
  14,	/* __upto_endless */
  14,	/* _content_lines */
  14,	/* animation_fps= */
  14,	/* assert_not_nil */
  14,	/* background_fbo */
  14,	/* change_dir_abs */
  14,	/* change_dir_rel */
  14,	/* close_on_exec= */
  14,	/* close_on_exec? */
  14,	/* const_defined? */
  14,	/* createInstance */
  14,	/* delete_prefix! */
  14,	/* delete_suffix! */
  14,	/* different_file */
  14,	/* each_codepoint */
  14,	/* filter_widgets */
  14,	/* get_remote_url */
  14,	/* gl_clear_color */
  14,	/* gl_scissor_end */
  14,	/* highlight_pos= */
  14,	/* install_method */
  14,	/* interval_ratio */
  14,	/* last_match_end */
  14,	/* load_event_seq */
  14,	/* method_missing */
  14,	/* modlabelHeight */
  14,	/* named_captures */
  14,	/* norm_harmonics */
  14,	/* onMouseRelease */
  14,	/* over_highlight */
  14,	/* paragraph_mode */
  14,	/* pending_damage */
  14,	/* perform_layout */
  14,	/* proper_subset? */
  14,	/* readable_real? */
  14,	/* regen_children */
  14,	/* runtime_points */
  14,	/* scrollbar_size */
  14,	/* selected_layer */
  14,	/* set_active_kit */
  14,	/* set_kit_enable */
  14,	/* set_noise_mode */
  14,	/* set_value_user */
  14,	/* set_vis_filter */
  14,	/* single_compile */
  14,	/* smash_draw_seq */
  14,	/* strike_through */
  14,	/* sustain_point= */
  14,	/* test_unix_file */
  14,	/* test_window_cd */
  14,	/* tick_animation */
  14,	/* transform_keys */
  14,	/* tri_low_left_x */
  14,	/* tri_low_left_y */
  14,	/* try_patch_rdep */
  14,	/* update_ui_path */
  14,	/* updating_layer */
  14,	/* writable_real? */
  14,	/* write_property */
  15,	/* @active_buttons */
  15,	/* @background_fbo */
  15,	/* @background_img */
  15,	/* @common_draw_id */
  15,	/* @hotload_frames */
  15,	/* @pending_change */
  15,	/* @pending_layout */
  15,	/* @pending_resize */
  15,	/* DirectoriesOnly */
  15,	/* ENOTRECOVERABLE */
  15,	/* EPROTONOSUPPORT */
  15,	/* ESOCKTNOSUPPORT */
  15,	/* FileBrowserTest */
  15,	/* MRUBY_COPYRIGHT */
  15,	/* STENCIL_STROKES */
  15,	/* SliderVisActive */
  15,	/* SystemCallError */
  15,	/* TextActiveColor */
  15,	/* VisSubHarmonics */
  15,	/* VisualLightFill */
  15,	/* ZynAddVoiceList */
  15,	/* ZynAnalogFilter */
  15,	/* ZynBandwidthEnv */
  15,	/* ZynEffectBypass */
  15,	/* ZynHeaderParams */
  15,	/* ZynKitKeyButton */
  15,	/* ZynMidiLearnRow */
  15,	/* ZynOscilloscope */
  15,	/* ZynPadHarmonics */
  15,	/* ZynSubAmpbutton */
  15,	/* ZynSubBandwidth */
  15,	/* ZynSubFilterEnv */
  15,	/* _check_readable */
  15,	/* _content_lines= */
  15,	/* append_features */
  15,	/* automation_view */
  15,	/* clear_on_extern */
  15,	/* connect_watcher */
  15,	/* create_font_mem */
  15,	/* do_update_coeff */
  15,	/* each_with_index */
  15,	/* ensure_database */
  15,	/* handleCursorPos */
  15,	/* indirect_method */
  15,	/* initialize_copy */
  15,	/* install_context */
  15,	/* interval_ratio= */
  15,	/* linear_gradient */
  15,	/* load_scale_file */
  15,	/* method_defined? */
  15,	/* module_function */
  15,	/* pad_repetitions */
  15,	/* parse_unix_path */
  15,	/* partchannelRefs */
  15,	/* pending_damage= */
  15,	/* propigate_stale */
  15,	/* radial_gradient */
  15,	/* reset_transform */
  15,	/* runtime_points= */
  15,	/* setup_valuerefs */
  15,	/* source_location */
  15,	/* string_to_lines */
  15,	/* string_to_stats */
  15,	/* text_box_bounds */
  15,	/* transform_keys! */
  15,	/* tri_low_right_x */
  15,	/* tri_low_right_y */
  15,	/* under_highlight */
  15,	/* world_readable? */
  15,	/* world_writable? */
  16,	/* $damaged_classes */
  16,	/* @auto_apply_last */
  16,	/* @automation_view */
  16,	/* FilterHighlight1 */
  16,	/* FilterHighlight2 */
  16,	/* FloatDomainError */
  16,	/* HSliderKeySelect */
  16,	/* MRUBY_RELEASE_NO */
  16,	/* PropertyDatabase */
  16,	/* SliderBackground */
  16,	/* SystemStackError */
  16,	/* VisualBackground */
  16,	/* ZynEffectsInsert */
  16,	/* ZynEffectsSystem */
  16,	/* ZynOscilModRight */
  16,	/* ZynSubFreqbutton */
  16,	/* active_indicator */
  16,	/* background_color */
  16,	/* clear_on_extern= */
  16,	/* connect_property */
  16,	/* consume_arg_list */
  16,	/* create_image_mem */
  16,	/* create_new_child */
  16,	/* defaultMaxStages */
  16,	/* draw_color_wheel */
  16,	/* draw_placeholder */
  16,	/* executable_real? */
  16,	/* forget_all_state */
  16,	/* get_global_const */
  16,	/* handleMousePress */
  16,	/* install_database */
  16,	/* invalid_position */
  16,	/* num_visible_rows */
  16,	/* prepend_features */
  16,	/* proper_superset? */
  16,	/* remove_old_child */
  16,	/* text_break_lines */
  16,	/* text_line_height */
  16,	/* transform_values */
  16,	/* under_highlight= */
  16,	/* update_nonfree_x */
  16,	/* update_nonfree_y */
  17,	/* @active_indicator */
  17,	/* @animate_frame_dt */
  17,	/* @scheduled_events */
  17,	/* @stale_rdep_graph */
  17,	/* @transaction_nest */
  17,	/* ConstantDirectory */
  17,	/* GL_IMPLEMENTATION */
  17,	/* GeneralBackground */
  17,	/* MRUBY_DESCRIPTION */
  17,	/* ZeroDivisionError */
  17,	/* ZynAutomationName */
  17,	/* ZynAutomationPlot */
  17,	/* ZynAutomationSlot */
  17,	/* ZynMixerMasterCol */
  17,	/* ZynModFreqGeneral */
  17,	/* code_format_print */
  17,	/* consume_value_tok */
  17,	/* create_image_rgba */
  17,	/* current_transform */
  17,	/* defaultMaxStages= */
  17,	/* disable_kernel_io */
  17,	/* ensure_properties */
  17,	/* expand_path_array */
  17,	/* flush_word_buffer */
  17,	/* generate_children */
  17,	/* generational_mode */
  17,	/* get_list_from_int */
  17,	/* intersect_scissor */
  17,	/* punish_difference */
  17,	/* remove_properties */
  17,	/* test_windows_file */
  17,	/* text_line_height= */
  17,	/* transform_values! */
  17,	/* update_dependency */
  18,	/* HarmonicEditSingle */
  18,	/* MRUBY_RELEASE_DATE */
  18,	/* ZynAddOscilloscope */
  18,	/* ZynAmpVoiceGeneral */
  18,	/* ZynAutomationParam */
  18,	/* ZynPadOscilloscope */
  18,	/* ZynSubAnalogFilter */
  18,	/* ZynSubOscilloscope */
  18,	/* bound_to_temporary */
  18,	/* displayValueToText */
  18,	/* generational_mode= */
  18,	/* handleMouseRelease */
  18,	/* initialize_w_flags */
  18,	/* install_initialize */
  18,	/* joint_bounding_box */
  18,	/* load_qml_from_file */
  18,	/* make_draw_sequence */
  18,	/* opt_norm_harmonics */
  18,	/* parse_windows_path */
  18,	/* pending_change_cat */
  18,	/* sub_synth_response */
  18,	/* test_unix_add_char */
  18,	/* test_unix_set_home */
  18,	/* test_window_cd_alt */
  19,	/* @animate_frame_next */
  19,	/* BackgroundTextColor */
  19,	/* GL_COLOR_BUFFER_BIT */
  19,	/* GL_DEPTH_BUFFER_BIT */
  19,	/* IMAGE_PREMULTIPLIED */
  19,	/* NotImplementedError */
  19,	/* RUBY_ENGINE_VERSION */
  19,	/* ZynAddVoiceListItem */
  19,	/* ZynFreqGeneralVoice */
  19,	/* add_attr_connection */
  19,	/* build_qml_dep_graph */
  19,	/* consume_instruction */
  19,	/* old_square_brancket */
  19,	/* respond_to_missing? */
  19,	/* text_letter_spacing */
  20,	/* RecursiveDirectories */
  20,	/* end_load_transaction */
  20,	/* set_vis_oscilloscope */
  20,	/* text_glyph_positions */
  20,	/* text_letter_spacing= */
  21,	/* GL_STENCIL_BUFFER_BIT */
  21,	/* ZynAutomationMidiChan */
  21,	/* ZynInstrumentSettings */
  21,	/* __coerce_step_counter */
  21,	/* assert_nothing_raised */
  21,	/* compute_content_lines */
  21,	/* enumerator_block_call */
  21,	/* handle_pending_layout */
  21,	/* handle_pending_resize */
  21,	/* instance_variable_get */
  21,	/* test_windows_set_home */
  21,	/* think_of_the_children */
  21,	/* update_path_recursive */
  22,	/* IMAGE_GENERATE_MIPMAPS */
  22,	/* convert_partial_to_dir */
  22,	/* singleton_method_added */
  22,	/* start_load_transaction */
  23,	/* _replace_back_reference */
  23,	/* formant_filter_response */
  23,	/* mruby_qml_parse_test_ir */
  23,	/* mruby_qml_parse_test_vm */
  23,	/* power_sign_stroke_color */
  24,	/* get_enable_option_string */
  24,	/* make_draw_sequence_recur */
  24,	/* remove_instance_variable */
  25,	/* StartRecursiveDirectories */
  25,	/* copy_current_transform_to */
  25,	/* get_disable_option_string */
  25,	/* test_windows_change_drive */
  26,	/* mruby_qml_parse_test_parse */
  28,	/* text_glyph_positions_yielded */
  72,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/enum.rb */
  72,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/hash.rb */
  73,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/array.rb */
  73,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/range.rb */
  74,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/compar.rb */
  74,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/kernel.rb */
  74,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/string.rb */
  74,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/symbol.rb */
  75,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/00class.rb */
  75,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/10error.rb */
  75,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/numeric.rb */
  80,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir/mrblib/dir.rb */
  80,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/osc.rb */
  81,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/util.rb */
  82,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/build.rb */
  84,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-set/mrblib/mrb_set.rb */
  85,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir-glob/mrblib/dir.rb */
  85,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/color.rb */
  86,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-file-stat/mrblib/ext.rb */
  86,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/nanovg.rb */
  86,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/test.rb */
  86,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/pos.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/context.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-process/mrblib/status.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/build.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/rect.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/util.rb */
  87,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/colorwheel.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-process/mrblib/process.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/parser.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/loader.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/sched.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/draw-common.rb */
  88,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/macro-state.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/transform.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/prog-ir.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/prog-vm.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/fcache.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/layout.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/remote.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/script.rb */
  89,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/file-browser.rb */
  90,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir-glob/mrblib/dir_glob.rb */
  90,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/database.rb */
  91,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/font_handle.rb */
  91,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb */
  91,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-time/mrblib/time.rb */
  91,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/ui-event.rb */
  92,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-file-stat/mrblib/file-stat.rb */
  92,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/image_handle.rb */
  92,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/react-attr.rb */
  93,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-print/mrblib/print.rb */
  93,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/parse-types.rb */
  95,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-hash-ext/mrblib/hash.rb */
  95,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-proc-ext/mrblib/proc.rb */
  95,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/time-profile.rb */
  96,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-regexp-pcre/mrblib/regexp_pcre.rb */
  96,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-regexp-pcre/mrblib/string_pcre.rb */
  96,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-sprintf/mrblib/string.rb */
  96,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/draw-sequence.rb */
  97,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-array-ext/mrblib/array.rb */
  99,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file_constants.rb */
  99,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-object-ext/mrblib/object.rb */
  99,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-string-ext/mrblib/string.rb */
  103,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-enumerator/mrblib/enumerator.rb */
  103,	/* /build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-toplevel-ext/mrblib/toplevel.rb */
};

static const char * const presym_name_table[] = {
  "!",
  "%",
  "&",
  "*",
  "+",
  "-",
  "/",
  "<",
  ">",
  "E",
  "^",
  "_",
  "`",
  "a",
  "b",
  "c",
  "d",
  "e",
  "f",
  "g",
  "h",
  "i",
  "j",
  "k",
  "l",
  "m",
  "n",
  "o",
  "p",
  "q",
  "r",
  "s",
  "t",
  "u",
  "v",
  "w",
  "x",
  "y",
  "z",
  "|",
  "~",
  "!=",
  "!~",
  "$$",
  "$&",
  "$'",
  "$0",
  "$?",
  "$`",
  "$~",
  "&&",
  "**",
  "+@",
  "-@",
  "<<",
  "<=",
  "==",
  "=~",
  ">=",
  ">>",
  "@h",
  "@q",
  "@t",
  "@w",
  "@x",
  "@y",
  "AA",
  "AM",
  "CA",
  "CC",
  "CI",
  "CW",
  "EC",
  "EI",
  "GC",
  "GL",
  "IO",
  "IR",
  "PI",
  "SA",
  "SC",
  "SP",
  "[]",
  "a0",
  "a1",
  "a=",
  "aa",
  "ar",
  "at",
  "aw",
  "ax",
  "ay",
  "b=",
  "bb",
  "bg",
  "bh",
  "bi",
  "br",
  "bs",
  "bt",
  "bw",
  "bx",
  "by",
  "c1",
  "c2",
  "c=",
  "cb",
  "cc",
  "ch",
  "ci",
  "cl",
  "co",
  "cs",
  "cv",
  "cx",
  "cy",
  "d2",
  "d=",
  "db",
  "dp",
  "dt",
  "dv",
  "dx",
  "dy",
  "e=",
  "e_",
  "ed",
  "ei",
  "eq",
  "ev",
  "f=",
  "fd",
  "fn",
  "fo",
  "fr",
  "fs",
  "g=",
  "gc",
  "gm",
  "h=",
  "hc",
  "hf",
  "hh",
  "hl",
  "hm",
  "id",
  "ii",
  "im",
  "in",
  "io",
  "ir",
  "kk",
  "kr",
  "la",
  "lb",
  "le",
  "lh",
  "li",
  "ll",
  "lm",
  "ln",
  "lp",
  "lu",
  "m1",
  "m2",
  "m3",
  "md",
  "mm",
  "mn",
  "ms",
  "mw",
  "mx",
  "my",
  "n2",
  "nd",
  "nk",
  "nn",
  "nt",
  "nv",
  "of",
  "on",
  "oo",
  "op",
  "p1",
  "p2",
  "p3",
  "pb",
  "pc",
  "ph",
  "pi",
  "pp",
  "pr",
  "ps",
  "pt",
  "pw",
  "px",
  "py",
  "r0",
  "r1",
  "r=",
  "re",
  "rf",
  "ri",
  "rr",
  "rs",
  "rt",
  "rw",
  "ry",
  "sh",
  "sn",
  "ss",
  "sv",
  "sw",
  "sx",
  "sy",
  "t1",
  "t2",
  "t3",
  "t4",
  "t5",
  "tb",
  "te",
  "th",
  "tp",
  "tr",
  "tw",
  "tx",
  "ty",
  "ul",
  "up",
  "ur",
  "v1",
  "v2",
  "va",
  "vg",
  "vo",
  "vr",
  "vs",
  "vv",
  "vw",
  "w=",
  "wb",
  "wc",
  "wd",
  "wf",
  "wp",
  "ww",
  "x1",
  "x2",
  "x=",
  "xc",
  "xf",
  "xm",
  "xp",
  "xx",
  "y1",
  "y2",
  "y=",
  "yc",
  "yf",
  "ym",
  "yp",
  "yt",
  "yy",
  "||",
  "$vg",
  "<=>",
  "===",
  "@IR",
  "@cc",
  "@db",
  "@dx",
  "@dy",
  "@eq",
  "@ev",
  "@fn",
  "@hm",
  "@id",
  "@ir",
  "@lp",
  "@mx",
  "@my",
  "@rw",
  "@sx",
  "@sy",
  "@tb",
  "@vg",
  "@vv",
  "ALT",
  "CCW",
  "Col",
  "DSP",
  "Dir",
  "EIO",
  "FBO",
  "NAN",
  "NVG",
  "OSC",
  "Osc",
  "Pos",
  "Qml",
  "Set",
  "TID",
  "[]=",
  "_bx",
  "_by",
  "_lx",
  "_ly",
  "_rx",
  "_ry",
  "_ux",
  "_uy",
  "abs",
  "act",
  "add",
  "all",
  "alt",
  "amp",
  "ani",
  "app",
  "arc",
  "arg",
  "arp",
  "arr",
  "ary",
  "avg",
  "bar",
  "bb1",
  "bb2",
  "bbl",
  "bbs",
  "beg",
  "bg=",
  "bid",
  "blk",
  "bnd",
  "bot",
  "box",
  "but",
  "bx1",
  "bx2",
  "bx3",
  "by1",
  "by2",
  "by3",
  "cap",
  "cat",
  "cc=",
  "cch",
  "chd",
  "chr",
  "clr",
  "cls",
  "cmd",
  "cmp",
  "cnt",
  "col",
  "cos",
  "cpy",
  "ctx",
  "dat",
  "day",
  "db=",
  "del",
  "dem",
  "dev",
  "dig",
  "dim",
  "dir",
  "div",
  "dmg",
  "dne",
  "dsp",
  "dst",
  "dt_",
  "dup",
  "dyn",
  "eff",
  "elm",
  "end",
  "ent",
  "env",
  "eof",
  "erf",
  "err",
  "evs",
  "exp",
  "ext",
  "fav",
  "fbo",
  "fib",
  "fil",
  "fin",
  "fn=",
  "foo",
  "gap",
  "gen",
  "gid",
  "hes",
  "hex",
  "hl=",
  "hsl",
  "hue",
  "ids",
  "idx",
  "img",
  "ind",
  "ino",
  "ins",
  "inx",
  "ist",
  "key",
  "kid",
  "kit",
  "lab",
  "len",
  "let",
  "lfo",
  "lhs",
  "lim",
  "lir",
  "log",
  "low",
  "mag",
  "map",
  "max",
  "mch",
  "mid",
  "min",
  "mmm",
  "mod",
  "mon",
  "new",
  "nhr",
  "now",
  "num",
  "nxt",
  "obj",
  "oct",
  "off",
  "old",
  "opt",
  "ord",
  "osc",
  "out",
  "p1=",
  "p2=",
  "pad",
  "par",
  "pat",
  "pdb",
  "pid",
  "pir",
  "pop",
  "pos",
  "pow",
  "prt",
  "pts",
  "pwd",
  "qid",
  "quo",
  "red",
  "ref",
  "rel",
  "rem",
  "req",
  "res",
  "ret",
  "rgb",
  "rhs",
  "rnd",
  "row",
  "run",
  "rw2",
  "sec",
  "sel",
  "sep",
  "seq",
  "set",
  "sin",
  "src",
  "srt",
  "st0",
  "st1",
  "st2",
  "st3",
  "str",
  "sub",
  "sum",
  "sup",
  "sus",
  "sym",
  "tab",
  "tan",
  "tap",
  "te1",
  "te2",
  "te3",
  "te4",
  "tic",
  "tmp",
  "toc",
  "tok",
  "top",
  "tot",
  "tr!",
  "typ",
  "uid",
  "url",
  "use",
  "utc",
  "val",
  "vce",
  "vel",
  "vis",
  "wah",
  "wid",
  "win",
  "x_b",
  "x_m",
  "xc=",
  "xsp",
  "y_b",
  "y_m",
  "yc=",
  "zip",
  "@add",
  "@amp",
  "@app",
  "@arp",
  "@avg",
  "@bot",
  "@box",
  "@buf",
  "@but",
  "@cat",
  "@clr",
  "@col",
  "@cpy",
  "@del",
  "@dep",
  "@dir",
  "@dst",
  "@dyn",
  "@eff",
  "@env",
  "@ext",
  "@fib",
  "@fil",
  "@gen",
  "@hes",
  "@hue",
  "@key",
  "@kit",
  "@lfo",
  "@lhs",
  "@mod",
  "@nhr",
  "@num",
  "@obj",
  "@oct",
  "@opt",
  "@pid",
  "@pos",
  "@pow",
  "@qid",
  "@ref",
  "@rhs",
  "@rnd",
  "@row",
  "@rw2",
  "@sep",
  "@seq",
  "@str",
  "@sub",
  "@sus",
  "@te1",
  "@te2",
  "@te3",
  "@te4",
  "@top",
  "@typ",
  "@url",
  "@vel",
  "@vis",
  "@wah",
  "ARGV",
  "BUTT",
  "CTRL",
  "Draw",
  "EADV",
  "EDOM",
  "EXCL",
  "File",
  "Glob",
  "Grid",
  "HOLE",
  "Hash",
  "Knob",
  "Math",
  "Menu",
  "NONE",
  "NULL",
  "Node",
  "PUGL",
  "Path",
  "Proc",
  "RDWR",
  "Rect",
  "SYNC",
  "Stat",
  "Test",
  "Text",
  "Time",
  "Unit",
  "_dev",
  "abbv",
  "acos",
  "add=",
  "add?",
  "aeps",
  "all?",
  "ampl",
  "any?",
  "appl",
  "arg0",
  "arg1",
  "arg2",
  "args",
  "argv",
  "asin",
  "atan",
  "attr",
  "back",
  "bank",
  "base",
  "bbox",
  "best",
  "blue",
  "bold",
  "bsiz",
  "byte",
  "call",
  "cang",
  "cbrt",
  "ceil",
  "chan",
  "char",
  "chop",
  "circ",
  "code",
  "cols",
  "comb",
  "conn",
  "copy",
  "cosh",
  "ctrl",
  "curr",
  "cval",
  "data",
  "demo",
  "dest",
  "dirs",
  "dist",
  "down",
  "draw",
  "drum",
  "dst?",
  "dump",
  "dval",
  "e_id",
  "each",
  "echo",
  "edit",
  "egrp",
  "elem",
  "emit",
  "end_",
  "enum",
  "eof?",
  "epos",
  "epri",
  "eql?",
  "erfc",
  "estr",
  "eval",
  "excl",
  "exit",
  "exp1",
  "exp2",
  "ext1",
  "ext2",
  "ext=",
  "fade",
  "favs",
  "feed",
  "ff_h",
  "ff_w",
  "ff_x",
  "ff_y",
  "file",
  "fill",
  "filt",
  "find",
  "fine",
  "flag",
  "font",
  "foot",
  "fork",
  "free",
  "freq",
  "full",
  "func",
  "fv_h",
  "fv_w",
  "fv_x",
  "fv_y",
  "fval",
  "gain",
  "getc",
  "gets",
  "glob",
  "gmt?",
  "gold",
  "grad",
  "grep",
  "grid",
  "gsub",
  "harm",
  "hash",
  "head",
  "high",
  "hit?",
  "home",
  "hour",
  "hpad",
  "hsla",
  "idx2",
  "idx=",
  "inds",
  "info",
  "init",
  "inst",
  "item",
  "join",
  "key?",
  "keys",
  "kill",
  "kits",
  "knob",
  "lary",
  "last",
  "lbut",
  "left",
  "lidx",
  "line",
  "list",
  "log2",
  "logo",
  "loop",
  "lval",
  "map!",
  "mapp",
  "max_",
  "mday",
  "menu",
  "mesg",
  "meta",
  "meth",
  "min_",
  "mod=",
  "mode",
  "mono",
  "moog",
  "move",
  "mval",
  "name",
  "nan?",
  "nbox",
  "ndep",
  "nest",
  "next",
  "nil?",
  "node",
  "noff",
  "none",
  "note",
  "num=",
  "nval",
  "objs",
  "off=",
  "offs",
  "oldi",
  "oldl",
  "oldr",
  "olds",
  "open",
  "opts",
  "orig",
  "oval",
  "pack",
  "pad1",
  "pad2",
  "pad=",
  "padh",
  "padw",
  "pars",
  "part",
  "pat=",
  "path",
  "pbox",
  "pbvm",
  "peek",
  "perm",
  "pipe",
  "plen",
  "plot",
  "poll",
  "port",
  "pos2",
  "pos=",
  "ppid",
  "prev",
  "proc",
  "prog",
  "prop",
  "pset",
  "push",
  "puts",
  "pval",
  "q_ir",
  "quit",
  "rand",
  "rdev",
  "read",
  "rect",
  "recv",
  "refs",
  "relx",
  "rely",
  "rest",
  "rgba",
  "rgbf",
  "ridx",
  "root",
  "ropt",
  "row1",
  "row2",
  "row3",
  "rows",
  "rseq",
  "rval",
  "sans",
  "save",
  "scan",
  "seek",
  "seen",
  "send",
  "setf",
  "seti",
  "sets",
  "sheq",
  "side",
  "sine",
  "sinh",
  "size",
  "skip",
  "slot",
  "snsa",
  "snsb",
  "sort",
  "spin",
  "sqrt",
  "stat",
  "stem",
  "step",
  "stop",
  "str2",
  "sub!",
  "succ",
  "supe",
  "swap",
  "sym=",
  "sync",
  "tabs",
  "tanh",
  "te1=",
  "tell",
  "test",
  "text",
  "tgrp",
  "then",
  "this",
  "tick",
  "time",
  "to_a",
  "to_f",
  "to_h",
  "to_i",
  "to_s",
  "tr_s",
  "tty?",
  "tune",
  "tval",
  "type",
  "uniq",
  "upto",
  "usec",
  "user",
  "utc?",
  "vals",
  "vfor",
  "vgrp",
  "view",
  "vis=",
  "vpad",
  "vpow",
  "wNew",
  "wOld",
  "warp",
  "wave",
  "wday",
  "weak",
  "widg",
  "xdat",
  "xmin",
  "xoff",
  "xpad",
  "xpts",
  "ydat",
  "yday",
  "year",
  "yloc",
  "ymin",
  "yoff",
  "ypos",
  "ypts",
  "zone",
  "@ampl",
  "@appl",
  "@args",
  "@bank",
  "@base",
  "@chan",
  "@code",
  "@copy",
  "@ctrl",
  "@data",
  "@demo",
  "@dirs",
  "@drum",
  "@echo",
  "@edit",
  "@egrp",
  "@favs",
  "@file",
  "@filt",
  "@font",
  "@foot",
  "@free",
  "@freq",
  "@full",
  "@func",
  "@gain",
  "@glob",
  "@harm",
  "@hash",
  "@head",
  "@info",
  "@init",
  "@item",
  "@knob",
  "@last",
  "@lbut",
  "@line",
  "@logo",
  "@mapp",
  "@menu",
  "@meth",
  "@mode",
  "@name",
  "@next",
  "@objs",
  "@part",
  "@path",
  "@plot",
  "@port",
  "@prev",
  "@proc",
  "@pset",
  "@refs",
  "@row1",
  "@row2",
  "@row3",
  "@side",
  "@slot",
  "@snsa",
  "@snsb",
  "@swap",
  "@test",
  "@text",
  "@tgrp",
  "@this",
  "@tune",
  "@type",
  "@unix",
  "@vfor",
  "@vgrp",
  "@vpow",
  "@wave",
  "Align",
  "Array",
  "BEVEL",
  "CREAT",
  "Class",
  "Color",
  "DEBUG",
  "DSYNC",
  "E2BIG",
  "EAUTH",
  "EBADE",
  "EBADF",
  "EBADR",
  "EBUSY",
  "ECOMM",
  "EFBIG",
  "EIDRM",
  "EINTR",
  "ELOOP",
  "ENOSR",
  "ENXIO",
  "EPERM",
  "EPIPE",
  "EROFS",
  "ESRCH",
  "ETIME",
  "EXDEV",
  "Errno",
  "Fiber",
  "Float",
  "Forms",
  "Group",
  "MITER",
  "MRuby",
  "Match",
  "Paint",
  "ROUND",
  "RSYNC",
  "Range",
  "SHIFT",
  "SOLID",
  "STDIN",
  "SUPER",
  "Sched",
  "TFunc",
  "TInst",
  "TProp",
  "TRUNC",
  "Theme",
  "VisEq",
  "_mode",
  "_pipe",
  "_rdev",
  "about",
  "abs_x",
  "abs_y",
  "acosh",
  "align",
  "alpha",
  "aname",
  "angle",
  "appl=",
  "apply",
  "args=",
  "arity",
  "array",
  "ary_F",
  "ary_T",
  "asinh",
  "assoc",
  "atan2",
  "atanh",
  "atime",
  "bank=",
  "banks",
  "base=",
  "begin",
  "black",
  "blist",
  "block",
  "bound",
  "boxes",
  "breal",
  "bytes",
  "capts",
  "chBox",
  "ch_id",
  "chars",
  "chdir",
  "check",
  "child",
  "chmod",
  "chomp",
  "chop!",
  "chunk",
  "class",
  "clean",
  "clear",
  "clone",
  "close",
  "cname",
  "coeff",
  "color",
  "cols=",
  "coral",
  "count",
  "ctime",
  "curry",
  "cvt_x",
  "cvt_y",
  "data=",
  "data_",
  "debug",
  "delay",
  "delta",
  "depth",
  "doRun",
  "draw1",
  "draw2",
  "drum=",
  "dummy",
  "emode",
  "errno",
  "event",
  "exit!",
  "exit?",
  "extfm",
  "extra",
  "fancy",
  "favs=",
  "fbase",
  "fetch",
  "ff_x2",
  "field",
  "file=",
  "file?",
  "files",
  "first",
  "fixed",
  "flags",
  "float",
  "flock",
  "floor",
  "flush",
  "fname",
  "forms",
  "found",
  "frame",
  "frexp",
  "front",
  "ftype",
  "fv_w2",
  "fv_x2",
  "gbl_h",
  "gbl_w",
  "getgm",
  "getwd",
  "grad1",
  "grad2",
  "green",
  "grid=",
  "gridt",
  "gsub!",
  "head1",
  "hedit",
  "hfill",
  "hpack",
  "hypot",
  "ident",
  "image",
  "impl=",
  "index",
  "info=",
  "inner",
  "input",
  "is_a?",
  "label",
  "lastx",
  "lasty",
  "layer",
  "ldexp",
  "learn",
  "level",
  "limit",
  "lines",
  "ljust",
  "loc_x",
  "local",
  "log10",
  "log_x",
  "log_y",
  "lsize",
  "lstat",
  "macro",
  "match",
  "max_x",
  "max_y",
  "merge",
  "meter",
  "micro",
  "min_x",
  "min_y",
  "mixer",
  "mkdir",
  "mockx",
  "mocky",
  "mode=",
  "monof",
  "month",
  "mouse",
  "mtime",
  "names",
  "next!",
  "nlink",
  "noise",
  "nopts",
  "npath",
  "nrows",
  "nsize",
  "ntype",
  "old_x",
  "oldcc",
  "omega",
  "onKey",
  "order",
  "oscil",
  "other",
  "outer",
  "padh2",
  "padw2",
  "paint",
  "panic",
  "param",
  "parts",
  "paste",
  "phase",
  "pipe?",
  "place",
  "plist",
  "polar",
  "popen",
  "power",
  "ppath",
  "pproc",
  "pread",
  "press",
  "prev=",
  "prime",
  "print",
  "props",
  "pxpad",
  "quote",
  "raise",
  "range",
  "ratio",
  "reads",
  "reset",
  "reson",
  "rgbaf",
  "rharm",
  "right",
  "rjust",
  "rmdir",
  "round",
  "rows=",
  "rwbox",
  "scale",
  "sched",
  "setrw",
  "settf",
  "setup",
  "shape",
  "shift",
  "size=",
  "size?",
  "skip=",
  "sleep",
  "slice",
  "slide",
  "slots",
  "solve",
  "sort!",
  "space",
  "spin=",
  "split",
  "spork",
  "srand",
  "stack",
  "stale",
  "start",
  "state",
  "stats",
  "store",
  "strip",
  "style",
  "subbw",
  "subfl",
  "subfq",
  "succ!",
  "super",
  "swapp",
  "sync=",
  "tabid",
  "term?",
  "thick",
  "throw",
  "time=",
  "times",
  "title",
  "toPos",
  "to_dB",
  "todel",
  "topOf",
  "top_h",
  "top_w",
  "top_x",
  "top_y",
  "total",
  "tr_s!",
  "tramp",
  "trans",
  "type=",
  "types",
  "umask",
  "union",
  "uniq!",
  "units",
  "updir",
  "value",
  "vfill",
  "vline",
  "voice",
  "vpack",
  "watch",
  "wheel",
  "width",
  "write",
  "xdiff",
  "xform",
  "xnorm",
  "xskip",
  "yaxis",
  "ydiff",
  "yield",
  "zero?",
  "$DEBUG",
  "$sched",
  "$stdin",
  "@aname",
  "@atime",
  "@boxes",
  "@cc_id",
  "@class",
  "@close",
  "@ctime",
  "@depth",
  "@extfm",
  "@fancy",
  "@fbase",
  "@field",
  "@files",
  "@flags",
  "@forms",
  "@frame",
  "@head1",
  "@hedit",
  "@ident",
  "@image",
  "@input",
  "@lastw",
  "@layer",
  "@learn",
  "@lines",
  "@meter",
  "@micro",
  "@mixer",
  "@modal",
  "@names",
  "@panic",
  "@param",
  "@paste",
  "@phase",
  "@plist",
  "@ppath",
  "@props",
  "@reson",
  "@row_h",
  "@rwbox",
  "@scale",
  "@setup",
  "@slide",
  "@slots",
  "@stale",
  "@state",
  "@subbw",
  "@subfl",
  "@subfq",
  "@swapp",
  "@title",
  "@total",
  "@value",
  "@wheel",
  "@width",
  "@yaxis",
  "APPEND",
  "BINARY",
  "Button",
  "DIRECT",
  "EACCES",
  "EAGAIN",
  "EBADFD",
  "EBFONT",
  "ECHILD",
  "ECHRNG",
  "EDQUOT",
  "EEXIST",
  "EFAULT",
  "EFTYPE",
  "EILSEQ",
  "EINVAL",
  "EIPSEC",
  "EISDIR",
  "EISNAM",
  "EL2HLT",
  "EL3HLT",
  "EL3RST",
  "ELNRNG",
  "EMFILE",
  "EMLINK",
  "ENFILE",
  "ENOANO",
  "ENOCSI",
  "ENODEV",
  "ENOENT",
  "ENOKEY",
  "ENOLCK",
  "ENOMEM",
  "ENOMSG",
  "ENONET",
  "ENOPKG",
  "ENOSPC",
  "ENOSTR",
  "ENOSYS",
  "ENOTTY",
  "EPROTO",
  "ERANGE",
  "ESPIPE",
  "ESRMNT",
  "ESTALE",
  "EUSERS",
  "EXFULL",
  "Fixnum",
  "Indent",
  "IrNode",
  "Kernel",
  "Layout",
  "LfoVis",
  "Module",
  "NOCTTY",
  "Nanovg",
  "NumBox",
  "Object",
  "Parser",
  "ProgIR",
  "ProgVM",
  "RDONLY",
  "Random",
  "Record",
  "Regexp",
  "Remote",
  "SQUARE",
  "STDERR",
  "STDOUT",
  "Slider",
  "States",
  "Status",
  "String",
  "Symbol",
  "TLocal",
  "VGroup",
  "WRONLY",
  "Widget",
  "Window",
  "ZynKit",
  "ZynLFO",
  "ZynWip",
  "__id__",
  "_chdir",
  "_getwd",
  "_mtime",
  "_popen",
  "action",
  "active",
  "addFav",
  "add_cb",
  "align=",
  "alive?",
  "amount",
  "analog",
  "append",
  "arc_to",
  "aspect",
  "avg_hz",
  "blocks",
  "border",
  "bottom",
  "bounds",
  "braces",
  "bright",
  "button",
  "cancel",
  "cc_num",
  "cctype",
  "center",
  "change",
  "chomp!",
  "chorus",
  "chroot",
  "circle",
  "clrFav",
  "coeff=",
  "colors",
  "concat",
  "cumsum",
  "curOff",
  "cursor",
  "damage",
  "delete",
  "depth=",
  "dest_x",
  "dest_y",
  "detect",
  "divide",
  "divmod",
  "doBank",
  "doLoad",
  "doSave",
  "doTest",
  "doType",
  "domain",
  "downto",
  "ec_key",
  "emode=",
  "empty?",
  "enable",
  "equal?",
  "escape",
  "events",
  "except",
  "exist?",
  "extend",
  "extent",
  "extern",
  "extmod",
  "extval",
  "fbase=",
  "fields",
  "fileno",
  "filter",
  "finish",
  "fixpad",
  "flavor",
  "footer",
  "for_fd",
  "format",
  "frames",
  "freeze",
  "gbl_cx",
  "gbl_cy",
  "genBox",
  "gensym",
  "getutc",
  "global",
  "gmtime",
  "handle",
  "header",
  "height",
  "hscale",
  "ifnone",
  "ignore",
  "image=",
  "indent",
  "index=",
  "inject",
  "input=",
  "insefx",
  "insert",
  "insset",
  "intern",
  "invert",
  "isatty",
  "itself",
  "kitnum",
  "label=",
  "labels",
  "lambda",
  "layer=",
  "layers",
  "layout",
  "lbrace",
  "length",
  "lines=",
  "loadIR",
  "loader",
  "longer",
  "lookup",
  "lsize=",
  "lstrip",
  "mapper",
  "match?",
  "maxkey",
  "maxlen",
  "member",
  "merge!",
  "method",
  "min_db",
  "minkey",
  "mktime",
  "modosc",
  "modsel",
  "names2",
  "noise=",
  "normal",
  "noteOn",
  "nrows=",
  "numBox",
  "number",
  "nunits",
  "nvalue",
  "nvowel",
  "object",
  "octave",
  "offset",
  "oldOff",
  "old_aw",
  "oldctx",
  "on_dir",
  "oscill",
  "outbuf",
  "outer=",
  "owned?",
  "p_code",
  "p_draw",
  "p_poll",
  "p_swap",
  "padstr",
  "parent",
  "path_1",
  "path_2",
  "path_3",
  "path_4",
  "path_5",
  "path_6",
  "path_7",
  "path_8",
  "path_9",
  "period",
  "phase=",
  "phaser",
  "points",
  "pos_id",
  "ppath=",
  "printf",
  "prtefx",
  "public",
  "pwrite",
  "pxpad=",
  "qml_ir",
  "radial",
  "radius",
  "rampup",
  "random",
  "rap2dB",
  "rassoc",
  "rbrace",
  "reader",
  "recalc",
  "record",
  "rect_h",
  "rect_w",
  "rect_x",
  "rect_y",
  "reduce",
  "regexp",
  "region",
  "rehash",
  "reject",
  "reload",
  "remote",
  "rename",
  "render",
  "resize",
  "resopt",
  "result",
  "resume",
  "reverb",
  "rewind",
  "rindex",
  "rotate",
  "row_id",
  "rstrip",
  "runner",
  "sample",
  "scale!",
  "scalex",
  "scroll",
  "search",
  "select",
  "setTab",
  "set_cc",
  "shift=",
  "skew_x",
  "skew_y",
  "slice!",
  "slider",
  "source",
  "space?",
  "spacer",
  "splice",
  "square",
  "stages",
  "stale=",
  "startt",
  "state=",
  "status",
  "stride",
  "string",
  "strip!",
  "stroke",
  "style=",
  "subamp",
  "subobj",
  "substr",
  "sysefx",
  "system",
  "tab_id",
  "tabbox",
  "title=",
  "titleH",
  "titleW",
  "to_int",
  "to_str",
  "to_sym",
  "toggle",
  "top_w2",
  "top_x2",
  "top_y2",
  "transf",
  "ungetc",
  "units=",
  "unlink",
  "unpack",
  "upcase",
  "update",
  "value=",
  "value?",
  "values",
  "velrnd",
  "vis_eq",
  "visual",
  "vlimit",
  "voices",
  "vowels",
  "vphase",
  "vstack",
  "weight",
  "wheel=",
  "whence",
  "white1",
  "white2",
  "widget",
  "width=",
  "widths",
  "window",
  "wscale",
  "wtitle",
  "xform=",
  "$remote",
  "$stderr",
  "$stdout",
  "@button",
  "@cctype",
  "@center",
  "@chorus",
  "@chrcls",
  "@cur_id",
  "@damage",
  "@events",
  "@extmod",
  "@fields",
  "@filter",
  "@footer",
  "@header",
  "@ignore",
  "@indent",
  "@insset",
  "@labels",
  "@maxkey",
  "@member",
  "@minkey",
  "@modsel",
  "@numBox",
  "@offset",
  "@oscill",
  "@phaser",
  "@points",
  "@pos_id",
  "@radial",
  "@regexp",
  "@resopt",
  "@reverb",
  "@scroll",
  "@search",
  "@slider",
  "@source",
  "@stages",
  "@status",
  "@stream",
  "@string",
  "@subamp",
  "@subobj",
  "@titleW",
  "@toggle",
  "@vis_eq",
  "@vlimit",
  "@voices",
  "@widget",
  "@widths",
  "@window",
  "BankOdd",
  "Binding",
  "Complex",
  "Context",
  "DEFAULT",
  "EBADMSG",
  "EBADRPC",
  "EBADRQC",
  "EBADSLT",
  "EDEADLK",
  "EDOOFUS",
  "EDOTDOT",
  "EISCONN",
  "ELIBACC",
  "ELIBBAD",
  "ELIBMAX",
  "ELIBSCN",
  "ENAVAIL",
  "ENOATTR",
  "ENOBUFS",
  "ENODATA",
  "ENOEXEC",
  "ENOLINK",
  "ENOTBLK",
  "ENOTDIR",
  "ENOTNAM",
  "ENOTSUP",
  "EREMCHG",
  "EREMOTE",
  "ERFKILL",
  "ETXTBSY",
  "EUCLEAN",
  "EUNATCH",
  "Formant",
  "GradBox",
  "HSlider",
  "HotLoad",
  "IOError",
  "Integer",
  "LOCK_EX",
  "LOCK_NB",
  "LOCK_SH",
  "LOCK_UN",
  "LineCap",
  "NOATIME",
  "NOERROR",
  "NO_FLAG",
  "Numeric",
  "PathElm",
  "Pokemon",
  "Process",
  "Special",
  "TAssign",
  "TExtend",
  "TImport",
  "TMPFILE",
  "TestExt",
  "TextBox",
  "TextSel",
  "VSlider",
  "VuMeter",
  "WNOHANG",
  "Winding",
  "Yielder",
  "ZRunner",
  "ZynBank",
  "ZynEcho",
  "ZynLLFO",
  "ZynLogo",
  "ZynPart",
  "__lines",
  "abs_sum",
  "action=",
  "active=",
  "add_cat",
  "add_dir",
  "addbase",
  "amp_env",
  "amp_gen",
  "amp_lfo",
  "amplBox",
  "animate",
  "any_kit",
  "ary_max",
  "ary_sum",
  "asctime",
  "aspect2",
  "au_plot",
  "authbox",
  "basemod",
  "blksize",
  "browser",
  "bsearch",
  "buttBox",
  "buttons",
  "casecmp",
  "cb_item",
  "cb_list",
  "channel",
  "closed?",
  "cls_def",
  "collect",
  "command",
  "commbox",
  "compact",
  "compile",
  "consume",
  "content",
  "context",
  "cpy_but",
  "curOff=",
  "cur_end",
  "current",
  "damaged",
  "default",
  "del_set",
  "delete!",
  "delete?",
  "depends",
  "destroy",
  "details",
  "dirname",
  "disable",
  "doMerge",
  "doSetup",
  "do_norm",
  "draw_id",
  "ebutton",
  "effects",
  "ellipse",
  "enable=",
  "entries",
  "envlope",
  "ev_prop",
  "ev_type",
  "exists?",
  "exited?",
  "explore",
  "extbase",
  "extent=",
  "extern=",
  "extname",
  "feather",
  "fields=",
  "fil_sel",
  "filtBox",
  "filter!",
  "filters",
  "finite?",
  "fixpad=",
  "flatten",
  "flavor=",
  "fnmatch",
  "folders",
  "for_num",
  "foreach",
  "formant",
  "format=",
  "freqBox",
  "friday?",
  "frozen?",
  "funcpar",
  "get_dep",
  "get_kit",
  "get_tab",
  "getaddr",
  "getbyte",
  "getport",
  "headBox",
  "header=",
  "height=",
  "heights",
  "in_test",
  "include",
  "indexes",
  "init_gl",
  "ins_sel",
  "inspect",
  "invalid",
  "inverse",
  "keep_if",
  "key_mod",
  "keyrest",
  "kitedit",
  "kitnum=",
  "labels=",
  "lambda?",
  "lfo_mod",
  "lfo_vis",
  "limited",
  "line_to",
  "lstrip!",
  "map_or!",
  "mapping",
  "matches",
  "maximum",
  "member?",
  "message",
  "methods",
  "miniBox",
  "minimum",
  "modules",
  "monday?",
  "move_to",
  "nactive",
  "namebox",
  "needles",
  "new_dsp",
  "new_key",
  "normal=",
  "noteOff",
  "numbBox",
  "number=",
  "nunits=",
  "nvowels",
  "nwidget",
  "obj_ids",
  "octave=",
  "offset=",
  "oldOff=",
  "old_dsp",
  "old_sub",
  "onMerge",
  "onSetup",
  "onWrite",
  "opt_bar",
  "options",
  "oscill=",
  "overlay",
  "p_total",
  "pad_but",
  "padding",
  "parent=",
  "partial",
  "path_10",
  "pattern",
  "period=",
  "pointer",
  "points=",
  "pp_info",
  "prepend",
  "private",
  "produce",
  "program",
  "pst_but",
  "pstring",
  "punish2",
  "q_value",
  "quad_to",
  "radius=",
  "range_x",
  "range_y",
  "refresh",
  "reject!",
  "release",
  "remote=",
  "replace",
  "require",
  "rescale",
  "restore",
  "result=",
  "reverse",
  "rewrite",
  "rightOf",
  "rotate!",
  "row1Box",
  "row2Box",
  "row3Box",
  "row_id=",
  "rstrip!",
  "runTest",
  "running",
  "sGlobal",
  "scissor",
  "search_",
  "select!",
  "selfBox",
  "sep_len",
  "setBank",
  "setType",
  "set_amp",
  "set_max",
  "set_min",
  "set_tab",
  "setbyte",
  "setgid?",
  "setuid?",
  "shorter",
  "shuffle",
  "skew_x!",
  "skew_y!",
  "slide_q",
  "slot_id",
  "socket?",
  "spacer=",
  "sprintf",
  "squeeze",
  "stages=",
  "sticky?",
  "stopsig",
  "subset?",
  "subtabs",
  "subview",
  "sunday?",
  "swapBox",
  "symlink",
  "sysopen",
  "sysread",
  "sysseek",
  "tabbox=",
  "tabpack",
  "termsig",
  "textBox",
  "textsel",
  "this_id",
  "titleW=",
  "to_enum",
  "to_path",
  "to_proc",
  "tooltip",
  "topSize",
  "uheight",
  "ui_path",
  "unbound",
  "unknown",
  "unlearn",
  "unpack1",
  "unshift",
  "upcase!",
  "upcase=",
  "use_mtx",
  "velrnd=",
  "vis_sub",
  "visharm",
  "visual=",
  "vow_num",
  "vowels=",
  "vumeter",
  "waiting",
  "waitpid",
  "warning",
  "weights",
  "window=",
  "xpoints",
  "ypoints",
  "$anon_id",
  "@activew",
  "@addbase",
  "@amp_env",
  "@amp_gen",
  "@amp_lfo",
  "@au_plot",
  "@authbox",
  "@basemod",
  "@browser",
  "@buttons",
  "@cb_list",
  "@clicked",
  "@commbox",
  "@content",
  "@context",
  "@cpy_but",
  "@depends",
  "@details",
  "@ebutton",
  "@explore",
  "@fil_sel",
  "@folders",
  "@for_num",
  "@funcpar",
  "@hotload",
  "@ins_sel",
  "@kitedit",
  "@lfo_mod",
  "@lfo_vis",
  "@matches",
  "@namebox",
  "@onWrite",
  "@options",
  "@pad_but",
  "@pp_info",
  "@pst_but",
  "@slide_q",
  "@subtabs",
  "@textBox",
  "@textsel",
  "@ui_path",
  "@used_id",
  "@vis_sub",
  "@visharm",
  "@vow_num",
  "@vumeter",
  "ArrowBox",
  "BUF_SIZE",
  "BankEven",
  "BusyLoop",
  "CachedIR",
  "ClearBox",
  "ColorBox",
  "ColorSel",
  "DataView",
  "DrawRect",
  "DropDown",
  "DummyBox",
  "EALREADY",
  "EL2NSYNC",
  "ELIBEXEC",
  "EMSGSIZE",
  "ENETDOWN",
  "ENOTCONN",
  "ENOTSOCK",
  "ENOTUNIQ",
  "EOFError",
  "EPROCLIM",
  "ERESTART",
  "ESTRPIPE",
  "EXTENDED",
  "Envelope",
  "FileTest",
  "GridLine",
  "INFINITY",
  "KeyBlack",
  "KeyError",
  "Keyboard",
  "Literals",
  "MAX_AUTO",
  "MAX_SLOT",
  "MainMenu",
  "ModWheel",
  "NOFOLLOW",
  "NONBLOCK",
  "NVGError",
  "NilClass",
  "NumEntry",
  "Property",
  "Rational",
  "SEEK_CUR",
  "SEEK_END",
  "SEEK_SET",
  "Selector",
  "Solidity",
  "TabGroup",
  "TestBase",
  "TestCase",
  "TestRows",
  "TestSwap",
  "TextEdit",
  "TextLine",
  "TitleBar",
  "Valuator",
  "WaveForm",
  "WaveView",
  "ZynAbout",
  "ZynMixer",
  "ZynOscil",
  "ZynScale",
  "__ary_eq",
  "__delete",
  "__send__",
  "__svalue",
  "__to_int",
  "_bufread",
  "_gethome",
  "_inspect",
  "accessor",
  "add_attr",
  "add_char",
  "add_favs",
  "add_func",
  "alienwah",
  "allocate",
  "amplEBox",
  "amplLBox",
  "ampl_env",
  "ampl_lfo",
  "applying",
  "arg_list",
  "automate",
  "bank_tag",
  "bar_size",
  "base_osc",
  "basename",
  "between?",
  "bg_color",
  "black_bb",
  "bot_left",
  "button_c",
  "button_p",
  "bytesize",
  "callback",
  "captures",
  "casecmp?",
  "centered",
  "chardev?",
  "children",
  "circ_mag",
  "classify",
  "collect!",
  "compact!",
  "contains",
  "content=",
  "contents",
  "copyable",
  "cur_time",
  "dark_off",
  "database",
  "default=",
  "del_char",
  "del_list",
  "depends=",
  "deselect",
  "diameter",
  "dir_name",
  "dnd_drop",
  "dnd_pick",
  "doRescan",
  "doSearch",
  "doUpdate",
  "doupcase",
  "downcase",
  "draw_alt",
  "draw_new",
  "each_key",
  "editable",
  "enum_for",
  "env_plot",
  "envelope",
  "eval_str",
  "extended",
  "feather=",
  "file_sel",
  "filename",
  "filetype",
  "filtEBox",
  "filtLBox",
  "filt_env",
  "filt_lfo",
  "filter_q",
  "find_all",
  "fixedpad",
  "flatten!",
  "fnmatch?",
  "for_num=",
  "formants",
  "freqEBox",
  "freqLBox",
  "freq_env",
  "freq_lfo",
  "freq_var",
  "full_dir",
  "get_mode",
  "get_node",
  "get_note",
  "get_part",
  "getlocal",
  "gl_clear",
  "global_x",
  "global_y",
  "harmonic",
  "has_key?",
  "haystack",
  "home_dir",
  "hotload=",
  "include?",
  "included",
  "info_box",
  "instance",
  "inverse!",
  "keyPress",
  "keyboard",
  "kind_of?",
  "kit_item",
  "kittable",
  "labelBox",
  "layer_id",
  "lfo_plot",
  "line_cap",
  "linear_x",
  "linear_y",
  "linspace",
  "literal?",
  "load_qml",
  "logo_bot",
  "logo_top",
  "logspace",
  "max_text",
  "maximum=",
  "med_fill",
  "metadata",
  "midi_ref",
  "min_dist",
  "minimize",
  "minimum=",
  "mod_wave",
  "modified",
  "modulate",
  "multiply",
  "new_args",
  "new_diff",
  "next_ctr",
  "next_sel",
  "next_sep",
  "nformant",
  "no_black",
  "norm_0_1",
  "norm_sum",
  "numentry",
  "oldValue",
  "old_gsub",
  "old_time",
  "onScroll",
  "on_color",
  "on_write",
  "opt_plot",
  "opt_vals",
  "options=",
  "osc_wave",
  "overtone",
  "pad_norm",
  "path_ref",
  "path_str",
  "pattern=",
  "patterns",
  "priority",
  "prop_add",
  "property",
  "provided",
  "q_value=",
  "qml_data",
  "rampdown",
  "rdepends",
  "readbyte",
  "readchar",
  "readline",
  "readlink",
  "realpath",
  "renderer",
  "response",
  "reverse!",
  "run_view",
  "selected",
  "selector",
  "self_len",
  "setValue",
  "set_data",
  "set_dirs",
  "set_favs",
  "set_free",
  "set_freq",
  "set_gain",
  "set_mode",
  "set_view",
  "settings",
  "shuffle!",
  "slide_q=",
  "slot_id=",
  "solve_ir",
  "source_x",
  "source_y",
  "special?",
  "squeeze!",
  "statevar",
  "stopped?",
  "str_each",
  "subsynth",
  "subtract",
  "success?",
  "swapcase",
  "switched",
  "symlink?",
  "syswrite",
  "teardown",
  "testRoot",
  "text_box",
  "textedit",
  "titleBox",
  "tooltip=",
  "topSize=",
  "total_ir",
  "transfer",
  "triangle",
  "truncate",
  "tuesday?",
  "type_var",
  "ui_path=",
  "valuator",
  "valueRef",
  "vce_list",
  "velocity",
  "vertical",
  "vis_sub=",
  "visreson",
  "vow_num=",
  "waitpid2",
  "weights=",
  "whenTime",
  "white_bb",
  "wintitle",
  "xpoints=",
  "ypoints=",
  "zipToPos",
  "$test_err",
  "@active_y",
  "@alloc_id",
  "@ampl_env",
  "@ampl_lfo",
  "@animated",
  "@arg_list",
  "@backdrop",
  "@bank_tag",
  "@base_osc",
  "@button_c",
  "@button_p",
  "@callback",
  "@cursor_x",
  "@draw_alt",
  "@draw_seq",
  "@filt_env",
  "@filt_lfo",
  "@frame_id",
  "@freq_env",
  "@freq_lfo",
  "@info_box",
  "@instance",
  "@keyboard",
  "@kit_item",
  "@kittable",
  "@learning",
  "@minimize",
  "@mod_wave",
  "@numentry",
  "@osc_wave",
  "@overtone",
  "@rdepends",
  "@run_view",
  "@selector",
  "@settings",
  "@stop_exc",
  "@subsynth",
  "@textedit",
  "@valuator",
  "@vce_list",
  "@view_pos",
  "@visreson",
  "@wintitle",
  "ALIGN_TOP",
  "ANTIALIAS",
  "BoundAttr",
  "CachedDep",
  "Constants",
  "ECANCELED",
  "EDEADLOCK",
  "EHOSTDOWN",
  "EMULTIHOP",
  "ENEEDAUTH",
  "ENETRESET",
  "ENOMEDIUM",
  "ENOTEMPTY",
  "EOVERFLOW",
  "EREMOTEIO",
  "ESHUTDOWN",
  "ETIMEDOUT",
  "Exception",
  "Generator",
  "KeyEnable",
  "KitButton",
  "KnobGrad1",
  "KnobGrad2",
  "LogWidget",
  "MULTILINE",
  "MatchData",
  "Modifiers",
  "NameError",
  "ParModule",
  "PowButton",
  "Rectangle",
  "SEPARATOR",
  "ScrollBar",
  "SearchBox",
  "SelButton",
  "SelColumn",
  "Swappable",
  "TabButton",
  "TextColor",
  "TextField",
  "TotalObjs",
  "Transform",
  "TrueClass",
  "TypeError",
  "VisFilter",
  "VisualDim",
  "WUNTRACED",
  "ZynAmpEnv",
  "ZynAmpMod",
  "ZynCenter",
  "ZynChorus",
  "ZynFooter",
  "ZynHeader",
  "ZynKitRow",
  "ZynPadAmp",
  "ZynPhaser",
  "ZynReverb",
  "ZynSubAmp",
  "ZynTuning",
  "ZynWipTwo",
  "__ary_cmp",
  "__outer__",
  "_gc_root_",
  "_read_buf",
  "_readchar",
  "_sys_fail",
  "_sysclose",
  "add_child",
  "add_point",
  "add_seq_c",
  "add_synth",
  "addglobal",
  "amplitude",
  "ancestors",
  "anon_test",
  "assert_eq",
  "backtrace",
  "bandwidth",
  "bank_name",
  "bank_type",
  "bar_color",
  "bar_size=",
  "base_harm",
  "base_osc=",
  "base_path",
  "best_diff",
  "best_dist",
  "bezier_to",
  "birthtime",
  "black_pos",
  "blockdev?",
  "bot_right",
  "build_fbo",
  "button_c=",
  "button_p=",
  "byteslice",
  "callback=",
  "casefold?",
  "centered=",
  "changeMax",
  "changeMin",
  "children=",
  "circ_link",
  "circ_text",
  "clear_sel",
  "code_attr",
  "color_rgb",
  "const_get",
  "const_set",
  "container",
  "copyable=",
  "coredump?",
  "cur_start",
  "data_view",
  "del_point",
  "delay_var",
  "delete_at",
  "delete_if",
  "demo_mode",
  "depth_var",
  "dev_major",
  "dev_minor",
  "dim_color",
  "disjoint?",
  "doRefresh",
  "doUpdate=",
  "doupcase=",
  "downcase!",
  "dragScale",
  "drag_prev",
  "drag_type",
  "draw_grid",
  "draw_path",
  "draw_play",
  "draw_stop",
  "draw_text",
  "each_byte",
  "each_char",
  "each_line",
  "each_pair",
  "editable=",
  "ego_death",
  "end_frame",
  "end_with?",
  "enveditor",
  "exception",
  "exclusive",
  "fail_test",
  "feedvalue",
  "file_name",
  "find_font",
  "fine_mode",
  "fixed_pad",
  "fixedpad=",
  "flat_line",
  "font_blur",
  "font_face",
  "font_size",
  "footerbox",
  "frequency",
  "full_harm",
  "getStride",
  "get_image",
  "get_units",
  "get_voice",
  "get_width",
  "grpowned?",
  "harmonics",
  "infinite?",
  "inherited",
  "init_font",
  "init_pugl",
  "initalize",
  "intersect",
  "iterator?",
  "kittable=",
  "knobPhase",
  "knobWidth",
  "knob_dash",
  "known_cls",
  "labelsBox",
  "learn_ref",
  "learning=",
  "left_text",
  "lerp_rgba",
  "line_cap=",
  "line_join",
  "localtime",
  "long_mode",
  "magnitude",
  "max_text=",
  "midi_chan",
  "minheight",
  "mk_points",
  "mouseMove",
  "multiply!",
  "name_push",
  "new_label",
  "new_value",
  "new_width",
  "next_list",
  "next_sect",
  "nformants",
  "normalize",
  "numButton",
  "numerator",
  "object_id",
  "off_color",
  "old_index",
  "old_slice",
  "old_split",
  "old_valid",
  "onSpecial",
  "opt_vals=",
  "out_value",
  "overtone=",
  "pack_misc",
  "padButton",
  "pad_synth",
  "padfactor",
  "padglobal",
  "parmodule",
  "partition",
  "pass_test",
  "path_join",
  "path_simp",
  "phase_mod",
  "phase_osc",
  "phase_var",
  "pos_vowel",
  "pre_match",
  "prepended",
  "prev_note",
  "priority=",
  "protected",
  "push_char",
  "rdepends=",
  "read_list",
  "readable?",
  "readlines",
  "renderer=",
  "resonance",
  "root_node",
  "runUpdate",
  "run_view=",
  "satisfied",
  "saturday?",
  "sel_color",
  "select_id",
  "selected=",
  "send_name",
  "separator",
  "set_files",
  "set_level",
  "set_modal",
  "set_scale",
  "set_value",
  "set_voice",
  "set_watch",
  "shortcuts",
  "signaled?",
  "slide_amp",
  "slidetype",
  "slot_name",
  "slot_path",
  "subButton",
  "sub_synth",
  "subglobal",
  "subsynth=",
  "superargs",
  "superset?",
  "swapcase!",
  "swappable",
  "testSetup",
  "textColor",
  "textScale",
  "thursday?",
  "title_bar",
  "to_delete",
  "totalHarm",
  "total_len",
  "transform",
  "translate",
  "transpose",
  "tryScroll",
  "ungetbyte",
  "unhandled",
  "updatePos",
  "validated",
  "valueRef=",
  "value_lab",
  "value_ref",
  "value_sel",
  "values_at",
  "vce_list=",
  "velocity=",
  "vertical=",
  "vowel_num",
  "wantedMax",
  "wantedMin",
  "wave_view",
  "wheelwell",
  "whenClick",
  "whenEnter",
  "whenTime=",
  "whenValue",
  "whiteKeys",
  "writable?",
  "zero_line",
  "zynCenter",
  "$ruby_mode",
  "@active_ev",
  "@addglobal",
  "@bank_name",
  "@bank_type",
  "@base_harm",
  "@container",
  "@data_view",
  "@enveditor",
  "@feedvalue",
  "@fine_mode",
  "@footerbox",
  "@full_harm",
  "@global_ir",
  "@knobPhase",
  "@knobWidth",
  "@lookahead",
  "@meta_prop",
  "@midi_chan",
  "@numerator",
  "@padButton",
  "@padglobal",
  "@phase_mod",
  "@phase_osc",
  "@pos_vowel",
  "@quit_time",
  "@read_list",
  "@send_name",
  "@separator",
  "@shortcuts",
  "@slide_amp",
  "@slot_name",
  "@subButton",
  "@subglobal",
  "@swappable",
  "@title_bar",
  "@total_len",
  "@wave_view",
  "@wheelwell",
  "ALIGN_LEFT",
  "AbortFrame",
  "Comparable",
  "CopyButton",
  "DemoLayers",
  "EADDRINUSE",
  "ECONNRESET",
  "EOPNOTSUPP",
  "EOWNERDEAD",
  "EPROTOTYPE",
  "EditRegion",
  "EntryMatch",
  "Enumerable",
  "Enumerator",
  "FakeWindow",
  "FalseClass",
  "FiberError",
  "FileButton",
  "FlowLayout",
  "FontHandle",
  "Group_nocp",
  "IGNORECASE",
  "ImageFlags",
  "IndentTest",
  "IndexError",
  "InnerGrad1",
  "InnerGrad2",
  "KitButtons",
  "MacroState",
  "MainWindow",
  "OverlayBox",
  "PlotLabelY",
  "QmlIRCache",
  "RadialMenu",
  "RangeError",
  "TParseType",
  "TestLfoVis",
  "TextScroll",
  "UiEventSeq",
  "VisFormant",
  "VisualLine",
  "VolumeKnob",
  "ZynEffects",
  "ZynEnvEdit",
  "ZynFormant",
  "ZynFreqEnv",
  "ZynFreqMod",
  "ZynPadFreq",
  "ZynSidebar",
  "ZynSubFreq",
  "__case_eqq",
  "__num_to_a",
  "active_ref",
  "add_method",
  "add_parent",
  "allow_dots",
  "assert_nil",
  "automation",
  "background",
  "bank_type=",
  "base_title",
  "begin_path",
  "cache_file",
  "capitalize",
  "change_cat",
  "change_vis",
  "check_args",
  "class_eval",
  "class_name",
  "close_path",
  "codepoints",
  "contentBox",
  "correct_ir",
  "deg_to_rad",
  "delay_time",
  "difference",
  "dimensions",
  "directory?",
  "distortion",
  "doFastLoad",
  "doRefresh=",
  "doSavePart",
  "dragScale=",
  "drag_prev=",
  "drag_type=",
  "draw_arrow",
  "draw_black",
  "draw_layer",
  "draw_pause",
  "draw_white",
  "dump_plist",
  "each_index",
  "each_value",
  "env_marker",
  "eval_value",
  "everything",
  "exitstatus",
  "extensions",
  "externalDb",
  "fd_or_path",
  "file_value",
  "filebutton",
  "fill_color",
  "fill_paint",
  "filter_amp",
  "filtertype",
  "findWidget",
  "find_index",
  "find_slice",
  "fixed_long",
  "font_blur=",
  "font_error",
  "font_face=",
  "font_size=",
  "full_title",
  "gain_value",
  "given_args",
  "gl_scissor",
  "global_pad",
  "has_value?",
  "horizontal",
  "identifier",
  "image_size",
  "init_class",
  "initialize",
  "innerspace",
  "internalDb",
  "intersect?",
  "invalid_ir",
  "invalidate",
  "key_widget",
  "kitbuttons",
  "knobOffset",
  "last_match",
  "layoutOpts",
  "learn_midi",
  "learn_mode",
  "leftButton",
  "light_fill",
  "line_join=",
  "load_scale",
  "main_width",
  "make_child",
  "make_curry",
  "match_data",
  "maxeffects",
  "menuIndent",
  "midi_learn",
  "mousePress",
  "move_sense",
  "needsRegen",
  "new_height",
  "next_coeff",
  "next_frame",
  "nharmonics",
  "noise_mode",
  "normal_int",
  "note_names",
  "numButtonn",
  "numButtont",
  "num_fields",
  "octave_num",
  "old_slice!",
  "other_hash",
  "overlaybox",
  "padprofile",
  "parameters",
  "path_split",
  "path_token",
  "post_match",
  "prev_note=",
  "properties",
  "qwerty_low",
  "rad_to_deg",
  "rdev_major",
  "rdev_minor",
  "recur_list",
  "redraw_fbo",
  "redraw_img",
  "refreshing",
  "reset_mode",
  "resolution",
  "rpartition",
  "run_script",
  "screenshot",
  "sel_column",
  "sel_folder",
  "select_id=",
  "self_arity",
  "selminibox",
  "separator=",
  "setDataVis",
  "set_active",
  "set_enable",
  "set_filter",
  "set_offset",
  "set_scroll",
  "short_name",
  "slide_amp=",
  "slide_freq",
  "slidetype=",
  "splitColor",
  "step_ratio",
  "stream_out",
  "sub_global",
  "subsubview",
  "superclass",
  "tail_empty",
  "test_paths",
  "textColor=",
  "textHeight",
  "textScale=",
  "text_align",
  "text_color",
  "text_field",
  "textrender",
  "tick_sched",
  "toggleable",
  "totalHarm=",
  "total_objs",
  "translate!",
  "un_rescale",
  "unix_start",
  "updateType",
  "update_pos",
  "user_value",
  "value_lab=",
  "value_sel=",
  "vis_filter",
  "voice_item",
  "vowel_num=",
  "wednesday?",
  "whenCancel",
  "whenClick=",
  "whenValue=",
  "white_keys",
  "whitespace",
  "with_index",
  "workaround",
  "yield_self",
  "$test_quiet",
  "$total_objs",
  "@anonymous3",
  "@automation",
  "@base_title",
  "@cache_load",
  "@click_time",
  "@cursor_col",
  "@cursor_row",
  "@draw_layer",
  "@event_list",
  "@extensions",
  "@externalDb",
  "@filebutton",
  "@full_title",
  "@identifier",
  "@internalDb",
  "@kitbuttons",
  "@knobOffset",
  "@last_match",
  "@learn_mode",
  "@log_widget",
  "@menuIndent",
  "@overlaybox",
  "@padprofile",
  "@properties",
  "@read_count",
  "@redraw_fbo",
  "@redraw_img",
  "@setup_done",
  "@slide_freq",
  "@stream_len",
  "@stream_pos",
  "@text_field",
  "@textrender",
  "@true_label",
  "@value_prop",
  "@vis_filter",
  "@voice_item",
  "@word_buf_w",
  "ALIGN_RIGHT",
  "ApplyButton",
  "Automations",
  "BasicObject",
  "ButtonGrad1",
  "ButtonGrad2",
  "CachedCtime",
  "ColorButton",
  "ColorScheme",
  "CreateFlags",
  "DataViewAlt",
  "DomainError",
  "DrawSeqNode",
  "EINPROGRESS",
  "EKEYEXPIRED",
  "EKEYREVOKED",
  "EMEDIUMTYPE",
  "ENETUNREACH",
  "ENOPROTOOPT",
  "EWOULDBLOCK",
  "Environment",
  "Errno2class",
  "FNM_SYSCASE",
  "FancyButton",
  "FileBrowser",
  "FrozenError",
  "GroupHeader",
  "IMAGE_FLIPY",
  "ImageHandle",
  "LabelButton",
  "LearnButton",
  "ModuleGrad1",
  "ModuleGrad2",
  "MouseButton",
  "MouseScroll",
  "OverlayTest",
  "PanicButton",
  "PasteButton",
  "ProgBuildVM",
  "QmlIrToRuby",
  "RUBY_ENGINE",
  "RegexpError",
  "RemoteParam",
  "ScriptError",
  "SyntaxError",
  "TimeProfile",
  "VisHarmonic",
  "WindowGrad1",
  "WindowGrad2",
  "ZynAddSynth",
  "ZynAddVoice",
  "ZynAlienwah",
  "ZynDAFilter",
  "ZynDFFilter",
  "ZynDyFilter",
  "ZynEqFilter",
  "ZynKitTable",
  "ZynMixerCol",
  "ZynOscilMod",
  "ZynPadSynth",
  "ZynSettings",
  "ZynSubSynth",
  "__ary_index",
  "_recur_list",
  "abort_frame",
  "active_auto",
  "attr_reader",
  "attr_writer",
  "begin_frame",
  "best_height",
  "bg_on_color",
  "black_color",
  "bound_child",
  "capitalize!",
  "change_file",
  "change_view",
  "circ_filter",
  "clear_flags",
  "clear_seq_c",
  "close_write",
  "combination",
  "consume_tok",
  "copy_button",
  "create_font",
  "create_menu",
  "damage_item",
  "damage_self",
  "dark_orange",
  "default_dir",
  "del_partial",
  "delay_time=",
  "display_log",
  "doInsSelect",
  "draw_button",
  "draw_normal",
  "draw_record",
  "draw_strike",
  "each_string",
  "eq_response",
  "executable?",
  "expand_path",
  "file_select",
  "fill_color=",
  "fill_paint=",
  "filter_freq",
  "filtertype=",
  "find_widget",
  "fixed_width",
  "font_handle",
  "gain_value=",
  "genConstBox",
  "get_context",
  "get_refresh",
  "gl_viewport",
  "init_window",
  "inner_color",
  "knobLRcross",
  "label_items",
  "last_match=",
  "layoutOpts=",
  "learn_midi=",
  "learn_mode=",
  "light_filll",
  "line_widths",
  "log_widget=",
  "main_widget",
  "make_points",
  "map_include",
  "maxeffects=",
  "miter_limit",
  "module_eval",
  "mouseScroll",
  "needRefresh",
  "needsRegen=",
  "next_coeff=",
  "next_values",
  "noise_mode=",
  "numformants",
  "onMouseMove",
  "outer_color",
  "overlay_fbo",
  "overlay_lfo",
  "owned_real?",
  "padprofile=",
  "partsetting",
  "peek_values",
  "permutation",
  "pure_string",
  "pure_symbol",
  "qwerty_high",
  "read_string",
  "recommended",
  "refreshing=",
  "render_seqs",
  "reset_value",
  "respond_to?",
  "rightButton",
  "sample_rate",
  "search_path",
  "selected_id",
  "send_points",
  "set_content",
  "set_non_kit",
  "set_partial",
  "set_vis_amp",
  "set_vis_env",
  "set_vis_lfo",
  "slide_freq=",
  "start_with?",
  "step_ratio=",
  "subfqbutton",
  "text_align=",
  "text_bounds",
  "text_color1",
  "text_color2",
  "tick_events",
  "tick_remote",
  "toggleable=",
  "tri_upper_x",
  "tri_upper_y",
  "try_hotload",
  "update_data",
  "update_path",
  "update_text",
  "update_time",
  "value_label",
  "weak_box_id",
  "weight_list",
  "whenSwapped",
  "whitespace=",
  "windowTitle",
  "with_object",
  "$current_dir",
  "$dummy_class",
  "$global_self",
  "@@key_lookup",
  "@active_line",
  "@anonymous17",
  "@anonymous18",
  "@anonymous20",
  "@anonymous31",
  "@anonymous43",
  "@anonymous47",
  "@anonymous51",
  "@anonymous52",
  "@anonymous53",
  "@anonymous54",
  "@anonymous55",
  "@anonymous57",
  "@anonymous58",
  "@anonymous59",
  "@anonymous60",
  "@anonymous61",
  "@anonymous67",
  "@copy_button",
  "@current_dir",
  "@knobLRcross",
  "@line_widths",
  "@main_widget",
  "@overlay_fbo",
  "@overlay_img",
  "@partsetting",
  "@search_path",
  "@send_update",
  "@subfqbutton",
  "@word_buffer",
  "ALIGN_BOTTOM",
  "ALIGN_CENTER",
  "ALIGN_MIDDLE",
  "ButtonActive",
  "BypassButton",
  "DrawSequence",
  "EAFNOSUPPORT",
  "ECONNABORTED",
  "ECONNREFUSED",
  "EDESTADDRREQ",
  "EHOSTUNREACH",
  "EKEYREJECTED",
  "ENAMETOOLONG",
  "EPFNOSUPPORT",
  "EPROCUNAVAIL",
  "EPROGUNAVAIL",
  "ERPCMISMATCH",
  "ETOOMANYREFS",
  "FNM_CASEFOLD",
  "FNM_DOTMATCH",
  "FNM_NOESCAPE",
  "FNM_PATHNAME",
  "FileSelector",
  "HarmonicEdit",
  "HarmonicView",
  "NumberButton",
  "ParModuleRow",
  "RUBY_VERSION",
  "RuntimeError",
  "SHARE_DELETE",
  "ScrollActive",
  "SliderActive",
  "SliderStroke",
  "SustainPoint",
  "TextModColor",
  "ToggleButton",
  "UiEventTypes",
  "VisResonance",
  "VisualBright",
  "VisualSelect",
  "VisualStroke",
  "ZynAddGlobal",
  "ZynDynFilter",
  "ZynEqualizer",
  "ZynFilterEnv",
  "ZynMidiLearn",
  "ZynModAmpEnv",
  "ZynPadGlobal",
  "ZynPatchInfo",
  "ZynResonance",
  "ZynSendToRow",
  "ZynSubFilter",
  "ZynSubGlobal",
  "__attached__",
  "__printstr__",
  "_concat_path",
  "activeWidget",
  "active_auto=",
  "active_event",
  "add_property",
  "alias_method",
  "analogButton",
  "assert_equal",
  "assert_raise",
  "black_accent",
  "black_key_id",
  "block_given?",
  "bound_parent",
  "bound_points",
  "box_gradient",
  "bright_green",
  "cancel_frame",
  "changeAnalog",
  "check_redraw",
  "column_count",
  "column_index",
  "consume_inst",
  "consume_line",
  "create_image",
  "default_proc",
  "delayRefresh",
  "delete_image",
  "do_with_enum",
  "drawVZSlider",
  "draw_borders",
  "draw_classic",
  "draw_overlay",
  "drive_prefix",
  "enable_color",
  "env_sel_line",
  "escape_table",
  "event_widget",
  "exclude_end?",
  "fetch_values",
  "font_face_id",
  "force_update",
  "get_view_pos",
  "get_x_points",
  "getkeystring",
  "global_alpha",
  "handleScroll",
  "ignoreAspect",
  "ignore_phase",
  "image_handle",
  "ind_selected",
  "indent_color",
  "inner_color=",
  "install_attr",
  "instance_of?",
  "intersection",
  "last_up_time",
  "layout_hpack",
  "make_formant",
  "method_added",
  "middleButton",
  "middle_panel",
  "midi_unlearn",
  "miter_limit=",
  "mouseRelease",
  "mouse_enable",
  "mouse_handle",
  "needRefresh=",
  "needs_update",
  "numformants=",
  "onMouseEnter",
  "onMouseHover",
  "onMouseLeave",
  "onMousePress",
  "oscillbutton",
  "oscilloscope",
  "outer_color=",
  "partchannels",
  "paste_button",
  "path_winding",
  "pre_multiply",
  "print_matrix",
  "pure_numeric",
  "remove_const",
  "remove_sense",
  "reverse_each",
  "rounded_rect",
  "runBuildTest",
  "search_path=",
  "selected_fbo",
  "selected_val",
  "set_callback",
  "set_home_dir",
  "set_value_ar",
  "set_value_tf",
  "set_view_pos",
  "set_vis_freq",
  "setup_widget",
  "should_close",
  "shownWeights",
  "smash_layout",
  "strike_color",
  "stroke_color",
  "stroke_paint",
  "stroke_width",
  "test_no_home",
  "test_summary",
  "test_unix_cd",
  "text_metrics",
  "tick_hotload",
  "turn_off_tab",
  "undef_method",
  "updatePosAbs",
  "update_coeff",
  "update_image",
  "update_value",
  "value_label=",
  "whenModified",
  "whenSwapped=",
  "white_accent",
  "white_key_id",
  "windowResize",
  "windowTitle=",
  "$test_counter",
  "@analogButton",
  "@anonymous110",
  "@anonymous111",
  "@anonymous113",
  "@anonymous114",
  "@anonymous115",
  "@anonymous116",
  "@anonymous117",
  "@anonymous118",
  "@anonymous119",
  "@anonymous122",
  "@anonymous124",
  "@anonymous125",
  "@anonymous126",
  "@anonymous127",
  "@anonymous129",
  "@anonymous141",
  "@anonymous145",
  "@anonymous146",
  "@anonymous148",
  "@anonymous149",
  "@anonymous150",
  "@anonymous157",
  "@anonymous162",
  "@anonymous163",
  "@anonymous170",
  "@anonymous171",
  "@anonymous177",
  "@anonymous178",
  "@anonymous179",
  "@anonymous180",
  "@anonymous181",
  "@anonymous185",
  "@anonymous186",
  "@anonymous192",
  "@anonymous207",
  "@anonymous208",
  "@anonymous214",
  "@anonymous215",
  "@anonymous216",
  "@anonymous219",
  "@anonymous220",
  "@anonymous221",
  "@anonymous223",
  "@anonymous224",
  "@anonymous225",
  "@anonymous226",
  "@anonymous227",
  "@anonymous228",
  "@anonymous229",
  "@anonymous230",
  "@anonymous242",
  "@anonymous243",
  "@anonymous244",
  "@anonymous247",
  "@anonymous248",
  "@anonymous249",
  "@anonymous250",
  "@anonymous251",
  "@anonymous252",
  "@anonymous253",
  "@anonymous255",
  "@anonymous256",
  "@anonymous257",
  "@anonymous258",
  "@anonymous259",
  "@anonymous260",
  "@anonymous261",
  "@anonymous263",
  "@anonymous264",
  "@anonymous265",
  "@anonymous266",
  "@anonymous267",
  "@anonymous268",
  "@anonymous269",
  "@anonymous270",
  "@anonymous271",
  "@anonymous272",
  "@anonymous273",
  "@anonymous274",
  "@anonymous275",
  "@anonymous276",
  "@anonymous277",
  "@anonymous280",
  "@anonymous281",
  "@anonymous282",
  "@anonymous284",
  "@anonymous285",
  "@anonymous286",
  "@anonymous287",
  "@anonymous288",
  "@anonymous289",
  "@anonymous292",
  "@anonymous293",
  "@anonymous294",
  "@anonymous295",
  "@anonymous297",
  "@anonymous298",
  "@anonymous299",
  "@anonymous300",
  "@anonymous301",
  "@anonymous304",
  "@anonymous305",
  "@anonymous306",
  "@anonymous307",
  "@anonymous308",
  "@anonymous310",
  "@anonymous311",
  "@anonymous312",
  "@anonymous314",
  "@anonymous315",
  "@anonymous316",
  "@anonymous319",
  "@anonymous320",
  "@anonymous321",
  "@anonymous324",
  "@anonymous328",
  "@anonymous329",
  "@anonymous332",
  "@anonymous333",
  "@anonymous337",
  "@anonymous341",
  "@anonymous345",
  "@anonymous349",
  "@anonymous355",
  "@anonymous358",
  "@anonymous359",
  "@anonymous360",
  "@anonymous361",
  "@anonymous363",
  "@anonymous364",
  "@anonymous371",
  "@anonymous373",
  "@anonymous374",
  "@anonymous375",
  "@anonymous376",
  "@anonymous379",
  "@anonymous380",
  "@anonymous383",
  "@anonymous384",
  "@anonymous385",
  "@anonymous386",
  "@anonymous387",
  "@anonymous388",
  "@anonymous389",
  "@anonymous390",
  "@anonymous391",
  "@anonymous392",
  "@anonymous393",
  "@anonymous395",
  "@anonymous396",
  "@anonymous397",
  "@anonymous398",
  "@anonymous399",
  "@anonymous400",
  "@anonymous401",
  "@anonymous403",
  "@anonymous404",
  "@anonymous405",
  "@anonymous406",
  "@anonymous408",
  "@anonymous409",
  "@anonymous410",
  "@anonymous411",
  "@anonymous412",
  "@anonymous415",
  "@anonymous416",
  "@anonymous417",
  "@anonymous418",
  "@anonymous419",
  "@anonymous420",
  "@anonymous422",
  "@anonymous423",
  "@anonymous424",
  "@anonymous425",
  "@anonymous426",
  "@anonymous428",
  "@anonymous429",
  "@anonymous430",
  "@anonymous439",
  "@anonymous440",
  "@anonymous441",
  "@anonymous442",
  "@anonymous443",
  "@anonymous444",
  "@anonymous445",
  "@anonymous446",
  "@anonymous447",
  "@anonymous448",
  "@anonymous449",
  "@anonymous450",
  "@anonymous451",
  "@anonymous452",
  "@anonymous453",
  "@anonymous454",
  "@anonymous457",
  "@anonymous458",
  "@anonymous459",
  "@anonymous460",
  "@anonymous461",
  "@anonymous462",
  "@anonymous463",
  "@anonymous464",
  "@anonymous465",
  "@anonymous466",
  "@anonymous467",
  "@anonymous468",
  "@anonymous469",
  "@anonymous470",
  "@anonymous471",
  "@anonymous472",
  "@anonymous473",
  "@anonymous476",
  "@anonymous478",
  "@anonymous480",
  "@anonymous482",
  "@anonymous483",
  "@anonymous484",
  "@anonymous485",
  "@anonymous486",
  "@anonymous487",
  "@anonymous489",
  "@anonymous490",
  "@anonymous491",
  "@anonymous493",
  "@anonymous494",
  "@anonymous495",
  "@anonymous496",
  "@anonymous498",
  "@anonymous499",
  "@anonymous501",
  "@anonymous502",
  "@anonymous503",
  "@anonymous506",
  "@anonymous507",
  "@anonymous510",
  "@anonymous511",
  "@anonymous512",
  "@anonymous513",
  "@anonymous514",
  "@anonymous515",
  "@anonymous516",
  "@anonymous517",
  "@anonymous518",
  "@anonymous519",
  "@anonymous520",
  "@anonymous521",
  "@anonymous522",
  "@anonymous523",
  "@anonymous524",
  "@anonymous526",
  "@anonymous527",
  "@anonymous528",
  "@anonymous529",
  "@anonymous530",
  "@anonymous531",
  "@anonymous532",
  "@anonymous533",
  "@anonymous534",
  "@anonymous535",
  "@anonymous536",
  "@anonymous539",
  "@anonymous540",
  "@anonymous541",
  "@anonymous542",
  "@anonymous544",
  "@anonymous545",
  "@anonymous546",
  "@anonymous547",
  "@anonymous549",
  "@anonymous550",
  "@anonymous551",
  "@anonymous552",
  "@anonymous553",
  "@anonymous554",
  "@anonymous556",
  "@anonymous557",
  "@anonymous558",
  "@anonymous559",
  "@anonymous560",
  "@anonymous565",
  "@anonymous568",
  "@anonymous571",
  "@anonymous573",
  "@anonymous574",
  "@anonymous575",
  "@anonymous577",
  "@anonymous579",
  "@anonymous581",
  "@anonymous583",
  "@anonymous584",
  "@anonymous586",
  "@anonymous587",
  "@anonymous588",
  "@anonymous589",
  "@anonymous590",
  "@anonymous591",
  "@anonymous593",
  "@anonymous594",
  "@anonymous595",
  "@anonymous596",
  "@anonymous610",
  "@anonymous611",
  "@anonymous612",
  "@anonymous613",
  "@anonymous614",
  "@anonymous615",
  "@anonymous621",
  "@anonymous622",
  "@anonymous623",
  "@anonymous625",
  "@anonymous627",
  "@anonymous629",
  "@anonymous630",
  "@anonymous632",
  "@anonymous633",
  "@anonymous634",
  "@anonymous635",
  "@anonymous636",
  "@anonymous638",
  "@anonymous639",
  "@anonymous640",
  "@anonymous642",
  "@anonymous643",
  "@anonymous644",
  "@anonymous647",
  "@anonymous648",
  "@anonymous649",
  "@anonymous650",
  "@anonymous651",
  "@anonymous652",
  "@anonymous653",
  "@anonymous655",
  "@anonymous656",
  "@anonymous657",
  "@anonymous658",
  "@anonymous659",
  "@anonymous660",
  "@anonymous661",
  "@anonymous662",
  "@anonymous664",
  "@anonymous665",
  "@anonymous666",
  "@anonymous667",
  "@anonymous668",
  "@anonymous669",
  "@anonymous670",
  "@anonymous674",
  "@anonymous683",
  "@anonymous684",
  "@anonymous685",
  "@anonymous686",
  "@anonymous687",
  "@anonymous688",
  "@anonymous691",
  "@anonymous692",
  "@anonymous693",
  "@anonymous694",
  "@anonymous695",
  "@anonymous696",
  "@anonymous697",
  "@anonymous698",
  "@anonymous699",
  "@anonymous701",
  "@anonymous702",
  "@anonymous704",
  "@anonymous705",
  "@anonymous706",
  "@anonymous708",
  "@anonymous709",
  "@anonymous711",
  "@anonymous712",
  "@anonymous713",
  "@anonymous715",
  "@anonymous720",
  "@anonymous722",
  "@anonymous723",
  "@anonymous724",
  "@anonymous725",
  "@anonymous726",
  "@anonymous727",
  "@anonymous728",
  "@anonymous729",
  "@anonymous730",
  "@anonymous731",
  "@anonymous734",
  "@anonymous735",
  "@anonymous736",
  "@anonymous737",
  "@anonymous739",
  "@anonymous740",
  "@anonymous741",
  "@anonymous742",
  "@anonymous743",
  "@anonymous745",
  "@anonymous746",
  "@anonymous747",
  "@anonymous748",
  "@anonymous750",
  "@anonymous751",
  "@anonymous752",
  "@anonymous754",
  "@anonymous755",
  "@anonymous756",
  "@anonymous757",
  "@anonymous758",
  "@anonymous759",
  "@anonymous760",
  "@anonymous761",
  "@anonymous762",
  "@anonymous763",
  "@anonymous764",
  "@anonymous765",
  "@anonymous767",
  "@anonymous768",
  "@anonymous769",
  "@anonymous770",
  "@anonymous771",
  "@anonymous772",
  "@anonymous773",
  "@anonymous774",
  "@anonymous776",
  "@anonymous777",
  "@anonymous778",
  "@anonymous780",
  "@anonymous781",
  "@anonymous784",
  "@anonymous785",
  "@anonymous786",
  "@anonymous787",
  "@anonymous788",
  "@anonymous789",
  "@anonymous790",
  "@anonymous791",
  "@anonymous792",
  "@anonymous794",
  "@anonymous795",
  "@anonymous796",
  "@anonymous797",
  "@anonymous798",
  "@anonymous800",
  "@anonymous801",
  "@anonymous802",
  "@anonymous803",
  "@anonymous804",
  "@anonymous805",
  "@anonymous807",
  "@anonymous808",
  "@anonymous809",
  "@anonymous810",
  "@anonymous811",
  "@anonymous812",
  "@anonymous822",
  "@anonymous823",
  "@anonymous824",
  "@anonymous825",
  "@anonymous826",
  "@anonymous828",
  "@anonymous829",
  "@anonymous830",
  "@anonymous831",
  "@anonymous832",
  "@anonymous833",
  "@anonymous834",
  "@anonymous835",
  "@anonymous836",
  "@anonymous837",
  "@anonymous838",
  "@anonymous839",
  "@anonymous840",
  "@anonymous841",
  "@anonymous842",
  "@anonymous843",
  "@anonymous844",
  "@anonymous845",
  "@anonymous846",
  "@anonymous847",
  "@anonymous848",
  "@anonymous849",
  "@anonymous850",
  "@anonymous851",
  "@anonymous852",
  "@anonymous853",
  "@anonymous854",
  "@anonymous855",
  "@anonymous856",
  "@anonymous857",
  "@anonymous858",
  "@anonymous859",
  "@anonymous860",
  "@anonymous861",
  "@anonymous862",
  "@anonymous863",
  "@anonymous864",
  "@anonymous868",
  "@anonymous871",
  "@anonymous872",
  "@anonymous873",
  "@anonymous874",
  "@anonymous875",
  "@anonymous876",
  "@anonymous879",
  "@anonymous881",
  "@anonymous882",
  "@anonymous883",
  "@anonymous884",
  "@anonymous885",
  "@anonymous886",
  "@anonymous887",
  "@anonymous888",
  "@anonymous889",
  "@anonymous890",
  "@anonymous891",
  "@anonymous894",
  "@anonymous895",
  "@anonymous896",
  "@anonymous897",
  "@anonymous899",
  "@anonymous902",
  "@anonymous903",
  "@anonymous904",
  "@anonymous906",
  "@anonymous907",
  "@anonymous911",
  "@anonymous912",
  "@anonymous914",
  "@anonymous915",
  "@anonymous916",
  "@anonymous917",
  "@anonymous919",
  "@anonymous920",
  "@anonymous921",
  "@anonymous922",
  "@anonymous923",
  "@anonymous924",
  "@anonymous927",
  "@anonymous928",
  "@anonymous929",
  "@anonymous930",
  "@anonymous931",
  "@anonymous932",
  "@anonymous933",
  "@anonymous934",
  "@anonymous935",
  "@anonymous942",
  "@anonymous943",
  "@anonymous944",
  "@anonymous948",
  "@anonymous949",
  "@anonymous951",
  "@anonymous952",
  "@anonymous953",
  "@anonymous954",
  "@anonymous955",
  "@anonymous956",
  "@anonymous957",
  "@anonymous958",
  "@anonymous959",
  "@anonymous960",
  "@anonymous961",
  "@anonymous962",
  "@anonymous963",
  "@anonymous965",
  "@anonymous966",
  "@anonymous967",
  "@anonymous968",
  "@anonymous969",
  "@anonymous970",
  "@anonymous971",
  "@anonymous972",
  "@anonymous973",
  "@anonymous974",
  "@anonymous975",
  "@anonymous976",
  "@anonymous977",
  "@anonymous978",
  "@anonymous979",
  "@anonymous980",
  "@anonymous982",
  "@anonymous983",
  "@anonymous984",
  "@anonymous985",
  "@anonymous986",
  "@anonymous987",
  "@anonymous988",
  "@anonymous989",
  "@anonymous990",
  "@anonymous991",
  "@anonymous992",
  "@anonymous993",
  "@anonymous994",
  "@anonymous995",
  "@anonymous996",
  "@anonymous997",
  "@anonymous998",
  "@current_file",
  "@keep_running",
  "@middle_panel",
  "@needs_update",
  "@oscillbutton",
  "@paste_button",
  "@startup_time",
  "ALT_SEPARATOR",
  "ArgumentError",
  "CachedClasses",
  "ConfirmButton",
  "ConstantEntry",
  "EADDRNOTAVAIL",
  "EPROGMISMATCH",
  "EnvelopePoint",
  "GlobalIRCache",
  "HarmonicColor",
  "IMAGE_REPEATX",
  "IMAGE_REPEATY",
  "KeyBackground",
  "KeyWhiteGrad1",
  "KeyWhiteGrad2",
  "MRUBY_VERSION",
  "NoMemoryError",
  "NoMethodError",
  "QmlSearchPath",
  "RootDirectory",
  "SidebarButton",
  "StandardError",
  "StopIteration",
  "TriggerButton",
  "ZynAmpGeneral",
  "ZynAutomation",
  "ZynDistortion",
  "ZynPadProfile",
  "ZynPortamento",
  "ZynResOptions",
  "ZynSendToGrid",
  "ZynSubFreqEnv",
  "__classname__",
  "__sub_replace",
  "__update_hash",
  "animate_frame",
  "animation_fbo",
  "assert_not_eq",
  "attr_accessor",
  "attr_property",
  "black_pattern",
  "brace_pattern",
  "bsearch_index",
  "calc_cursor_x",
  "change_active",
  "change_filter",
  "clear_refresh",
  "const_missing",
  "content_items",
  "context_apply",
  "create_radial",
  "damage_region",
  "default_proc=",
  "define_method",
  "delayRefresh=",
  "delete_prefix",
  "delete_suffix",
  "display_value",
  "drag_and_drop",
  "draw_borders=",
  "draw_centered",
  "draw_inactive",
  "drawn_widgets",
  "dynamicfilter",
  "expanded_path",
  "extend_object",
  "flatten_merge",
  "font_face_id=",
  "force_refresh",
  "get_note_name",
  "get_qml_const",
  "global_alpha=",
  "handle_events",
  "harmonic_view",
  "highlight_pos",
  "ignore_phase=",
  "image_pattern",
  "in_lower_half",
  "ind_selected=",
  "indirect_attr",
  "init_automate",
  "initialize_rb",
  "instance_eval",
  "instance_exec",
  "learn_address",
  "load_property",
  "make_bandpass",
  "make_callback",
  "make_rdepends",
  "message_class",
  "mouse_enable=",
  "needs_refresh",
  "no_constraint",
  "opt_magnitude",
  "oscillbutton=",
  "outline_color",
  "path_elements",
  "path_winding=",
  "pre_multiply!",
  "prev_channels",
  "rec_clean_cbs",
  "rec_del_props",
  "refresh_recur",
  "reorder_cache",
  "reset_scissor",
  "selected_item",
  "set_backtrace",
  "set_sub_value",
  "set_value_str",
  "setup_classes",
  "shownWeights=",
  "splitted_path",
  "strip_literal",
  "stroke_color=",
  "stroke_paint=",
  "stroke_width=",
  "sub_harmonics",
  "sustain_color",
  "sustain_point",
  "update_active",
  "update_points",
  "update_values",
  "whenModified=",
  "windows_path?",
  "windows_start",
  "$auto_apply_dt",
  "@active_widget",
  "@animation_fbo",
  "@animation_img",
  "@anonymous1000",
  "@anonymous1001",
  "@anonymous1002",
  "@anonymous1010",
  "@anonymous1011",
  "@anonymous1012",
  "@anonymous1013",
  "@anonymous1014",
  "@anonymous1015",
  "@anonymous1017",
  "@anonymous1019",
  "@anonymous1021",
  "@anonymous1024",
  "@anonymous1025",
  "@anonymous1026",
  "@anonymous1027",
  "@anonymous1028",
  "@anonymous1029",
  "@anonymous1030",
  "@anonymous1031",
  "@anonymous1032",
  "@anonymous1033",
  "@anonymous1034",
  "@anonymous1035",
  "@anonymous1037",
  "@anonymous1040",
  "@anonymous1043",
  "@anonymous1044",
  "@anonymous1048",
  "@anonymous1049",
  "@anonymous1050",
  "@anonymous1051",
  "@anonymous1052",
  "@anonymous1053",
  "@anonymous1054",
  "@anonymous1055",
  "@anonymous1056",
  "@anonymous1057",
  "@anonymous1058",
  "@anonymous1059",
  "@anonymous1061",
  "@anonymous1062",
  "@anonymous1063",
  "@anonymous1064",
  "@anonymous1065",
  "@anonymous1066",
  "@anonymous1067",
  "@anonymous1068",
  "@anonymous1069",
  "@anonymous1070",
  "@anonymous1071",
  "@anonymous1072",
  "@anonymous1073",
  "@anonymous1076",
  "@anonymous1077",
  "@anonymous1079",
  "@anonymous1080",
  "@anonymous1081",
  "@anonymous1082",
  "@anonymous1083",
  "@anonymous1084",
  "@anonymous1085",
  "@anonymous1086",
  "@anonymous1087",
  "@anonymous1088",
  "@anonymous1089",
  "@anonymous1090",
  "@anonymous1093",
  "@anonymous1094",
  "@anonymous1095",
  "@anonymous1096",
  "@anonymous1097",
  "@anonymous1098",
  "@anonymous1099",
  "@anonymous1100",
  "@anonymous1101",
  "@anonymous1102",
  "@anonymous1103",
  "@anonymous1104",
  "@anonymous1105",
  "@anonymous1106",
  "@anonymous1107",
  "@anonymous1108",
  "@anonymous1109",
  "@anonymous1110",
  "@anonymous1113",
  "@anonymous1114",
  "@anonymous1117",
  "@anonymous1118",
  "@anonymous1119",
  "@anonymous1120",
  "@anonymous1121",
  "@anonymous1122",
  "@anonymous1123",
  "@anonymous1124",
  "@anonymous1125",
  "@anonymous1126",
  "@anonymous1127",
  "@anonymous1128",
  "@anonymous1129",
  "@anonymous1130",
  "@anonymous1131",
  "@anonymous1132",
  "@anonymous1133",
  "@anonymous1134",
  "@anonymous1135",
  "@anonymous1136",
  "@anonymous1137",
  "@anonymous1140",
  "@anonymous1145",
  "@anonymous1150",
  "@anonymous1156",
  "@anonymous1157",
  "@anonymous1158",
  "@anonymous1159",
  "@anonymous1160",
  "@anonymous1161",
  "@anonymous1162",
  "@anonymous1163",
  "@anonymous1164",
  "@anonymous1166",
  "@anonymous1167",
  "@anonymous1168",
  "@anonymous1169",
  "@anonymous1170",
  "@anonymous1171",
  "@anonymous1173",
  "@anonymous1175",
  "@anonymous1176",
  "@anonymous1177",
  "@anonymous1178",
  "@anonymous1179",
  "@anonymous1180",
  "@anonymous1181",
  "@anonymous1182",
  "@anonymous1183",
  "@anonymous1188",
  "@anonymous1190",
  "@anonymous1192",
  "@anonymous1193",
  "@anonymous1194",
  "@anonymous1195",
  "@anonymous1196",
  "@anonymous1197",
  "@anonymous1198",
  "@anonymous1199",
  "@anonymous1200",
  "@anonymous1201",
  "@anonymous1202",
  "@anonymous1203",
  "@anonymous1205",
  "@anonymous1206",
  "@anonymous1207",
  "@anonymous1208",
  "@anonymous1209",
  "@anonymous1210",
  "@anonymous1211",
  "@anonymous1212",
  "@anonymous1213",
  "@anonymous1214",
  "@anonymous1220",
  "@anonymous1221",
  "@anonymous1222",
  "@anonymous1226",
  "@anonymous1227",
  "@anonymous1228",
  "@anonymous1229",
  "@anonymous1230",
  "@anonymous1231",
  "@anonymous1232",
  "@anonymous1233",
  "@anonymous1234",
  "@anonymous1235",
  "@anonymous1238",
  "@anonymous1239",
  "@anonymous1240",
  "@anonymous1241",
  "@anonymous1242",
  "@anonymous1243",
  "@anonymous1246",
  "@anonymous1250",
  "@anonymous1252",
  "@anonymous1254",
  "@anonymous1255",
  "@anonymous1256",
  "@anonymous1257",
  "@anonymous1258",
  "@anonymous1259",
  "@anonymous1261",
  "@anonymous1262",
  "@anonymous1263",
  "@children_locs",
  "@damage_layers",
  "@harmonic_view",
  "@needs_refresh",
  "@old_read_list",
  "@path_elements",
  "@sub_harmonics",
  "ALIGN_BASELINE",
  "ButtonInactive",
  "DirectoryMatch",
  "HighlightGrad1",
  "HighlightGrad2",
  "KeyBlackAccent",
  "KeyWhiteAccent",
  "LayoutConstBox",
  "LocalJumpError",
  "PATH_SEPARATOR",
  "RemoteMetadata",
  "ScrollInactive",
  "VisualDimTrans",
  "ZynControllers",
  "ZynEffectGroup",
  "ZynEffectsPart",
  "ZynFreqGeneral",
  "ZynPadOvertone",
  "ZynSubHarmonic",
  "__upto_endless",
  "_content_lines",
  "animation_fps=",
  "assert_not_nil",
  "background_fbo",
  "change_dir_abs",
  "change_dir_rel",
  "close_on_exec=",
  "close_on_exec?",
  "const_defined?",
  "createInstance",
  "delete_prefix!",
  "delete_suffix!",
  "different_file",
  "each_codepoint",
  "filter_widgets",
  "get_remote_url",
  "gl_clear_color",
  "gl_scissor_end",
  "highlight_pos=",
  "install_method",
  "interval_ratio",
  "last_match_end",
  "load_event_seq",
  "method_missing",
  "modlabelHeight",
  "named_captures",
  "norm_harmonics",
  "onMouseRelease",
  "over_highlight",
  "paragraph_mode",
  "pending_damage",
  "perform_layout",
  "proper_subset?",
  "readable_real?",
  "regen_children",
  "runtime_points",
  "scrollbar_size",
  "selected_layer",
  "set_active_kit",
  "set_kit_enable",
  "set_noise_mode",
  "set_value_user",
  "set_vis_filter",
  "single_compile",
  "smash_draw_seq",
  "strike_through",
  "sustain_point=",
  "test_unix_file",
  "test_window_cd",
  "tick_animation",
  "transform_keys",
  "tri_low_left_x",
  "tri_low_left_y",
  "try_patch_rdep",
  "update_ui_path",
  "updating_layer",
  "writable_real?",
  "write_property",
  "@active_buttons",
  "@background_fbo",
  "@background_img",
  "@common_draw_id",
  "@hotload_frames",
  "@pending_change",
  "@pending_layout",
  "@pending_resize",
  "DirectoriesOnly",
  "ENOTRECOVERABLE",
  "EPROTONOSUPPORT",
  "ESOCKTNOSUPPORT",
  "FileBrowserTest",
  "MRUBY_COPYRIGHT",
  "STENCIL_STROKES",
  "SliderVisActive",
  "SystemCallError",
  "TextActiveColor",
  "VisSubHarmonics",
  "VisualLightFill",
  "ZynAddVoiceList",
  "ZynAnalogFilter",
  "ZynBandwidthEnv",
  "ZynEffectBypass",
  "ZynHeaderParams",
  "ZynKitKeyButton",
  "ZynMidiLearnRow",
  "ZynOscilloscope",
  "ZynPadHarmonics",
  "ZynSubAmpbutton",
  "ZynSubBandwidth",
  "ZynSubFilterEnv",
  "_check_readable",
  "_content_lines=",
  "append_features",
  "automation_view",
  "clear_on_extern",
  "connect_watcher",
  "create_font_mem",
  "do_update_coeff",
  "each_with_index",
  "ensure_database",
  "handleCursorPos",
  "indirect_method",
  "initialize_copy",
  "install_context",
  "interval_ratio=",
  "linear_gradient",
  "load_scale_file",
  "method_defined?",
  "module_function",
  "pad_repetitions",
  "parse_unix_path",
  "partchannelRefs",
  "pending_damage=",
  "propigate_stale",
  "radial_gradient",
  "reset_transform",
  "runtime_points=",
  "setup_valuerefs",
  "source_location",
  "string_to_lines",
  "string_to_stats",
  "text_box_bounds",
  "transform_keys!",
  "tri_low_right_x",
  "tri_low_right_y",
  "under_highlight",
  "world_readable?",
  "world_writable?",
  "$damaged_classes",
  "@auto_apply_last",
  "@automation_view",
  "FilterHighlight1",
  "FilterHighlight2",
  "FloatDomainError",
  "HSliderKeySelect",
  "MRUBY_RELEASE_NO",
  "PropertyDatabase",
  "SliderBackground",
  "SystemStackError",
  "VisualBackground",
  "ZynEffectsInsert",
  "ZynEffectsSystem",
  "ZynOscilModRight",
  "ZynSubFreqbutton",
  "active_indicator",
  "background_color",
  "clear_on_extern=",
  "connect_property",
  "consume_arg_list",
  "create_image_mem",
  "create_new_child",
  "defaultMaxStages",
  "draw_color_wheel",
  "draw_placeholder",
  "executable_real?",
  "forget_all_state",
  "get_global_const",
  "handleMousePress",
  "install_database",
  "invalid_position",
  "num_visible_rows",
  "prepend_features",
  "proper_superset?",
  "remove_old_child",
  "text_break_lines",
  "text_line_height",
  "transform_values",
  "under_highlight=",
  "update_nonfree_x",
  "update_nonfree_y",
  "@active_indicator",
  "@animate_frame_dt",
  "@scheduled_events",
  "@stale_rdep_graph",
  "@transaction_nest",
  "ConstantDirectory",
  "GL_IMPLEMENTATION",
  "GeneralBackground",
  "MRUBY_DESCRIPTION",
  "ZeroDivisionError",
  "ZynAutomationName",
  "ZynAutomationPlot",
  "ZynAutomationSlot",
  "ZynMixerMasterCol",
  "ZynModFreqGeneral",
  "code_format_print",
  "consume_value_tok",
  "create_image_rgba",
  "current_transform",
  "defaultMaxStages=",
  "disable_kernel_io",
  "ensure_properties",
  "expand_path_array",
  "flush_word_buffer",
  "generate_children",
  "generational_mode",
  "get_list_from_int",
  "intersect_scissor",
  "punish_difference",
  "remove_properties",
  "test_windows_file",
  "text_line_height=",
  "transform_values!",
  "update_dependency",
  "HarmonicEditSingle",
  "MRUBY_RELEASE_DATE",
  "ZynAddOscilloscope",
  "ZynAmpVoiceGeneral",
  "ZynAutomationParam",
  "ZynPadOscilloscope",
  "ZynSubAnalogFilter",
  "ZynSubOscilloscope",
  "bound_to_temporary",
  "displayValueToText",
  "generational_mode=",
  "handleMouseRelease",
  "initialize_w_flags",
  "install_initialize",
  "joint_bounding_box",
  "load_qml_from_file",
  "make_draw_sequence",
  "opt_norm_harmonics",
  "parse_windows_path",
  "pending_change_cat",
  "sub_synth_response",
  "test_unix_add_char",
  "test_unix_set_home",
  "test_window_cd_alt",
  "@animate_frame_next",
  "BackgroundTextColor",
  "GL_COLOR_BUFFER_BIT",
  "GL_DEPTH_BUFFER_BIT",
  "IMAGE_PREMULTIPLIED",
  "NotImplementedError",
  "RUBY_ENGINE_VERSION",
  "ZynAddVoiceListItem",
  "ZynFreqGeneralVoice",
  "add_attr_connection",
  "build_qml_dep_graph",
  "consume_instruction",
  "old_square_brancket",
  "respond_to_missing?",
  "text_letter_spacing",
  "RecursiveDirectories",
  "end_load_transaction",
  "set_vis_oscilloscope",
  "text_glyph_positions",
  "text_letter_spacing=",
  "GL_STENCIL_BUFFER_BIT",
  "ZynAutomationMidiChan",
  "ZynInstrumentSettings",
  "__coerce_step_counter",
  "assert_nothing_raised",
  "compute_content_lines",
  "enumerator_block_call",
  "handle_pending_layout",
  "handle_pending_resize",
  "instance_variable_get",
  "test_windows_set_home",
  "think_of_the_children",
  "update_path_recursive",
  "IMAGE_GENERATE_MIPMAPS",
  "convert_partial_to_dir",
  "singleton_method_added",
  "start_load_transaction",
  "_replace_back_reference",
  "formant_filter_response",
  "mruby_qml_parse_test_ir",
  "mruby_qml_parse_test_vm",
  "power_sign_stroke_color",
  "get_enable_option_string",
  "make_draw_sequence_recur",
  "remove_instance_variable",
  "StartRecursiveDirectories",
  "copy_current_transform_to",
  "get_disable_option_string",
  "test_windows_change_drive",
  "mruby_qml_parse_test_parse",
  "text_glyph_positions_yielded",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/enum.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/hash.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/array.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/range.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/compar.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/kernel.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/string.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/symbol.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/00class.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/10error.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrblib/numeric.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir/mrblib/dir.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/osc.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/util.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/build.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-set/mrblib/mrb_set.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir-glob/mrblib/dir.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/color.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-file-stat/mrblib/ext.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/nanovg.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/test.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/pos.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/context.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-process/mrblib/status.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/io.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/build.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/rect.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/util.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/colorwheel.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-process/mrblib/process.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/parser.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/loader.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/sched.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/draw-common.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/macro-state.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/transform.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/prog-ir.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/prog-vm.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/fcache.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/layout.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/remote.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/script.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-zest/mrblib/file-browser.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-dir-glob/mrblib/dir_glob.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-spawn/mrblib/database.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/font_handle.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/kernel.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-time/mrblib/time.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/ui-event.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-file-stat/mrblib/file-stat.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-nanovg/mrblib/image_handle.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/react-attr.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-print/mrblib/print.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-qml-parse/mrblib/parse-types.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-hash-ext/mrblib/hash.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-proc-ext/mrblib/proc.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/time-profile.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-regexp-pcre/mrblib/regexp_pcre.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/deps/mruby-regexp-pcre/mrblib/string_pcre.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-sprintf/mrblib/string.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/src/mruby-widget-lib/mrblib/draw-sequence.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-array-ext/mrblib/array.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-io/mrblib/file_constants.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-object-ext/mrblib/object.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-string-ext/mrblib/string.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-enumerator/mrblib/enumerator.rb",
  "/build/zynaddsubfx/src/zynaddsubfx-mruby-zest-build/mruby/mrbgems/mruby-toplevel-ext/mrblib/toplevel.rb",
};
